@@ -98,6 +98,9 @@ typedef int32_t tAppId;
 #define APPID_SESSION_HOST_CACHE_MATCHED    (1ULL << 42)
 #define APPID_SESSION_OOO_CHECK_TP          (1ULL << 43)
 
+#define APPID_SESSION_HTTP_TUNNEL           (1ULL << 44)
+#define APPID_SESSION_HTTP_CONNECT          (1ULL << 45)
+
 #define APPID_SESSION_IGNORE_ID_FLAGS       (APPID_SESSION_IGNORE_FLOW | \
                                              APPID_SESSION_NOT_A_SERVICE | \
                                              APPID_SESSION_NO_TPI | \
