@@ -35,11 +35,15 @@
 #define CS_TYPE_RELOAD          0x0002
 #define CS_TYPE_IS_PROCESSING   0x0003
 #define CS_TYPE_DUMP_PACKETS    0x0004
+#define CS_TYPE_MEM_USAGE       0x0005
 #define CS_TYPE_ACTION_STATS    0x0006
 #define CS_TYPE_STREAM_STATS    0x0007
 #define CS_TYPE_SMTP_STATS      0x0008
 #define CS_TYPE_SSL_STATS       0x0009
 #define CS_TYPE_SIP_STATS       0x000A
+#define CS_TYPE_FLOWIP_START    0x000D
+#define CS_TYPE_FLOWIP_STOP     0x000E
+#define CS_TYPE_FLOWIP_SHOW     0x000F
 #define CS_TYPE_MAX             0x1FFF
 #define CS_HEADER_VERSION       0x0001
 #define CS_HEADER_SUCCESS       0x0000
@@ -49,6 +53,7 @@
 #define CS_CONFIG_SWAP          0x000A
 #endif
 /* For SFR Display */
+#define MEM_STATS_BUF_SIZE 7680 //CS_STATS_BUF_SIZE * (no. of preprocessors) * 2 = 1280 * 3 * 2
 #define CS_STATS_BUF_SIZE 1280
 #pragma pack(1)
 typedef struct _CS_MESSAGE_DATA_HEADER
