@@ -116,6 +116,10 @@ static void DispatchPreprocessors( Packet *p, tSfPolicyId policy_id, SnortPolicy
     PreprocEnableMask pps_enabled_foo;
     bool alerts_processed = false;
 
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+    uint64_t start=0, end=0;
+#endif
+ 
     // No expected sessions yet.
     p->expectedSession = NULL;
 
@@ -139,7 +143,21 @@ static void DispatchPreprocessors( Packet *p, tSfPolicyId policy_id, SnortPolicy
             break;
 
         if ( preprocHandlesProto( p, ppn ) && IsPreprocessorEnabled( p, ppn->preproc_bit ) )
+        {
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+            if (p->pkth && (p->pkth->flags & DAQ_PKT_FLAG_DEBUG_ON))
+            {
+                get_clockticks(start);
+                ppn->func( p, ppn->context );
+                get_clockticks(end);
+                print_flow(p,NULL,ppn->preproc_id,start,end);
+            }
+            else
+                ppn->func( p, ppn->context );
+#else
             ppn->func( p, ppn->context );
+#endif 
+        }
 
 
         if( !alerts_processed && ( p->ips_os_selected || ppn->preproc_id == PP_FW_RULE_ENGINE ) )
@@ -169,6 +187,7 @@ static void DispatchPreprocessors( Packet *p, tSfPolicyId policy_id, SnortPolicy
 int Preprocess(Packet * p)
 {
     int retval = 0;
+    int detect_retval = 0;
     tSfPolicyId policy_id;
 
    /* NAP runtime policy may have been updated during decode, 
@@ -253,8 +272,10 @@ int Preprocess(Packet * p)
         // ok, dispatch all preprocs enabled for this packet/session
         DispatchPreprocessors( p, policy_id, policy );
 
-        if ( do_detect )
-            Detect(p);
+        if ( do_detect ) 
+        {
+            detect_retval = Detect(p);
+        }
     }
 
     check_tags_flag = 1;
@@ -339,6 +360,9 @@ int Preprocess(Packet * p)
             LogMessage("PPM: Process-EndPkt[%u]\n\n",(unsigned)pktcnt);
         }
 #endif
+       // When detection is required to happen and it is skipped , then only we will print the trace. 
+        if (do_detect && (!detect_retval)) 
+            PPM_LATENCY_TRACE();
 
         PPM_PKT_LOG(p);
     }
@@ -563,6 +587,10 @@ int Detect(Packet * p)
     int detected = 0;
     PROFILE_VARS;
 
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+    uint64_t start = 0, end = 0;
+#endif
+
     if ((p == NULL) || !IPH_IS_VALID(p))
     {
         return 0;
@@ -625,7 +653,20 @@ int Detect(Packet * p)
     **  that we can do IP checks.
     */
     PREPROC_PROFILE_START(detectPerfStats);
+ #if defined(DAQ_VERSION) && DAQ_VERSION > 9
+    if (p->pkth && (p->pkth->flags & DAQ_PKT_FLAG_DEBUG_ON))
+    {
+        get_clockticks(start);
+        detected = fpEvalPacket(p);
+        get_clockticks(end);
+        print_flow(p,"DETECTION",0,start,end);
+    }
+    else
+        detected = fpEvalPacket(p);
+ #else
     detected = fpEvalPacket(p);
+#endif
+
     PREPROC_PROFILE_END(detectPerfStats);
 
     return detected;
