@@ -1034,7 +1034,7 @@ int detection_option_node_evaluate(detection_option_tree_node_t *node, detection
                                  !detection_filter_test(
                                  otn->detection_filter,
                                  GET_SRC_IP(eval_data->p), GET_DST_IP(eval_data->p),
-                                 eval_data->p->pkth->ts.tv_sec, eval_data,otn))
+                                 eval_data->p->pkth->ts.tv_sec, eval_data))
                         {
 #ifdef PERF_PROFILING
                             if (PROFILING_RULES)
