@@ -64,7 +64,7 @@
 #include <strings.h>
 #endif
 #include <errno.h>
-
+#include "limits.h"
 #include "sf_types.h"
 #include "snort_bounds.h"
 #include "byte_extract.h"
@@ -911,13 +911,29 @@ int ByteMath(void *option_data, Packet *p)
         payload_bytes_grabbed, btd->offset, btd->rvalue, btd->rvalue, value, value); );
     switch(btd->operator)
     {
-        case BM_PLUS: *value += btd->rvalue;
-                      success = 1;
-                      break;
+        case BM_PLUS: if ((UINT_MAX - *value) < btd->rvalue)
+                      {
+                          LogMessage("Buffer Overflow\n");
+                          return DETECTION_OPTION_NO_MATCH;
+                      }
+                      else
+                      {
+                          *value += btd->rvalue;
+                          success = 1;
+                          break;
+                      }
 
-        case BM_MINUS: *value -= btd->rvalue;
-                       success = 1;
-                       break;
+        case BM_MINUS: if (*value < btd->rvalue)
+                       { 
+                           LogMessage("Buffer Underflow\n");
+                           return DETECTION_OPTION_NO_MATCH;
+                       }
+                       else
+                       {
+                           *value -= btd->rvalue;
+                           success = 1;
+                           break;
+                       }
 
         case BM_MULTIPLY: *value *= btd->rvalue;
                      success = 1;
