@@ -35,7 +35,6 @@
 
 #include "sfthreshold.h"
 #include "ipv6_port.h"
-#include "treenodes.h"
 
 typedef struct _DetectionFilterConfig
 {
@@ -54,7 +53,7 @@ void detection_filter_cleanup( void );
 void detection_filter_print_config(DetectionFilterConfig *);
 void detection_filter_reset_active(void);
 
-int detection_filter_test(void*, sfaddr_t* sip, sfaddr_t* dip, long curtime, detection_option_eval_data_t *eval_data, OptTreeNode *otn);
+int detection_filter_test(void*, sfaddr_t* sip, sfaddr_t* dip, long curtime, detection_option_eval_data_t *eval_data);
 void * detection_filter_create(DetectionFilterConfig *, THDX_STRUCT *);
 
 #endif
