@@ -55,7 +55,7 @@
 #endif
 #endif
 
-#define PREPROCESSOR_DATA_VERSION 22
+#define PREPROCESSOR_DATA_VERSION 25
 
 #include "sf_dynamic_common.h"
 #include "sf_dynamic_engine.h"
@@ -222,6 +222,10 @@ typedef int (*DynamicQueryFlow)(const DAQ_PktHdr_t *hdr, DAQ_QueryFlow_t* query)
 typedef void (*DynamicDebugPkt)(uint8_t moduleId, uint8_t logLevel, const DAQ_Debug_Packet_Params_t *params, const char *msg, ...);
 #endif
 
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+typedef int (*DynamicIoctl)(unsigned int type, char *buffer, size_t *len);
+#endif
+
 typedef int (*DynamicIsStrEmpty)(const char * );
 typedef void (*AddPeriodicCheck)(void (*pp_check_func) (int, void *), void *arg, uint16_t, uint32_t, uint32_t);
 typedef void (*AddPostConfigFuncs)(struct _SnortConfig *, void (*pp_post_config_func) (struct _SnortConfig *, void *), void *arg);
@@ -332,7 +336,11 @@ typedef int (*RegisterMemoryStatsFunc)(uint preproc, char* preproc_name,
 typedef void* (*SnortAllocFunc)(int num, unsigned long size, uint32_t preproc, bool data);
 
 typedef void (*SnortFreeFunc)(void * ptr, uint32_t size, uint32_t preproc, bool data);
-
+typedef bool (*ReputationProcessExternalIpFunc)(void *p, sfaddr_t* ip);
+typedef void (*RegisterReputationProcessExternalFunc)(ReputationProcessExternalIpFunc);
+/* FTP data transfer mode */
+typedef bool (*ftpGetModefunc)(void *ssnptr);
+typedef void (*RegisterFtpQueryModefunc)(ftpGetModefunc);
 #define ENC_DYN_FWD 0x80000000
 #define ENC_DYN_NET 0x10000000
 
@@ -509,6 +517,10 @@ typedef struct _DynamicPreprocessorData
     DynamicDebugPkt dynamicDebugPkt;
 #endif
 
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+    DynamicIoctl dynamicIoctl;
+#endif
+
     AddPeriodicCheck addPeriodicCheck;
     AddPostConfigFuncs addPostConfigFunc;
     AddToPostConfList addFuncToPostConfigList;
@@ -606,6 +618,10 @@ typedef struct _DynamicPreprocessorData
     RegisterGetDaqCapaTimeoutFunc registerGetDaqCapaTimeout;
 #endif
 
+    ReputationProcessExternalIpFunc reputation_process_external_ip;
+    RegisterReputationProcessExternalFunc registerReputationProcessExternal;
+    RegisterFtpQueryModefunc registerFtpmodeQuery;
+    ftpGetModefunc ftpGetMode;
 
 } DynamicPreprocessorData;
 
