@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * Author: Steve Sturges
@@ -319,6 +319,10 @@ static int GetDynamicPreprocOptFpContents(void *r, FPContentInfo **fp_contents)
 
     *fp_contents = NULL;
 
+    if (rule->options == NULL) {
+        return (-1);
+    }
+
     /* Get flow direction */
     for (i = 0, option = rule->options[i];
             option != NULL;
@@ -835,7 +839,7 @@ int RegisterOneRule(struct _SnortConfig *sc, Rule *rule, int registerRule)
     RuleOption *option;
     int fast_pattern = 0;
 
-    for (i=0;rule->options[i] != NULL; i++)
+    for (i=0; ((rule->options) && rule->options[i] != NULL); i++)
     {
         option = rule->options[i];
         switch (option->optionType)
@@ -1055,7 +1059,7 @@ int RegisterOneRule(struct _SnortConfig *sc, Rule *rule, int registerRule)
                     &FreeOneRule,
                     &GetDynamicPreprocOptFpContents) == -1)
         {
-            for (i = 0; rule->options[i] != NULL; i++)
+            for (i = 0; ((rule->options) && rule->options[i] != NULL); i++)
             {
                 option = rule->options[i];
                 switch (option->optionType)
@@ -1230,7 +1234,7 @@ static int DumpRule(FILE *fp, Rule *rule)
     if (rule->info.priority != 0)
         fprintf(fp, "priority:%d; ", rule->info.priority);
 
-    for (i = 0; rule->options[i] != NULL; i++)
+    for (i = 0; ((rule->options) && rule->options[i] != NULL); i++)
     {
         if( rule->options[i]->optionType == OPTION_TYPE_FLOWBIT )
         {
