@@ -80,6 +80,7 @@
 
 #include "snort.h"
 #include "profiler.h"
+#include "reload.h"
 
 #ifdef PERF_PROFILING
 PreprocStats dynamicRuleEvalPerfStats;
@@ -274,8 +275,14 @@ void DynamicRuleListFree(DynamicRuleNode *head)
     {
         DynamicRuleNode *tmp = head->next;
 
+        /* 
+         * Clean up will be executed only when snort exits or
+         * dynamic libs have changed
+         */
         if (head->freeFunc)
+        {
             head->freeFunc((void *)head->rule);
+        }
 
         free(head);
         head = tmp;
@@ -332,7 +339,7 @@ int RegisterDynamicRule(
                    __FILE__, __LINE__);
     }
 
-    if ( SnortIsInitializing() )
+    if ( SnortDynamicLibsChanged() || SnortIsInitializing() )
     {
         node = (DynamicRuleNode *)SnortAlloc(sizeof(DynamicRuleNode));
 
@@ -468,6 +475,11 @@ int ReloadDynamicRules(SnortConfig *sc)
      * dynamic detection has changed.
      */
     DynamicRuleNode *node = snort_conf->dynamic_rules;
+  
+    sc->dynamic_rules = snort_conf->dynamic_rules;
+    sc->loadedDetectionPlugins = snort_conf->loadedDetectionPlugins;
+    snort_conf->loadedDetectionPlugins = NULL;
+    snort_conf->dynamic_rules = NULL;
 
     for (; node != NULL; node = node->next)
     {
