@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -1007,6 +1007,10 @@ typedef enum
     APP_ID_FTP_ACTIVE=4002,
     APP_ID_FTP_PASSIVE=4003,
     APP_ID_PSIPHON=4075,
+    APP_ID_ENIP=5001,
+    APP_ID_CIP=5002,
+    APP_ID_CIP_UNKNOWN=5003,
+    APP_ID_CIP_MALFORMED=5005,
     APP_ID_UNKNOWN_UI = 65535  /*This causes the UI to render Unknown instead of pending or blank */
 } appIdEnum;
 
@@ -1043,4 +1047,7 @@ typedef enum {
 #define FINGERPRINT_UDP_FLAGS_NT    0x00001000
 #define FINGERPRINT_UDP_FLAGS_MASK  (FINGERPRINT_UDP_FLAGS_XENIX | FINGERPRINT_UDP_FLAGS_NT)
 
+#define NEW_PAYLOAD_STATE           0xA0000000
+#define OLD_PAYLOAD_STATE           0xB0000000
+
 #endif  /* __APP_ID_H__ */
