@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -98,6 +98,18 @@ tAppId getFwReferredAppId(struct AppIdData *appIdData)
         return fwPickReferredPayloadAppId(appIdData);
     return APP_ID_NONE;
 }
+char* getTlsHost(struct AppIdData *appIdData)
+{   
+    if (appIdData && appIdData->tsession)
+        return appIdData->tsession->tls_host;
+    return NULL;
+}
+SFGHASH* getFwMultiPayloadList(struct AppIdData *appIdData)
+{
+    if (appIdData)
+        return fwPickMultiPayloadList(appIdData);
+    return NULL;
+}
 bool isSessionSslDecrypted(struct AppIdData *appIdData)
 {
     if (appIdData)
@@ -122,7 +134,9 @@ bool isHttpInspectionDone(struct AppIdData *appIdSession)
     if (!appIdSession)
         return true; // No wait for http discovery if AppId data is unavailable
     if ((appIdSession->common.fsf_type.flow_type != APPID_SESSION_TYPE_NORMAL)
-        || TPIsAppIdDone(appIdSession->tpsession))
+        || (TPIsAppIdDone(appIdSession->tpsession) &&
+            !(getAppIdFlag(appIdSession, APPID_SESSION_SSL_SESSION) && !getTlsHost(appIdSession) &&
+              appIdSession->rnaServiceState != RNA_STATE_FINISHED)))
         return true;
     return false;
 }
@@ -370,13 +384,6 @@ sfaddr_t* getHttpXffAddr(struct AppIdData* appIdData)
         return appIdData->hsession->xffAddr;
     return NULL;
 }
-
-char* getTlsHost(struct AppIdData *appIdData)
-{
-    if (appIdData && appIdData->tsession)
-        return appIdData->tsession->tls_host;
-    return NULL;
-}
 tAppId getPortServiceAppId(struct AppIdData *appIdData)
 {
     if (appIdData)
@@ -630,6 +637,7 @@ static struct AppIdApi appIdDispatchTable = {
     getFwClientAppId,
     getFwPayloadAppId,
     getFwReferredAppId,
+    getFwMultiPayloadList,
 
     isSessionSslDecrypted,
     IsAppIdInspectingSession,
