@@ -72,6 +72,7 @@ void appIdConfigParse(tAppidStaticConfig* appidSC, char *args)
     char **stoks;
     int s_toks;
     char *endPtr;
+    char *ro_app_detector_dir;
 
     memset (appidSC, 0, sizeof(*appidSC));
 
@@ -89,6 +90,15 @@ void appIdConfigParse(tAppidStaticConfig* appidSC, char *args)
     if ((args == NULL) || (strlen(args) == 0))
         return;
 
+    ro_app_detector_dir = getenv("APPID_DETECTOR_DIR");
+    if (ro_app_detector_dir)
+    {   
+        if (NULL == (appidSC->app_id_detector_path = strdup(ro_app_detector_dir)))
+        {   
+            _dpd.fatalMsg("Appid failed to allocate RO detector path\n");
+        }
+    }
+
     toks = _dpd.tokenSplit(args, ",", 0, &num_toks, 0);
     i = 0;
 
@@ -207,14 +217,17 @@ void appIdConfigParse(tAppidStaticConfig* appidSC, char *args)
         }
         else if(!strcasecmp(stoks[0], "app_detector_dir"))
         {
-            if ((s_toks != 2) || !*stoks[1])
+            if (!ro_app_detector_dir)
             {
-                _dpd.fatalMsg("%s(%d) => %s\n", *(_dpd.config_file), *(_dpd.config_line), "Invalid app_detector_dir");
-            }
+                if ((s_toks != 2) || !*stoks[1])
+                {
+                    _dpd.fatalMsg("%s(%d) => %s\n", *(_dpd.config_file), *(_dpd.config_line), "Invalid app_detector_dir");
+                }
 
-            if (NULL == (appidSC->app_id_detector_path = strdup(stoks[1])))
-            {
-                _dpd.fatalMsg("Appid failed to allocate detector path\n");
+                if (NULL == (appidSC->app_id_detector_path = strdup(stoks[1])))
+                {
+                    _dpd.fatalMsg("Appid failed to allocate detector path\n");
+                }
             }
         }
         else if(!strcasecmp(stoks[0], "instance_id"))
