@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -408,6 +408,12 @@ static void dumpStats2(void)
             header.type = UNIFIED2_IDS_EVENT_APPSTAT;
             header.length = buffSize - 2*sizeof(uint32_t);
             buffer = malloc(buffSize);
+            if(!buffer)
+            {
+                _dpd.errMsg("dumpStats2: "
+                        "Failed to allocate memory for appRecord in StatsBucket\n");
+                return;
+            }
 #           ifdef DEBUG_STATS
             fprintf(SF_DEBUG_FILE, "Write App Records %u Size: %lu\n",
                     bucket->appRecordCnt, buffSize);
