@@ -39,7 +39,10 @@
 #define USR_CONFIG_FILE "userappid.conf"
 
 #define MAX_TABLE_LINE_LEN      1024
+// Generic delimiter for conf file
 #define CONF_SEPARATORS         "\t\n\r"
+// Delimiter for appid.conf  and userappid.conf file
+#define CONF_SEPARATORS_USR_APPID         " \t\n\r"
 #define MIN_MAX_TP_FLOW_DEPTH   1
 #define MAX_MAX_TP_FLOW_DEPTH   1000000
 #define MIN_HOST_PORT_APP_CACHE_LOOKUP_INTERVAL    1
@@ -331,7 +334,7 @@ void appInfoTableInit(tAppidStaticConfig* appidSC, tAppIdConfig* pConfig)
 
     while (fgets(buf, sizeof(buf), tableFile))
     {
-        token = strtok(buf, CONF_SEPARATORS);
+        token = strtok(buf, CONF_SEPARATORS );
         if (!token)
         {
             _dpd.errMsg("Could not read id for Rna Id\n");
@@ -340,7 +343,7 @@ void appInfoTableInit(tAppidStaticConfig* appidSC, tAppIdConfig* pConfig)
 
         appId = strtol(token, NULL, 10);
 
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS );
         if (!token)
         {
             _dpd.errMsg("Could not read appName. Line %s\n", buf);
@@ -354,7 +357,7 @@ void appInfoTableInit(tAppidStaticConfig* appidSC, tAppIdConfig* pConfig)
             continue;
         }
 
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS );
         if (!token)
         {
             _dpd.errMsg("Could not read service id for Rna Id\n");
@@ -364,7 +367,7 @@ void appInfoTableInit(tAppidStaticConfig* appidSC, tAppIdConfig* pConfig)
 
         serviceId = strtol(token, NULL, 10);
 
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS );
         if (!token)
         {
             _dpd.errMsg("Could not read client id for Rna Id\n");
@@ -374,7 +377,7 @@ void appInfoTableInit(tAppidStaticConfig* appidSC, tAppIdConfig* pConfig)
 
         clientId = strtol(token, NULL, 10);
 
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS );
         if (!token)
         {
             _dpd.errMsg("Could not read payload id for Rna Id\n");
@@ -385,7 +388,7 @@ void appInfoTableInit(tAppidStaticConfig* appidSC, tAppIdConfig* pConfig)
         payloadId = strtol(token, NULL, 10);
 
         /* snort service key, if it exists */
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS );
         if (token)
         {
             snortName = strdup(token);
@@ -616,7 +619,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
     while (fgets(buf, sizeof(buf), config_file) != NULL)
     {
         line++;
-        token = strtok(buf, CONF_SEPARATORS);
+        token = strtok(buf, CONF_SEPARATORS_USR_APPID);
         if (token == NULL)
         {
             _dpd.errMsg("Could not read configuration at line %s:%u\n", path, line);
@@ -624,7 +627,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
         }
         conf_type = token;
 
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS_USR_APPID);
         if (token == NULL)
         {
             _dpd.errMsg("Could not read configuration value at line %s:%u\n", path, line);
@@ -632,7 +635,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
         }
         conf_key = token;
 
-        token = strtok(NULL, CONF_SEPARATORS);
+        token = strtok(NULL, CONF_SEPARATORS_USR_APPID);
         if (token == NULL)
         {
             _dpd.errMsg("Could not read configuration value at line %s:%u\n", path, line);
@@ -806,7 +809,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
             {
                 int temp_appid;
                 temp_appid = strtol(conf_val, NULL, 10 );
-                token = strtok(NULL, CONF_SEPARATORS);
+                token = strtok(NULL, CONF_SEPARATORS_USR_APPID);
                 if (token == NULL)
                 {
                     _dpd.errMsg("Could not read app_priority at line %u\n", line);
@@ -833,7 +836,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
                     referred_app_index += sprintf(referred_app_list, "%d ", atoi(conf_val));
                     appInfoEntryFlagSet(atoi(conf_val), APPINFO_FLAG_REFERRED, pConfig);
 
-                    while ((token = strtok(NULL, CONF_SEPARATORS)) != NULL)
+                    while ((token = strtok(NULL, CONF_SEPARATORS_USR_APPID)) != NULL)
                     {
                         referred_app_index += sprintf(referred_app_list+referred_app_index, "%d ", atoi(token));
                         appInfoEntryFlagSet(atoi(token), APPINFO_FLAG_REFERRED, pConfig);
@@ -903,6 +906,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
             else if (!(strcasecmp(conf_key, "bittorrent_aggressiveness")))
             {
                 int aggressiveness = atoi(conf_val);
+                _dpd.logMsg("AppId: bittorrent_aggressiveness %d\n", aggressiveness);
                 if (aggressiveness >= 50)
                 {
                     appidSC->recheck_for_unknown_appid = 1;
@@ -920,6 +924,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
             else if (!(strcasecmp(conf_key, "ultrasurf_aggressiveness")))
             {
                 int aggressiveness = atoi(conf_val);
+                _dpd.logMsg("AppId: ultrasurf_aggressiveness %d\n", aggressiveness);
                 if (aggressiveness >= 50)
                 {
                     appidSC->check_host_cache_unknown_ssl = 1;
@@ -936,6 +941,7 @@ static void appIdConfLoad (tAppidStaticConfig* appidSC, const char *path)
             else if (!(strcasecmp(conf_key, "psiphon_aggressiveness")))
             {
                 int aggressiveness = atoi(conf_val);
+                _dpd.logMsg("AppId: psiphon_aggressiveness %d\n", aggressiveness);
                 if (aggressiveness >= 50)
                 {
                     appidSC->check_host_cache_unknown_ssl = 1;
