@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -45,6 +45,7 @@
 #include "client_app_msn.h"
 #include "client_app_aim.h"
 #include "client_app_ym.h"
+#include "detector_cip.h"
 #include "detector_sip.h"
 #include "luaDetectorModule.h"
 #include "luaDetectorApi.h"
@@ -135,7 +136,9 @@ static tRNAClientAppModule *static_client_list[] =
     &pattern_tcp_client_mod,
     &dns_udp_client_mod,
     &dns_tcp_client_mod,
-    &http_client_mod
+    &http_client_mod,
+    &cip_client_mod,
+    &enip_client_mod
 };
 
 /*static const char * const MODULE_NAME = "ClientApp"; */
