@@ -90,9 +90,10 @@ static void DisplayConfig(tAppidStaticConfig* appidSC, tAppIdConfig *aic)
     NetworkSet *net_list;
 
     if (appidSC->appid_thirdparty_dir)
-    {
         _dpd.logMsg("    3rd Party Dir: %s\n", appidSC->appid_thirdparty_dir);
-    }
+    if (appidSC->tp_config_path)
+        _dpd.logMsg("    3rd Party Conf: %s\n", appidSC->tp_config_path);
+
     net_list = aic->net_list;
     _dpd.logMsg("    Monitoring Networks for any zone:\n");
     for (i = 0; i < net_list->count; i++)
