@@ -2229,7 +2229,7 @@ tAppId getAppIdFromUrl(char *host, char *url, char **version,
     int host_len;
     int referer_len = 0;
     int referer_path_len = 0;
-    int path_len;
+    int path_len = 0;
     tMlmpPattern patterns[3];
     tMlpPattern query;
     HostUrlDetectorPattern *data;
@@ -2293,13 +2293,16 @@ tAppId getAppIdFromUrl(char *host, char *url, char **version,
             free(temp_host);
             return 0;
         }
-        path_len = url_len - host_len;
-        path = url + host_len;
+
+        path = strchr(url, '/');
+        if (path)
+            path_len = url + url_len - path;
     }
-    else
+
+    if (!path_len)
     {
-        path = NULL;
-        path_len = 0;
+        path = "/";
+        path_len = 1;
     }
 
     patterns[0].pattern = (uint8_t *) host;
