@@ -46,6 +46,8 @@ typedef enum
     SMTP_CLIENT_STATE_MESSAGE,
     SMTP_CLIENT_STATE_GET_PRODUCT_VERSION,
     SMTP_CLIENT_STATE_SKIP_LINE,
+    SMTP_CLIENT_STATE_SKIP_SPACE,
+    SMTP_CLIENT_STATE_SKIP_EOL,
     SMTP_CLIENT_STATE_CONNECTION_ERROR,
     SMTP_CLIENT_STATE_STARTTLS,
     SMTP_CLIENT_STATE_LOGIN_USER,
@@ -114,8 +116,8 @@ typedef struct {
     unsigned appId;
 } Client_App_Pattern;
 
-#define HELO "HELO "
-#define EHLO "EHLO "
+#define HELO "HELO"
+#define EHLO "EHLO"
 #define MAILFROM "MAIL FROM:"
 #define RCPTTO "RCPT TO:"
 #define DATA "DATA"
@@ -235,8 +237,10 @@ static CLIENT_APP_RETCODE smtp_ca_init(const InitClientAppAPI * const init_api,
 
 typedef enum
 {
+    SMTP_SERVICE_STATE_NONE,
     SMTP_SERVICE_STATE_CONNECTION,
     SMTP_SERVICE_STATE_HELO,
+    SMTP_SERVICE_STATE_BAD_CLIENT,
     SMTP_SERVICE_STATE_TRANSFER,
     SMTP_SERVICE_STATE_CONNECTION_ERROR,
     SMTP_SERVICE_STATE_STARTTLS,
@@ -585,9 +589,9 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
     const uint8_t *end;
     unsigned len;
     int line_break = 0;
+    SMTPServiceState serviceState;
 #ifdef UNIT_TESTING
     SMTPClientState currState = SMTP_CLIENT_STATE_NONE;
-
 #endif
 
 #ifdef APP_ID_USES_REASSEMBLED
@@ -596,11 +600,11 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
     if ((dd = smtp_get_SMTPDetectorData(flowp)) == NULL)
         return CLIENT_APP_ENOMEM;
 
-    fd = &dd->client;
-
     if (dir != APP_ID_FROM_INITIATOR)
         return CLIENT_APP_INPROCESS;
 
+    fd = &dd->client;
+
     if (getAppIdFlag(flowp, APPID_SESSION_ENCRYPTED | APPID_SESSION_DECRYPTED) == APPID_SESSION_ENCRYPTED)
     {
         if ((fd->flags & CLIENT_FLAG_STARTTLS_SUCCESS))
@@ -625,11 +629,11 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
     for (end = data + size; data < end; data++)
     {
 #ifdef UNIT_TESTING
-    if (app_id_debug_session_flag && currState != fd->state)
-    {
-        DEBUG_WRAP(DebugMessage(DEBUG_APPID, "AppIdDbg %s SMTP client state %s\n", app_id_debug_session, stateName[fd->state]););
-        currState = fd->state;
-    }
+        if (app_id_debug_session_flag && currState != fd->state)
+        {
+            DEBUG_WRAP(DebugMessage(DEBUG_APPID, "AppIdDbg %s SMTP client state %s\n", app_id_debug_session, stateName[fd->state]););
+            currState = fd->state;
+        }
 #endif
         len = end - data;
         switch (fd->state)
@@ -639,20 +643,21 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
             {
                 data += (sizeof(HELO)-1)-1;
                 fd->nextstate = SMTP_CLIENT_STATE_MAIL_FROM;
-                fd->state = SMTP_CLIENT_STATE_SKIP_LINE;
+                fd->state = SMTP_CLIENT_STATE_SKIP_SPACE;
                 fd->flags &= ~ CLIENT_FLAG_STARTTLS_SUCCESS;
             }
             else if (len >= (sizeof(EHLO)-1) && strncasecmp((const char *)data, EHLO, sizeof(EHLO)-1) == 0)
             {
                 data += (sizeof(EHLO)-1)-1;
                 fd->nextstate = SMTP_CLIENT_STATE_MAIL_FROM;
-                fd->state = SMTP_CLIENT_STATE_SKIP_LINE;
+                fd->state = SMTP_CLIENT_STATE_SKIP_SPACE;
                 fd->flags &= ~ CLIENT_FLAG_STARTTLS_SUCCESS;
             }
             else goto done;
             break;
 
         case SMTP_CLIENT_STATE_MAIL_FROM:
+            serviceState = dd->server.state;
             if (len >= (sizeof(MAILFROM)-1) && strncasecmp((const char *)data, MAILFROM, sizeof(MAILFROM)-1) == 0)
             {
                 data += (sizeof(MAILFROM)-1)-1;
@@ -686,7 +691,7 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
             else if (len >= (sizeof(STARTTLS)-1) && strncasecmp((const char *)data, STARTTLS, sizeof(STARTTLS)-1) == 0)
             {
                 data += (sizeof(STARTTLS)-1)-1;
-                dd->server.state = SMTP_SERVICE_STATE_STARTTLS;
+                serviceState = dd->server.state = SMTP_SERVICE_STATE_STARTTLS;
                 fd->nextstate = fd->state;
                 fd->state = SMTP_CLIENT_STATE_SKIP_LINE;
             }
@@ -706,6 +711,12 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
                 dd->server.state = SMTP_SERVICE_STATE_HELO; // make sure that service side expects the 250
             }
             else goto done;
+            if (serviceState == SMTP_SERVICE_STATE_TRANSFER)
+            {
+                setAppIdFlag(flowp, APPID_SESSION_CONTINUE);
+                smtp_service_mod.api->add_service(flowp, pkt, dir, &svc_element,
+                                                  APP_ID_SMTP, NULL, NULL, NULL, NULL);
+            }
             break;
         case SMTP_CLIENT_STATE_LOGIN_USER:
             {
@@ -827,6 +838,34 @@ static CLIENT_APP_RETCODE smtp_ca_validate(const uint8_t *data, uint16_t size, c
             }
             break;
 
+        case SMTP_CLIENT_STATE_SKIP_SPACE:
+            if (*data == ' ')
+            {
+                fd->state = SMTP_CLIENT_STATE_SKIP_LINE;
+            }
+            else if (*data == '\n')
+            {
+                fd->pos = 0;
+                fd->state = fd->nextstate;
+                fd->nextstate = SMTP_CLIENT_STATE_NONE;
+            }
+            else if (*data == '\r')
+                fd->state = SMTP_CLIENT_STATE_SKIP_EOL;
+            else
+                goto done;
+            break;
+
+        case SMTP_CLIENT_STATE_SKIP_EOL:
+            if (*data == '\n')
+            {
+                fd->pos = 0;
+                fd->state = fd->nextstate;
+                fd->nextstate = SMTP_CLIENT_STATE_NONE;
+            }
+            else
+                goto done;
+            break;
+
         case SMTP_CLIENT_STATE_SKIP_LINE:
             if (*data == '\n')
             {
@@ -971,13 +1010,21 @@ static int smtp_svc_validate(ServiceValidationArgs* args)
         return SERVICE_SUCCESS; // client made the decision so we are totally done
     }
 
+    fd = &dd->server;
+
     if (args->dir != APP_ID_FROM_RESPONDER)
     {
-        goto inprocess; // allow client validator to have it's shot.
+        if (SMTP_SERVICE_STATE_HELO == fd->state)
+        {
+            if (!((size >= (sizeof(HELO)-1) && strncasecmp((const char *)data, HELO, sizeof(HELO)-1) == 0) ||
+                  (size >= (sizeof(EHLO)-1) && strncasecmp((const char *)data, EHLO, sizeof(EHLO)-1) == 0)))
+            {
+                fd->state = SMTP_SERVICE_STATE_BAD_CLIENT;
+            }
+        }
+        goto inprocess;
     }
 
-    fd = &dd->server;
-
     offset = 0;
     while (offset < size)
     {
@@ -999,10 +1046,9 @@ static int smtp_svc_validate(ServiceValidationArgs* args)
             case 421:
                 if (service_strstr(data, size, (const uint8_t *)SMTP_CLOSING_CONN, sizeof(SMTP_CLOSING_CONN)-1))
                     goto success;
-            case 520:
+                goto fail;
             case 554:
-                fd->state = SMTP_SERVICE_STATE_CONNECTION_ERROR;
-                break;
+                goto success;
             default:
                 goto fail;
             }
@@ -1045,10 +1091,18 @@ static int smtp_svc_validate(ServiceValidationArgs* args)
                     setAppIdFlag(flowp, APPID_SESSION_ENCRYPTED | APPID_SESSION_STICKY_SERVICE);
                 return SERVICE_SUCCESS;
             }
-            /* STARTTLS failed. */
-            break;
+            /* STARTTLS failed. Fall through and call this SMTP */
         case SMTP_SERVICE_STATE_TRANSFER:
             goto success;
+        case SMTP_SERVICE_STATE_BAD_CLIENT:
+            switch (fd->code)
+            {
+            case 500:
+            case 501:
+            case 502:
+            case 550:
+                goto success;
+            }
         case SMTP_SERVICE_STATE_CONNECTION_ERROR:
         default:
             goto fail;
@@ -1061,7 +1115,7 @@ inprocess:
 
 success:
     if (dd->need_continue > 0)
-       setAppIdFlag(flowp, APPID_SESSION_CONTINUE);
+        setAppIdFlag(flowp, APPID_SESSION_CONTINUE);
 
     smtp_service_mod.api->add_service(flowp, args->pkt, args->dir, &svc_element,
                                       APP_ID_SMTP, NULL, NULL, NULL, NULL);
