@@ -332,6 +332,9 @@ typedef struct AppIdData
     SEARCH_SUPPORT_TYPE search_support_type;
 
     uint16_t hostCacheVersion;
+#ifdef DAQ_CAPA_VRF
+    uint16_t serviceAsId; //This is specific to VRF
+#endif
 } tAppIdData;
 /**
  * Mark a flow with a particular flag
