@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,7 @@
 #include "sip_common.h"
 #include "appInfoTable.h"
 #include "thirdparty_appid_utils.h"
+#include "sfghash.h"
 
 #define PP_APP_ID   1
 
@@ -94,6 +95,7 @@ void AppIdAddDnsResponseInfo(tAppIdData *flow,
 void AppIdResetDnsInfo(tAppIdData *flow);
 
 void AppIdAddPayload(tAppIdData *flow, tAppId payload_id);
+void AppIdAddMultiPayload(tAppIdData *flow, tAppId payload_id);
 tAppIdData* appSharedDataAlloc(uint8_t proto, const struct in6_addr *ip, uint16_t initiator_port);
 tAppId getOpenAppId(void *ssnptr);
 
@@ -305,6 +307,14 @@ static inline tAppId pickPayloadId(tAppIdData *flow)
     return APP_ID_NONE;
 }
 
+static inline SFGHASH* pickMultiPayloadList(tAppIdData *flow)
+{
+    if (!flow || flow->common.fsf_type.flow_type != APPID_SESSION_TYPE_NORMAL)
+        return NULL;
+    if (flow->multiPayloadList)
+        return flow->multiPayloadList;
+    return NULL;
+}
 static inline tAppId pickReferredPayloadId(tAppIdData *flow)
 {
     if (!flow || flow->common.fsf_type.flow_type != APPID_SESSION_TYPE_NORMAL)
@@ -357,6 +367,13 @@ static inline tAppId fwPickReferredPayloadAppId(tAppIdData *session)
     return appId;
 }
 
+static inline SFGHASH* fwPickMultiPayloadList(tAppIdData *session)
+{
+    SFGHASH* multiPayloadList = NULL;
+    multiPayloadList = pickMultiPayloadList(session);
+    return multiPayloadList;
+}
+
 static inline tAppIdData* appSharedGetData(const SFSnortPacket *p)
 {
     return _dpd.sessionAPI->get_application_data(p->stream_session, PP_APP_ID);
