@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -157,6 +157,7 @@ typedef int (*IncompatibleData)(tAppIdData *flow, const SFSnortPacket *pkt, int
                                 const tRNAServiceElement *svc_element, unsigned flow_data_index, const struct appIdConfig_ *pConfig, AppIdServiceIDState *id_state);
 typedef void (*AddHostInfo)(tAppIdData *flow, SERVICE_HOST_INFO_CODE code, const void *info);
 typedef void (*AddPayload)(tAppIdData *, tAppId);
+typedef void (*AddMultiPayload)(tAppIdData *, tAppId);
 typedef void (*AddUser)(tAppIdData *, const char *, tAppId, int);
 typedef void (*AddMisc)(tAppIdData *, tAppId);
 typedef void (*AddDnsQueryInfo)(tAppIdData *flow,
@@ -184,6 +185,7 @@ typedef struct _SERVICE_API
     IncompatibleData incompatible_data;
     AddHostInfo  add_host_info;
     AddPayload add_payload;
+    AddMultiPayload add_multipayload;
     AddUser add_user;
     AddServiceConsumeSubtype add_service_consume_subtype;
     AddMisc add_misc;
