@@ -87,6 +87,7 @@
 #define STATE_ID_MAX_VALID_COUNT             5
 #define STATE_ID_NEEDED_DUPE_DETRACT_COUNT   3
 
+
 static void *service_flowdata_get(tAppIdData *flow, unsigned service_id);
 static int service_flowdata_add(tAppIdData *flow, void *data, unsigned service_id, AppIdFreeFCN fcn);
 static void AppIdAddHostInfo(tAppIdData *flow, SERVICE_HOST_INFO_CODE code, const void *info);
@@ -305,10 +306,19 @@ tAppId getPortServiceId(uint8_t proto, uint16_t port, const tAppIdConfig *pConfi
 
     if (proto == IPPROTO_TCP)
         appId = pConfig->tcp_port_only[port];
-    else if (proto == IPPROTO_UDP)
-        appId = pConfig->udp_port_only[port];
     else
-        appId = pConfig->ip_protocol[proto];
+        appId = pConfig->udp_port_only[port];
+
+    checkSandboxDetection(appId);
+
+    return appId;
+}
+
+tAppId getProtocolServiceId(uint8_t proto, const tAppIdConfig *pConfig)
+{
+    tAppId appId;
+
+    appId = pConfig->ip_protocol[proto];
 
     checkSandboxDetection(appId);
 
@@ -1295,6 +1305,10 @@ static int AppIdServiceAddServiceEx(tAppIdData *flow, const SFSnortPacket *pkt,
         return SERVICE_EINVALID;
     }
 
+#ifdef DAQ_CAPA_VRF 
+    uint16_t asId; 
+#endif
+
     tAppId tmpServiceAppId = flow->serviceAppId;
     flow->serviceData = svc_element;
 
@@ -1331,11 +1345,17 @@ static int AppIdServiceAddServiceEx(tAppIdData *flow, const SFSnortPacket *pkt,
         {
             ip = GET_DST_IP(pkt);
             port = pkt->dst_port;
+#ifdef DAQ_CAPA_VRF
+            asId = pkt->pkt_header->address_space_id_dst;
+#endif
         }
         else
         {
             ip = GET_SRC_IP(pkt);
             port = pkt->src_port;
+#ifdef DAQ_CAPA_VRF
+            asId = pkt->pkt_header->address_space_id_src;
+#endif
         }
         if (flow->service_port)
             port = flow->service_port;
@@ -1346,22 +1366,45 @@ static int AppIdServiceAddServiceEx(tAppIdData *flow, const SFSnortPacket *pkt,
         {
             ip = GET_SRC_IP(pkt);
             port = pkt->src_port;
+#ifdef DAQ_CAPA_VRF
+            asId = pkt->pkt_header->address_space_id_src;
+#endif
         }
         else
         {
             ip = GET_DST_IP(pkt);
             port = pkt->dst_port;
+#ifdef DAQ_CAPA_VRF
+            asId = pkt->pkt_header->address_space_id_dst;
+#endif
         }
     }
     if (!id_state)
+    {
+#ifdef DAQ_CAPA_VRF 
+        id_state = AppIdGetServiceIDState(ip, flow->proto, port,
+                                          AppIdServiceDetectionLevel(flow),
+                                          asId);
+#else
         id_state = AppIdGetServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow));
+#endif
+    }    
+#ifdef DAQ_CAPA_VRF 
+    if (!id_state && !(id_state = AppIdAddServiceIDState(ip, flow->proto, port,
+                                                         AppIdServiceDetectionLevel(flow), 
+                                                         asId)))
+#else
     if (!id_state && !(id_state = AppIdAddServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow))))
+#endif
     {
         _dpd.errMsg("Add service failed to create state");
         return SERVICE_ENOMEM;
     }
     flow->service_ip = *ip;
     flow->service_port = port;
+#ifdef DAQ_CAPA_VRF
+    flow->serviceAsId = asId;
+#endif
     id_state->reset_time = 0;
     if (id_state->state != SERVICE_ID_VALID)
     {
@@ -1376,15 +1419,22 @@ static int AppIdServiceAddServiceEx(tAppIdData *flow, const SFSnortPacket *pkt,
 
 #ifdef SERVICE_DEBUG
 #if SERVICE_DEBUG_PORT
-if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
+    if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
-{
-    char ipstr[INET6_ADDRSTRLEN];
+    {
+        char ipstr[INET6_ADDRSTRLEN];
 
-    ipstr[0] = 0;
-    inet_ntop(sfaddr_family(&flow->service_ip), (void *)sfaddr_get_ptr(&flow->service_ip), ipstr, sizeof(ipstr));
-    fprintf(SF_DEBUG_FILE, "Valid: %s:%u:%u %p %d\n", ipstr, (unsigned)flow->proto, (unsigned)flow->service_port, id_state, (int)id_state->state);
-}
+        ipstr[0] = 0;
+        inet_ntop(sfaddr_family(&flow->service_ip), (void *)sfaddr_get_ptr(&flow->service_ip), ipstr, sizeof(ipstr));
+#ifdef DAQ_CAPA_VRF
+        fprintf(SF_DEBUG_FILE, "Valid: %s:%u:%u AS %u %p %d\n", ipstr,
+                (unsigned)flow->proto, (unsigned)flow->service_port,
+                asId, id_state, (int)id_state->state);
+#else
+        fprintf(SF_DEBUG_FILE, "Valid: %s:%u:%u %p %d\n", ipstr, (unsigned)flow->proto,
+                (unsigned)flow->service_port, id_state, (int)id_state->state);
+#endif
+    }
 #endif
 
     if (!id_state->valid_count)
@@ -1402,8 +1452,17 @@ if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #if SERVICE_DEBUG_PORT
     if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
+    {
+#ifdef DAQ_CAPA_VRF
+        fprintf(SF_DEBUG_FILE, "Service %d for protocol %u on port %u (%u->%u) AS %u is valid\n",
+                (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port,
+                (unsigned)pkt->src_port, (unsigned)pkt->dst_port, asId);
+#else
         fprintf(SF_DEBUG_FILE, "Service %d for protocol %u on port %u (%u->%u) is valid\n",
-                (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port, (unsigned)pkt->src_port, (unsigned)pkt->dst_port);
+                (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port,
+                (unsigned)pkt->src_port, (unsigned)pkt->dst_port);
+#endif
+    }
 #endif
     return SERVICE_SUCCESS;
 }
@@ -1420,8 +1479,17 @@ int AppIdServiceAddServiceSubtype(tAppIdData *flow, const SFSnortPacket *pkt, in
 #if SERVICE_DEBUG_PORT
         if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
+        {
+#ifdef DAQ_CAPA_VRF
+            fprintf(SF_DEBUG_FILE, "Service %d for protocol %u on port %u (%u->%u) AS %u is valid, but skipped\n",
+                    (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port,
+                    (unsigned)pkt->src_port, (unsigned)pkt->dst_port, flow->serviceAsId); 
+#else
             fprintf(SF_DEBUG_FILE, "Service %d for protocol %u on port %u (%u->%u) is valid, but skipped\n",
-                    (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port, (unsigned)pkt->src_port, (unsigned)pkt->dst_port);
+                    (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port,
+                    (unsigned)pkt->src_port, (unsigned)pkt->dst_port);
+#endif
+        }
 #endif
         return SERVICE_SUCCESS;
     }
@@ -1442,8 +1510,17 @@ int AppIdServiceAddService(tAppIdData *flow, const SFSnortPacket *pkt, int dir,
 #if SERVICE_DEBUG_PORT
         if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
+        {
+#ifdef DAQ_CAPA_VRF
+            fprintf(SF_DEBUG_FILE, "Service %d for protocol %u on port %u (%u->%u) AS %u is valid, but skipped\n",
+                    (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port,
+                    (unsigned)pkt->src_port, (unsigned)pkt->dst_port, flow->serviceAsId);
+#else
             fprintf(SF_DEBUG_FILE, "Service %d for protocol %u on port %u (%u->%u) is valid, but skipped\n",
-                    (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port, (unsigned)pkt->src_port, (unsigned)pkt->dst_port);
+                    (int)appId, (unsigned)flow->proto, (unsigned)flow->service_port,
+                    (unsigned)pkt->src_port, (unsigned)pkt->dst_port);
+#endif
+        }
 #endif
         return SERVICE_SUCCESS;
     }
@@ -1480,7 +1557,8 @@ int AppIdServiceAddService(tAppIdData *flow, const SFSnortPacket *pkt, int dir,
 }
 
 int AppIdServiceInProcess(tAppIdData *flow, const SFSnortPacket *pkt, int dir,
-                          const tRNAServiceElement *svc_element, AppIdServiceIDState *id_state)
+                          const tRNAServiceElement *svc_element,
+                          AppIdServiceIDState *id_state)
 {
     if (!flow || !pkt)
     {
@@ -1497,16 +1575,28 @@ int AppIdServiceInProcess(tAppIdData *flow, const SFSnortPacket *pkt, int dir,
 
         ip = GET_SRC_IP(pkt);
         flow->service_ip = *ip;
+#ifdef DAQ_CAPA_VRF
+        flow->serviceAsId = pkt->pkt_header->address_space_id_src;
+#endif
         if (!flow->service_port)
             flow->service_port = pkt->src_port;
     }
 #ifdef SERVICE_DEBUG
 #if SERVICE_DEBUG_PORT
-        if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
+    if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
-            fprintf(SF_DEBUG_FILE, "Service for protocol %u on port %u is in process (%u->%u), %p %s",
-                    (unsigned)flow->proto, (unsigned)flow->service_port, (unsigned)pkt->src_port, (unsigned)pkt->dst_port,
-                    svc_element->validate, svc_element->name ? :"UNKNOWN");
+    {
+#ifdef DAQ_CAPA_VRF
+        fprintf(SF_DEBUG_FILE, "Service for protocol %u on port %u is in process (%u->%u) AS %u, %p %s",
+                (unsigned)flow->proto, (unsigned)flow->service_port, (unsigned)pkt->src_port, 
+                (unsigned)pkt->dst_port, flow->serviceAsId, 
+                svc_element->validate, svc_element->name ? :"UNKNOWN");
+#else
+        fprintf(SF_DEBUG_FILE, "Service for protocol %u on port %u is in process (%u->%u), %p %s",
+                (unsigned)flow->proto, (unsigned)flow->service_port, (unsigned)pkt->src_port, (unsigned)pkt->dst_port,
+                svc_element->validate, svc_element->name ? :"UNKNOWN");
+#endif
+    }
 #endif
 
     return SERVICE_SUCCESS;
@@ -1560,13 +1650,30 @@ int AppIdServiceIncompatibleData(tAppIdData *flow, const SFSnortPacket *pkt, int
     sfaddr_t *ip;
     ip = GET_SRC_IP(pkt);
     port = flow->service_port ? flow->service_port : pkt->src_port;
+#ifdef DAQ_CAPA_VRF
+    uint16_t asId = pkt->pkt_header->address_space_id_src;
+#endif
 
     if (!id_state)
+    {    
+#ifdef DAQ_CAPA_VRF 
+        id_state = AppIdGetServiceIDState(ip, flow->proto, port,
+                                          AppIdServiceDetectionLevel(flow),
+                                          asId);
+#else
         id_state = AppIdGetServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow));
+#endif
+    }   
 
     if (!id_state)
     {
+#ifdef DAQ_CAPA_VRF 
+        if (!(id_state = AppIdAddServiceIDState(ip, flow->proto, port,
+                                                AppIdServiceDetectionLevel(flow), 
+                                                asId)))
+#else
         if (!(id_state = AppIdAddServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow))))
+#endif
         {
             _dpd.errMsg("Incompatible service failed to create state");
             return SERVICE_ENOMEM;
@@ -1579,16 +1686,29 @@ int AppIdServiceIncompatibleData(tAppIdData *flow, const SFSnortPacket *pkt, int
     }
     flow->service_ip = *ip;
     flow->service_port = port;
+#ifdef DAQ_CAPA_VRF
+    flow->serviceAsId = asId;
+#endif
 
 #ifdef SERVICE_DEBUG
 #if SERVICE_DEBUG_PORT
     if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
+    {
+#ifdef DAQ_CAPA_VRF
+       fprintf(SF_DEBUG_FILE, "service_IC: State %s for protocol %u on port %u (%u->%u) AS %u, count %u, %s\n",
+               serviceIdStateName[id_state->state], (unsigned)flow->proto, (unsigned)flow->service_port,
+               (unsigned)pkt->src_port, (unsigned)pkt->dst_port, asId, 
+               id_state->invalid_client_count,
+               (id_state->svc && id_state->svc->name) ? id_state->svc->name:"UNKNOWN");
+#else
         fprintf(SF_DEBUG_FILE, "service_IC: State %s for protocol %u on port %u (%u->%u), count %u, %s\n",
                 serviceIdStateName[id_state->state], (unsigned)flow->proto, (unsigned)flow->service_port,
                 (unsigned)pkt->src_port, (unsigned)pkt->dst_port, id_state->invalid_client_count,
                 (id_state->svc && id_state->svc->name) ? id_state->svc->name:"UNKNOWN");
 #endif
+    }
+#endif
 
 #ifdef SERVICE_DEBUG
 #if SERVICE_DEBUG_PORT
@@ -1652,13 +1772,30 @@ int AppIdServiceFailService(tAppIdData* flow, const SFSnortPacket *pkt, int dir,
     port = flow->service_port ? flow->service_port : pkt->src_port;
     flow->service_ip = *ip;
     flow->service_port = port;
+#ifdef DAQ_CAPA_VRF
+    flow->serviceAsId = pkt->pkt_header->address_space_id_src;
+#endif
 
     if (!id_state)
-        id_state = AppIdGetServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow));
+    {    
+#ifdef DAQ_CAPA_VRF 
+       id_state = AppIdGetServiceIDState(ip, flow->proto, port,
+                                         AppIdServiceDetectionLevel(flow),
+                                         flow->serviceAsId);
+#else
+       id_state = AppIdGetServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow));
+#endif
+    }   
 
     if (!id_state)
     {
+#ifdef DAQ_CAPA_VRF 
+        if (!(id_state = AppIdAddServiceIDState(ip, flow->proto, port,
+                                                AppIdServiceDetectionLevel(flow),
+                                                flow->serviceAsId)))
+#else
         if (!(id_state = AppIdAddServiceIDState(ip, flow->proto, port, AppIdServiceDetectionLevel(flow))))
+#endif
         {
             _dpd.errMsg("Fail service failed to create state");
             return SERVICE_ENOMEM;
@@ -1671,11 +1808,21 @@ int AppIdServiceFailService(tAppIdData* flow, const SFSnortPacket *pkt, int dir,
 #if SERVICE_DEBUG_PORT
     if (pkt->dst_port == SERVICE_DEBUG_PORT || pkt->src_port == SERVICE_DEBUG_PORT)
 #endif
+    {
+#ifdef DAQ_CAPA_VRF
+       fprintf(SF_DEBUG_FILE, "service_fail: State %s for protocol %u on port %u (%u->%u) AS %u, count %u, valid count %u, currSvc %s\n",
+               serviceIdStateName[id_state->state], (unsigned)flow->proto, (unsigned)flow->service_port,
+               (unsigned)pkt->src_port, (unsigned)pkt->dst_port, flow->serviceAsId, 
+               id_state->invalid_client_count, id_state->valid_count,
+               (svc_element && svc_element->name) ? svc_element->name:"UNKNOWN");
+#else
         fprintf(SF_DEBUG_FILE, "service_fail: State %s for protocol %u on port %u (%u->%u), count %u, valid count %u, currSvc %s\n",
                 serviceIdStateName[id_state->state], (unsigned)flow->proto, (unsigned)flow->service_port,
                 (unsigned)pkt->src_port, (unsigned)pkt->dst_port, id_state->invalid_client_count, id_state->valid_count,
                 (svc_element && svc_element->name) ? svc_element->name:"UNKNOWN");
 #endif
+    }
+#endif
 
 #ifdef SERVICE_DEBUG
 #if SERVICE_DEBUG_PORT
@@ -1708,6 +1855,7 @@ static void HandleFailure(tAppIdData *flowp,
 {
     if (!id_state)
         return;
+
     /* If we had a valid detector, check for too many fails.  If so, start
      * search sequence again. */
     if (id_state->state == SERVICE_ID_VALID)
@@ -1729,6 +1877,9 @@ static void HandleFailure(tAppIdData *flowp,
                 id_state->valid_count--;
                 id_state->last_invalid_client = *client_ip;
                 id_state->invalid_client_count = 0;
+#ifdef DAQ_CAPA_VRF
+                id_state->asId = flowp->serviceAsId;
+#endif
             }
         }
         /* Just a plain old fail.  If too many of these happen, start
@@ -1737,8 +1888,13 @@ static void HandleFailure(tAppIdData *flowp,
         {
             if (sfip_fast_eq6(&id_state->last_detract, client_ip))
                 id_state->detract_count++;
-            else
+            else 
+            {
                 id_state->last_detract = *client_ip;
+#ifdef DAQ_CAPA_VRF
+                id_state->asId = flowp->serviceAsId;
+#endif
+            }
 
             if (id_state->detract_count >= STATE_ID_NEEDED_DUPE_DETRACT_COUNT)
             {
@@ -1783,7 +1939,16 @@ void FailInProcessService(tAppIdData *flowp, const tAppIdConfig *pConfig)
     if (getAppIdFlag(flowp, APPID_SESSION_SERVICE_DETECTED|APPID_SESSION_UDP_REVERSED))
         return;
 
-    id_state = AppIdGetServiceIDState(&flowp->service_ip, flowp->proto, flowp->service_port, AppIdServiceDetectionLevel(flowp));
+#ifdef DAQ_CAPA_VRF 
+    id_state = AppIdGetServiceIDState(&flowp->service_ip, flowp->proto, 
+                                      flowp->service_port, 
+                                      AppIdServiceDetectionLevel(flowp),
+                                      flowp->serviceAsId);
+#else
+    id_state = AppIdGetServiceIDState(&flowp->service_ip, flowp->proto,
+                                      flowp->service_port, 
+                                      AppIdServiceDetectionLevel(flowp));
+#endif
 
 #ifdef SERVICE_DEBUG
 #if SERVICE_DEBUG_PORT
@@ -1873,7 +2038,13 @@ static const tRNAServiceElement * AppIdGetNextService(const SFSnortPacket *p,
                 const tRNAServiceElement * reverse_service = NULL;
                 sfaddr_t * reverse_ip = GET_SRC_IP(p);
                 rnaData->tried_reverse_service = true;
+#ifdef DAQ_CAPA_VRF 
+                if((reverse_id_state = AppIdGetServiceIDState(reverse_ip, proto, p->src_port, 
+                                                              AppIdServiceDetectionLevel(rnaData), 
+                                                              p->pkt_header->address_space_id_src)))
+#else
                 if ((reverse_id_state = AppIdGetServiceIDState(reverse_ip, proto, p->src_port, AppIdServiceDetectionLevel(rnaData))))
+#endif
                 {
                     reverse_service = reverse_id_state->svc;
                 }
@@ -1923,12 +2094,18 @@ int AppIdDiscoverService(SFSnortPacket *p, const APPID_SESSION_DIRECTION dir, tA
     bool appIdFailServiceDone = false;
     sfaddr_t *ip;
     uint16_t port;
+#ifdef DAQ_CAPA_VRF
+    uint16_t asId;
+#endif
 
     /* Get packet info. */
     if (sfaddr_is_set(&rnaData->service_ip))
     {
         ip   = &rnaData->service_ip;
         port = rnaData->service_port;
+#ifdef DAQ_CAPA_VRF
+        asId = rnaData->serviceAsId;
+#endif
     }
     else
     {
@@ -1936,14 +2113,23 @@ int AppIdDiscoverService(SFSnortPacket *p, const APPID_SESSION_DIRECTION dir, tA
         {
             ip   = GET_SRC_IP(p);
             port = p->src_port;
+#ifdef DAQ_CAPA_VRF
+            asId = p->pkt_header->address_space_id_src;
+#endif
         }
         else
         {
             ip   = GET_DST_IP(p);
             port = p->dst_port;
+#ifdef DAQ_CAPA_VRF
+            asId = p->pkt_header->address_space_id_dst;
+#endif
         }
         rnaData->service_ip = *ip;
         rnaData->service_port = port;
+#ifdef DAQ_CAPA_VRF
+        rnaData->serviceAsId = asId;
+#endif
     }
 
     /* When a new flow was initialized, rnaData->search_state = 0 (SERVICE_ID_START) */
@@ -1951,12 +2137,22 @@ int AppIdDiscoverService(SFSnortPacket *p, const APPID_SESSION_DIRECTION dir, tA
     {
         rnaData->search_state = SERVICE_ID_PORT; // Also ensures this block to be executed once per flow
         /* Get host tracker state. */
+#ifdef DAQ_CAPA_VRF 
+        id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData),
+                                          asId);
+#else
         id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData));
+#endif        
         /* Create it if it doesn't exist yet. */
         if (id_state == NULL)
         {
             /* New one is memset to 0, hence id_state->state = 0 (SERVICE_ID_NEW) */
+#ifdef DAQ_CAPA_VRF 
+            if (!(id_state = AppIdAddServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData),
+                                                    asId)))
+#else 
             if (!(id_state = AppIdAddServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData))))
+#endif
             {
                 _dpd.errMsg("Discover service failed to create state");
                 return SERVICE_ENOMEM;
@@ -2089,7 +2285,14 @@ int AppIdDiscoverService(SFSnortPacket *p, const APPID_SESSION_DIRECTION dir, tA
                  && (rnaData->search_state == SERVICE_ID_PENDING) )
             {
                 if (!id_state)
+                {    
+#ifdef DAQ_CAPA_VRF 
+                    id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData),
+                                                      asId);
+#else
                     id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData));
+#endif
+                }                    
                 AppIdServiceFailService(rnaData, p, dir, NULL, APPID_SESSION_DATA_NONE, pConfig, id_state);
                 appIdFailServiceDone = true;
                 ret = SERVICE_NOMATCH;
@@ -2105,7 +2308,14 @@ int AppIdDiscoverService(SFSnortPacket *p, const APPID_SESSION_DIRECTION dir, tA
         if (!appIdFailServiceDone)
         {
             if (!id_state)
+            {
+#ifdef DAQ_CAPA_VRF 
+                id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData),
+                                                  asId);
+#else
                 id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData));
+#endif
+            }
             AppIdServiceFailService(rnaData, p, dir, NULL, APPID_SESSION_DATA_NONE, pConfig, id_state);
             appIdFailServiceDone = true;
             ret = SERVICE_NOMATCH;
@@ -2125,8 +2335,14 @@ int AppIdDiscoverService(SFSnortPacket *p, const APPID_SESSION_DIRECTION dir, tA
         if (rnaData->got_incompatible_services)
         {
             if (!id_state)
+            {
+#ifdef DAQ_CAPA_VRF 
+                id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData),
+                                                  asId);
+#else
                 id_state = AppIdGetServiceIDState(ip, proto, port, AppIdServiceDetectionLevel(rnaData));
-
+#endif
+            }
             if (id_state && id_state->invalid_client_count < STATE_ID_INVALID_CLIENT_THRESHOLD)
             {
                 if (sfip_fast_equals_raw(&id_state->last_invalid_client, tmp_ip))
