@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -43,8 +43,11 @@ typedef enum
     REXEC_STATE_COMMAND,
     REXEC_STATE_REPLY,
     REXEC_STATE_DONE,
+    REXEC_STATE_BAIL,
     REXEC_STATE_STDERR_CONNECT_SYN,
-    REXEC_STATE_STDERR_CONNECT_SYN_ACK
+    REXEC_STATE_STDERR_CONNECT_SYN_ACK,
+    REXEC_STATE_STDERR_WAIT,
+    REXEC_STATE_STDERR_DONE
 } REXECState;
 
 
@@ -120,6 +123,19 @@ static void rexec_free_state(void *data)
     }
 }
 
+/* Both the control & data sessions need to go to success else we bail.
+   Let the control/data session know that we're bailing */
+static void rexec_bail(ServiceREXECData *rd, tAppIdData *flowp)
+{
+    clearAppIdFlag(flowp, APPID_SESSION_REXEC_STDERR);
+
+    if (!rd) return;
+
+    rd->state = REXEC_STATE_BAIL;
+    if (rd->child) rd->child->state = REXEC_STATE_BAIL;
+    if (rd->parent) rd->parent->state = REXEC_STATE_BAIL;
+}
+
 static int rexec_validate(ServiceValidationArgs* args)
 {
     ServiceREXECData *rd;
@@ -132,6 +148,8 @@ static int rexec_validate(ServiceValidationArgs* args)
     SFSnortPacket *pkt = args->pkt; 
     const int dir = args->dir;
     uint16_t size = args->size;
+    bool app_id_debug_session_flag = args->app_id_debug_session_flag;
+    char* app_id_debug_session = args->app_id_debug_session;
 
     rd = rexec_service_mod.api->data_get(flowp, rexec_service_mod.flow_data_index);
     if (!rd)
@@ -149,6 +167,9 @@ static int rexec_validate(ServiceValidationArgs* args)
         rd->state = REXEC_STATE_PORT;
     }
 
+    if (app_id_debug_session_flag)
+        _dpd.logMsg("AppIdDbg %s rexec state %d\n", app_id_debug_session, rd->state);
+
     switch (rd->state)
     {
     case REXEC_STATE_PORT:
@@ -182,6 +203,7 @@ static int rexec_validate(ServiceValidationArgs* args)
 
                 if (rexec_service_mod.api->data_add(pf, tmp_rd, rexec_service_mod.flow_data_index, &rexec_free_state))
                 {
+                    pf->rnaServiceState = RNA_STATE_FINISHED;
                     free(tmp_rd);
                     return SERVICE_ENOMEM;
                 }
@@ -192,8 +214,6 @@ static int rexec_validate(ServiceValidationArgs* args)
                     tmp_rd->parent = NULL;
                     return SERVICE_ENULL;
                 }
-                rd->child = tmp_rd;
-                rd->state = REXEC_STATE_SERVER_CONNECT;
                 pf->rnaServiceState = RNA_STATE_STATEFUL;
                 pf->scan_flags |= SCAN_HOST_PORT_FLAG;
                 PopulateExpectedFlow(flowp, pf,
@@ -204,10 +224,13 @@ static int rexec_validate(ServiceValidationArgs* args)
                                      APPID_SESSION_PORT_SERVICE_DONE,
                                      APP_ID_FROM_RESPONDER);
                 pf->rnaServiceState = RNA_STATE_STATEFUL;
+                rd->child = tmp_rd;
+                rd->state = REXEC_STATE_SERVER_CONNECT;
+                setAppIdFlag(flowp, APPID_SESSION_CONTINUE);
+                goto success;
             }
             else
                 rd->state = REXEC_STATE_USERNAME;
-
         }
         else rd->state = REXEC_STATE_USERNAME;
         break;
@@ -266,8 +289,15 @@ static int rexec_validate(ServiceValidationArgs* args)
         if (!size) goto inprocess;
         if (dir != APP_ID_FROM_RESPONDER) goto fail;
         if (size != 1) goto fail;
+        if (rd->child)
+        {
+            if(rd->child->state == REXEC_STATE_STDERR_WAIT)
+                rd->child->state = REXEC_STATE_STDERR_DONE;
+            else
+                goto fail;
+        }
+        clearAppIdFlag(flowp, APPID_SESSION_CONTINUE);
         goto success;
-        break;
     case REXEC_STATE_STDERR_CONNECT_SYN:
         rd->state = REXEC_STATE_STDERR_CONNECT_SYN_ACK;
         break;
@@ -275,46 +305,43 @@ static int rexec_validate(ServiceValidationArgs* args)
         if (rd->parent && rd->parent->state == REXEC_STATE_SERVER_CONNECT)
         {
             rd->parent->state = REXEC_STATE_USERNAME;
-            clearAppIdFlag(flowp, APPID_SESSION_REXEC_STDERR | APPID_SESSION_CONTINUE);
-            goto success;
+            rd->state = REXEC_STATE_STDERR_WAIT;
+            break;
         }
+        goto bail;
+    case REXEC_STATE_STDERR_WAIT:
+        /* The only valid way out of this state is for the parent flow to change it. */
+        if (!size) break;
+        goto bail;
+    case REXEC_STATE_STDERR_DONE:
+        clearAppIdFlag(flowp, APPID_SESSION_REXEC_STDERR | APPID_SESSION_CONTINUE);
+        goto success;
+    case REXEC_STATE_BAIL:
     default:
         goto bail;
     }
 
 inprocess:
-    if (!getAppIdFlag(flowp, APPID_SESSION_SERVICE_DETECTED))
-    {
-        rexec_service_mod.api->service_inprocess(flowp, pkt, dir, &svc_element, NULL);
-    }
+    rexec_service_mod.api->service_inprocess(flowp, pkt, dir, &svc_element, NULL);
     return SERVICE_INPROCESS;
 
 success:
-    if (!getAppIdFlag(flowp, APPID_SESSION_SERVICE_DETECTED))
-    {
-        rexec_service_mod.api->add_service(flowp, pkt, dir, &svc_element,
-                                           APP_ID_EXEC, NULL, NULL, NULL, NULL);
-    }
+    rexec_service_mod.api->add_service(flowp, pkt, dir, &svc_element,
+                                       APP_ID_EXEC, NULL, NULL, NULL, NULL);
     return SERVICE_SUCCESS;
 
 bail:
-    if (!getAppIdFlag(flowp, APPID_SESSION_SERVICE_DETECTED))
-    {
-        rexec_service_mod.api->incompatible_data(flowp, pkt, dir, &svc_element,
-                                                 rexec_service_mod.flow_data_index,
-                                                 args->pConfig, NULL);
-    }
-    clearAppIdFlag(flowp, APPID_SESSION_CONTINUE);
+    rexec_bail(rd, flowp);
+    rexec_service_mod.api->incompatible_data(flowp, pkt, dir, &svc_element,
+                                             rexec_service_mod.flow_data_index,
+                                             args->pConfig, NULL);
     return SERVICE_NOT_COMPATIBLE;
 
 fail:
-    if (!getAppIdFlag(flowp, APPID_SESSION_SERVICE_DETECTED))
-    {
-        rexec_service_mod.api->fail_service(flowp, pkt, dir, &svc_element,
-                                            rexec_service_mod.flow_data_index,
-                                            args->pConfig, NULL);
-    }
-    clearAppIdFlag(flowp, APPID_SESSION_CONTINUE);
+    rexec_bail(rd, flowp);
+    rexec_service_mod.api->fail_service(flowp, pkt, dir, &svc_element,
+                                        rexec_service_mod.flow_data_index,
+                                        args->pConfig, NULL);
     return SERVICE_NOMATCH;
 }
 
