@@ -403,7 +403,8 @@ static int validate_packet(const uint8_t *data, uint16_t size, int dir,
                         dip = GET_DST_IP(pkt);
                         sip = GET_SRC_IP(pkt);
                         tmp = ntohl(pmr->port);
-                        pf = rpc_service_mod.api->flow_new(flowp, pkt, dip, 0, sip, (uint16_t)tmp, (uint8_t)ntohl(rd->proto), app_id, 0);
+                        pf = rpc_service_mod.api->flow_new(flowp, pkt, dip, 0, sip, (uint16_t)tmp, (uint8_t)ntohl(rd->proto), app_id, 
+                                                           APPID_EARLY_SESSION_FLAG_FW_RULE);
                         if (pf)
                         {
                             rpc_service_mod.api->data_add_id(pf, (uint16_t)tmp,
