@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -43,8 +43,11 @@ typedef enum
     RSHELL_STATE_COMMAND,
     RSHELL_STATE_REPLY,
     RSHELL_STATE_DONE,
+    RSHELL_STATE_BAIL,
     RSHELL_STATE_STDERR_CONNECT_SYN,
-    RSHELL_STATE_STDERR_CONNECT_SYN_ACK
+    RSHELL_STATE_STDERR_CONNECT_SYN_ACK,
+    RSHELL_STATE_STDERR_WAIT,
+    RSHELL_STATE_STDERR_DONE
 } RSHELLState;
 
 typedef struct _SERVICE_RSHELL_DATA
@@ -119,6 +122,19 @@ static void rshell_free_state(void *data)
     }
 }
 
+/* Both the control & data sessions need to go to success else we bail.
+   Let the control/data session know that we're bailing */
+static void rshell_bail(ServiceRSHELLData *rd, tAppIdData *flowp)
+{
+    clearAppIdFlag(flowp, APPID_SESSION_REXEC_STDERR);
+
+    if (!rd) return;
+
+    rd->state = RSHELL_STATE_BAIL;
+    if (rd->child) rd->child->state = RSHELL_STATE_BAIL;
+    if (rd->parent) rd->parent->state = RSHELL_STATE_BAIL;
+}
+
 static int rshell_validate(ServiceValidationArgs* args)
 {
     ServiceRSHELLData *rd = NULL;
@@ -172,17 +188,17 @@ static int rshell_validate(ServiceValidationArgs* args)
             sfaddr_t *sip;
             sfaddr_t *dip;
 
-            tmp_rd = calloc(1, sizeof(ServiceRSHELLData));
-            if (tmp_rd == NULL)
-                return SERVICE_ENOMEM;
-            tmp_rd->state = RSHELL_STATE_STDERR_CONNECT_SYN;
-            tmp_rd->parent = rd;
             dip = GET_DST_IP(pkt);
             sip = GET_SRC_IP(pkt);
             pf = rshell_service_mod.api->flow_new(flowp, pkt, dip, 0, sip, (uint16_t)port, IPPROTO_TCP, app_id, APPID_EARLY_SESSION_FLAG_FW_RULE);
             if (pf)
             {
-                pf->rnaClientState = RNA_STATE_FINISHED;
+                tmp_rd = calloc(1, sizeof(ServiceRSHELLData));
+                if (tmp_rd == NULL)
+                    return SERVICE_ENOMEM;
+                tmp_rd->state = RSHELL_STATE_STDERR_CONNECT_SYN;
+                tmp_rd->parent = rd;
+
                 if (rshell_service_mod.api->data_add(pf, tmp_rd, rshell_service_mod.flow_data_index, &rshell_free_state))
                 {
                     pf->rnaServiceState = RNA_STATE_FINISHED;
@@ -196,6 +212,7 @@ static int rshell_validate(ServiceValidationArgs* args)
                     tmp_rd->parent = NULL;
                     return SERVICE_ENOMEM;
                 }
+                pf->rnaClientState = RNA_STATE_FINISHED;
                 pf->scan_flags |= SCAN_HOST_PORT_FLAG;
                 PopulateExpectedFlow(flowp, pf,
                                      APPID_SESSION_CONTINUE |
@@ -205,14 +222,13 @@ static int rshell_validate(ServiceValidationArgs* args)
                                      APPID_SESSION_PORT_SERVICE_DONE, 
                                      APP_ID_FROM_RESPONDER);
                 pf->rnaServiceState = RNA_STATE_STATEFUL;
+                rd->child = tmp_rd;
+                rd->state = RSHELL_STATE_SERVER_CONNECT;
+                setAppIdFlag(flowp, APPID_SESSION_CONTINUE);
+                goto success; 
             }
             else
-            {
-                free(tmp_rd);
-                return SERVICE_ENOMEM;
-            }
-            rd->child = tmp_rd;
-            rd->state = RSHELL_STATE_SERVER_CONNECT;
+                rd->state = RSHELL_STATE_USERNAME;
         }
         else rd->state = RSHELL_STATE_USERNAME;
         break;
@@ -270,19 +286,28 @@ static int rshell_validate(ServiceValidationArgs* args)
     case RSHELL_STATE_REPLY:
         if (!size) goto inprocess;
         if (dir != APP_ID_FROM_RESPONDER) goto fail;
-        if (size == 1) goto success;
-        if (*data == 0x01)
+        if (size == 1 || *data == 0x01)
         {
-            data++;
-            size--;
-            for (i=0; i<size && data[i]; i++)
+            if (size != 1)
             {
-                if (!isprint(data[i]) && data[i] != 0x0A && data[i] != 0x0D && data[i] != 0x09) goto fail;
+                data++;
+                size--;
+                for (i=0; i<size && data[i]; i++)
+                {
+                    if (!isprint(data[i]) && data[i] != 0x0A && data[i] != 0x0D && data[i] != 0x09) goto fail;
+                }
             }
+            if (rd->child)
+            {
+                if (rd->child->state == RSHELL_STATE_STDERR_WAIT)
+                    rd->child->state = RSHELL_STATE_STDERR_DONE;
+                else
+                    goto fail;
+            }
+            clearAppIdFlag(flowp, APPID_SESSION_CONTINUE);
             goto success;
         }
         goto fail;
-        break;
     case RSHELL_STATE_STDERR_CONNECT_SYN:
         rd->state = RSHELL_STATE_STDERR_CONNECT_SYN_ACK;
         break;
@@ -290,9 +315,18 @@ static int rshell_validate(ServiceValidationArgs* args)
         if (rd->parent && rd->parent->state == RSHELL_STATE_SERVER_CONNECT)
         {
             rd->parent->state = RSHELL_STATE_USERNAME;
-            clearAppIdFlag(flowp, APPID_SESSION_REXEC_STDERR | APPID_SESSION_CONTINUE);
-            goto success;
+            rd->state = RSHELL_STATE_STDERR_WAIT;
+            break;
         }
+        goto bail;
+    case RSHELL_STATE_STDERR_WAIT:
+        /* The only valid way out of this state is for the parent flow to change it. */
+        if (!size) break;
+        goto bail;
+    case RSHELL_STATE_STDERR_DONE:
+        clearAppIdFlag(flowp, APPID_SESSION_REXEC_STDERR | APPID_SESSION_CONTINUE);
+        goto success;
+    case RSHELL_STATE_BAIL:
     default:
         goto bail;
     }
@@ -307,11 +341,13 @@ success:
     return SERVICE_SUCCESS;
 
 bail:
+    rshell_bail(rd, flowp);
     rshell_service_mod.api->incompatible_data(flowp, pkt, dir, &svc_element,
                                               rshell_service_mod.flow_data_index, args->pConfig, NULL);
     return SERVICE_NOT_COMPATIBLE;
 
 fail:
+    rshell_bail(rd, flowp);
     rshell_service_mod.api->fail_service(flowp, pkt, dir, &svc_element,
                                          rshell_service_mod.flow_data_index, args->pConfig, NULL);
     return SERVICE_NOMATCH;
