@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -415,7 +415,13 @@ void parse_client_initiation(const uint8_t *data, uint16_t size, ServiceSSLData
                                  + offsetof(ServiceSSLV3ExtensionServerName, string_length)
                                  + sizeof(ext->string_length);
             ss->host_name = malloc(len + 1);    /* Plus NULL term. */
-            if (ss->host_name)
+            if (!ss->host_name)
+            {
+                _dpd.errMsg("parse_client_initiation: "
+                        "Could not allocate memory for host name in ServiceSSLData\n");
+                return;
+            }
+            else
             {
                 memcpy(ss->host_name, str, len);
                 ss->host_name[len] = '\0';
