@@ -46,6 +46,7 @@ STATIC SFXHASH *serviceStateCache6;
 
 #define SERVICE_STATE_CACHE_ROWS    65536
 
+
 bool AppIdServiceStateReloadAdjust(bool idle, unsigned long memcap)
 {
     unsigned max_work = idle ? 512 : 8;
@@ -166,7 +167,12 @@ void AppIdServiceStateCleanup(void)
     }
 }
 
+#ifdef DAQ_CAPA_VRF
+void AppIdRemoveServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint32_t level,
+                               uint16_t asId)
+#else
 void AppIdRemoveServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint32_t level)
+#endif
 {
     AppIdServiceStateKey k;
     SFXHASH *cache;
@@ -177,6 +183,9 @@ void AppIdRemoveServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint
         k.key6.port = port;
         memcpy(k.key6.ip, sfaddr_get_ip6_ptr(ip), sizeof(k.key6.ip));
         k.key6.level = level;
+#ifdef DAQ_CAPA_VRF
+        k.key6.asId = asId;
+#endif
         cache = serviceStateCache6;
     }
     else
@@ -185,6 +194,9 @@ void AppIdRemoveServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint
         k.key4.port = port;
         k.key4.ip = sfaddr_get_ip4_value(ip);
         k.key4.level = level;
+#ifdef DAQ_CAPA_VRF
+        k.key4.asId = asId;
+#endif
         cache = serviceStateCache4;
     }
     if (sfxhash_remove(cache, &k) != SFXHASH_OK)
@@ -193,11 +205,21 @@ void AppIdRemoveServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint
 
         ipstr[0] = 0;
         inet_ntop(sfaddr_family(ip), (void *)sfaddr_get_ptr(ip), ipstr, sizeof(ipstr));
+#ifdef DAQ_CAPA_VRF
+        _dpd.errMsg("Failed to remove from hash: %s:%u:%u:%u\n", ipstr, (unsigned)proto,
+                     (unsigned)port, asId);
+#else
         _dpd.errMsg("Failed to remove from hash: %s:%u:%u\n",ipstr, (unsigned)proto, (unsigned)port);
+#endif
     }
 }
 
+#ifdef DAQ_CAPA_VRF
+AppIdServiceIDState* AppIdGetServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port,
+                                            uint32_t level, uint16_t asId)
+#else
 AppIdServiceIDState* AppIdGetServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint32_t level)
+#endif
 {
     AppIdServiceStateKey k;
     SFXHASH *cache;
@@ -209,6 +231,9 @@ AppIdServiceIDState* AppIdGetServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
         k.key6.port = port;
         memcpy(k.key6.ip, sfaddr_get_ip6_ptr(ip), sizeof(k.key6.ip));
         k.key6.level = level;
+#ifdef DAQ_CAPA_VRF        
+        k.key6.asId = asId;
+#endif
         cache = serviceStateCache6;
     }
     else
@@ -217,6 +242,9 @@ AppIdServiceIDState* AppIdGetServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
         k.key4.port = port;
         k.key4.ip = sfaddr_get_ip4_value(ip);
         k.key4.level = level;
+#ifdef DAQ_CAPA_VRF
+        k.key4.asId = asId;
+#endif
         cache = serviceStateCache4;
     }
     ss = sfxhash_find(cache, &k);
@@ -226,7 +254,14 @@ AppIdServiceIDState* AppIdGetServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
 
     ipstr[0] = 0;
     inet_ntop(sfaddr_family(ip), (void *)sfaddr_get_ptr(ip), ipstr, sizeof(ipstr));
-    _dpd.logMsg("ServiceState: Read from hash: %s:%u:%u:%u %p %u %p\n",ipstr, (unsigned)proto, (unsigned)port, level, ss, ss ? ss->state:0, ss ? ss->svc:NULL);
+#ifdef DAQ_CAPA_VRF    
+    _dpd.logMsg("ServiceState: Read from hash: %s:%u:%u:%u:%u %p %u %p\n",
+                 ipstr, (unsigned)proto, (unsigned)port, level, asId,
+                 ss, ss ? ss->state:0, ss ? ss->svc:NULL);
+#else    
+    _dpd.logMsg("ServiceState: Read from hash: %s:%u:%u:%u %p %u %p\n",ipstr,
+            (unsigned)proto, (unsigned)port, level, ss, ss ? ss->state:0, ss ? ss->svc:NULL);
+#endif
 #endif
 
     if (ss && ss->svc && !ss->svc->ref_count)
@@ -238,7 +273,12 @@ AppIdServiceIDState* AppIdGetServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
     return ss;
 }
 
+#ifdef DAQ_CAPA_VRF
+AppIdServiceIDState* AppIdAddServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, 
+                                            uint32_t level,  uint16_t asId)
+#else
 AppIdServiceIDState* AppIdAddServiceIDState(sfaddr_t *ip, uint16_t proto, uint16_t port, uint32_t level)
+#endif
 {
     AppIdServiceStateKey k;
     AppIdServiceIDState *ss = NULL;
@@ -251,6 +291,9 @@ AppIdServiceIDState* AppIdAddServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
         k.key6.port = port;
         memcpy(k.key6.ip, sfaddr_get_ip6_ptr(ip), sizeof(k.key6.ip));
         k.key6.level = level;
+#ifdef DAQ_CAPA_VRF
+        k.key6.asId = asId;
+#endif
         cache = serviceStateCache6;
     }
     else
@@ -259,6 +302,9 @@ AppIdServiceIDState* AppIdAddServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
         k.key4.port = port;
         k.key4.ip = sfaddr_get_ip4_value(ip);
         k.key4.level = level;
+#ifdef DAQ_CAPA_VRF
+        k.key4.asId = asId;
+#endif
         cache = serviceStateCache4;
     }
 #ifdef DEBUG_SERVICE_STATE
@@ -269,11 +315,23 @@ AppIdServiceIDState* AppIdAddServiceIDState(sfaddr_t *ip, uint16_t proto, uint16
     {
         ipstr[0] = 0;
         inet_ntop(sfaddr_family(ip), (void *)sfaddr_get_ptr(ip), ipstr, sizeof(ipstr));
-        _dpd.errMsg("ServiceState: Failed to add to hash: %s:%u:%u:%u\n",ipstr, (unsigned)proto, (unsigned)port, level);
+#ifdef DAQ_CAPA_VRF
+        _dpd.errMsg("ServiceState: Failed to add to hash: %s:%u:%u:%u:%u\n",ipstr, 
+                     (unsigned)proto, (unsigned)port, level, asId);
+#else
+        _dpd.errMsg("ServiceState: Failed to add to hash: %s:%u:%u:%u\n",ipstr, 
+                (unsigned)proto, (unsigned)port, level);
+#endif
         return NULL;
     }
 #ifdef DEBUG_SERVICE_STATE
-    _dpd.logMsg("ServiceState: Added to hash: %s:%u:%u:%u %p\n",ipstr, (unsigned)proto, (unsigned)port, level, ss);
+#ifdef DAQ_CAPA_VRF
+    _dpd.logMsg("ServiceState: Added to hash: %s:%u:%u:%u:%u %p\n", ipstr,
+                 (unsigned)proto, (unsigned)port, level, ss, asId);
+#else
+    _dpd.logMsg("ServiceState: Added to hash: %s:%u:%u:%u %p\n", ipstr,
+            (unsigned)proto, (unsigned)port, level, ss);
+#endif
 #endif
     if (ss)
         memset(ss, 0, sizeof(*ss));
