@@ -142,7 +142,14 @@ void ThirdPartyAppIDInit(struct AppidStaticConfig *appidStaticConfig)
         thirdpartyConfig.http_upgrade_reporting_enabled = 1;
     else
         thirdpartyConfig.http_upgrade_reporting_enabled = 0;
-    thirdpartyConfig.appid_tp_dir[0] = '\0';    // use default path
+
+    if (appidStaticConfig->tp_config_path)
+    {
+        strncpy(thirdpartyConfig.tp_config_path, appidStaticConfig->tp_config_path, TP_PATH_MAX);
+        thirdpartyConfig.tp_config_path[TP_PATH_MAX-1] = '\0';
+    }
+    else
+        thirdpartyConfig.tp_config_path[0] = '\0'; // use default path
 
     thirdpartyUtils.logMsg           = _dpd.logMsg;
     thirdpartyUtils.getSnortInstance = _dpd.getSnortInstance;
