@@ -559,8 +559,6 @@ static void DCE2_Smb2CloseCmd(DCE2_SmbSsnData *ssd, const Smb2Hdr *smb_hdr,
         _dpd.fileAPI->file_cache_update_entry(fileCache, (void *)ssd->sd.wire_pkt,
                 fileId_persistent, NULL,  0, ssd->ftracker.tracker.file.file_size, false, false);
         DCE2_Smb2ProcessFileData(ssd, NULL, 0, upload);
-        _dpd.fileAPI->file_event_log_dump(fileCache, (void *)ssd->sd.wire_pkt,
-                ssd->ftracker.fid_v2);
     }
 }
 
