@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2011-2013 Sourcefire, Inc.
  *
  * Author: Ryan Jordan
@@ -272,6 +272,11 @@ static void DNP3InitializeMempool(tSfPolicyUserContextId context_id)
             max_sessions = default_config->memcap / sizeof(dnp3_session_data_t);
 
             dnp3_mempool = (MemPool *)malloc(sizeof(MemPool));
+            if (!dnp3_mempool)
+            {
+                DynamicPreprocessorFatalMessage("DNP3InitializeMempool: "
+                        "Unable to allocate memory for dnp3 mempool\n");
+            }
             //mempool is set to 0 in init
             if (mempool_init(dnp3_mempool, max_sessions, sizeof(dnp3_session_data_t)))
             {
