@@ -88,7 +88,7 @@ static FileInfo* file_agent_get_file(void);
 static FileInfo *file_agent_finish_file(void);
 static File_Verdict file_agent_type_callback(void*, void*, uint32_t, bool,uint32_t);
 static File_Verdict file_agent_signature_callback(void*, void*, uint8_t*,
-        uint64_t, FileState *, bool, uint32_t);
+        uint64_t, FileState *, bool, uint32_t, bool);
 static int file_agent_queue_file(void*, void *);
 static int file_agent_init_socket(char *hostname, int portno);
 
@@ -663,7 +663,7 @@ static inline int file_agent_capture_error(FileCaptureState capture_state)
  * or capture/singature is aborted
  */
 static File_Verdict file_agent_signature_callback (void* p, void* ssnptr,
-        uint8_t* file_sig, uint64_t file_size, FileState *state, bool upload, uint32_t file_id)
+        uint8_t* file_sig, uint64_t file_size, FileState *state, bool upload, uint32_t file_id, bool is_partial)
 {
     FileCaptureInfo *file_mem = NULL;
     FileCaptureState capture_state;
@@ -722,7 +722,7 @@ static File_Verdict file_agent_signature_callback (void* p, void* ssnptr,
     }
 
     /*Save the file to our file queue*/
-    if (file_agent_queue_file(pkt->stream_session, file_mem) < 0)
+    if ((!is_partial) && (file_agent_queue_file(pkt->stream_session, file_mem) < 0))
     {
         file_inspect_stats.file_agent_memcap_failures++;
         _dpd.logMsg("File inspect: can't queue file!\n");
