@@ -1,6 +1,6 @@
 /* $Id$ */
 /*
- ** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ ** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  ** Copyright (C) 2004-2013 Sourcefire, Inc.
  **
  ** This program is free software; you can redistribute it and/or modify
@@ -1871,22 +1871,27 @@ int check_ftp(FTP_SESSION  *ftpssn, SFSnortPacket *p, int iMode)
                                 memcpy(ftpssn->filename, req->param_begin, req->param_size);
                                 ftpssn->filename[req->param_size] = '\0';
                                 ftpssn->file_xfer_info = req->param_size;
-                                 if (ftpssn->flags & FTP_FLG_MALWARE_ENABLED)
-                                 {
-                                     IP_COPY_VALUE(ftpssn->control_clientIP, GET_SRC_IP(p));
-                                     IP_COPY_VALUE(ftpssn->control_serverIP, GET_DST_IP(p));
-                                     ftpssn->control_serverPort = ntohs(p->tcp_header->destination_port);
-                                     ftpssn->control_clientPort = ntohs(p->tcp_header->source_port);
-                                     datassn = (FTP_DATA_SESSION *)ftpssn->datassn;
-                                     if(datassn)
-                                     {
-                                         char *file_name = strrchr(ftpssn->filename, '/');
-                                         if(!file_name)
-                                             file_name = ftpssn->filename;
-                                         datassn->path_hash = _dpd.fileAPI->str_to_hash((uint8_t *)file_name, strlen(file_name));
-                                     }
-                                  }
-                             }
+                                if (ftpssn->flags & FTP_FLG_MALWARE_ENABLED)
+                                {
+                                    IP_COPY_VALUE(ftpssn->control_clientIP, GET_SRC_IP(p));
+                                    IP_COPY_VALUE(ftpssn->control_serverIP, GET_DST_IP(p));
+                                    ftpssn->control_serverPort = ntohs(p->tcp_header->destination_port);
+                                    ftpssn->control_clientPort = ntohs(p->tcp_header->source_port);
+                                    datassn = (FTP_DATA_SESSION *)ftpssn->datassn;
+                                    if(datassn)
+                                    {
+                                        char *file_name = strrchr(ftpssn->filename, '/');
+                                        if(!file_name)
+                                            file_name = ftpssn->filename;
+                                        datassn->path_hash = _dpd.fileAPI->str_to_hash((uint8_t *)file_name, strlen(file_name));
+                                    }
+                                }
+                            }
+                            else
+                            {
+                                _dpd.errMsg("check_ftp: "
+                                        "Memory allocation failed for filename in ftpssn\n");
+                            }
                             // 0 for Download, 1 for Upload
                             ftpssn->data_xfer_dir = CmdConf->file_get_cmd ? false : true;
                             FTP_DATA_SESSION *ftpdata = ftpssn->datassn;
