@@ -59,7 +59,7 @@ extern IMAPConfig **imap_config;
 extern const IMAPToken imap_known_cmds[];
 
 /* Private functions */
-static int  ProcessPorts(IMAPConfig *, char *, int);
+static int  ProcessPorts(IMAPConfig *, char *, int, char **);
 
 /*
  * Function: IMAP_ParseArgs(char *)
@@ -78,6 +78,7 @@ void IMAP_ParseArgs(IMAPConfig *config, char *args)
 {
     int ret = 0;
     char *arg;
+    char *saveptr;
     char errStr[ERRSTRLEN];
     int errStrLen = ERRSTRLEN;
 
@@ -91,7 +92,7 @@ void IMAP_ParseArgs(IMAPConfig *config, char *args)
 
     *errStr = '\0';
 
-    arg = strtok(args, CONF_SEPARATORS);
+    arg = strtok_r(args, CONF_SEPARATORS, &saveptr);
 
     while ( arg != NULL )
     {
@@ -99,21 +100,21 @@ void IMAP_ParseArgs(IMAPConfig *config, char *args)
 
         if ( !strcasecmp(CONF_PORTS, arg) )
         {
-            ret = ProcessPorts(config, errStr, errStrLen);
+            ret = ProcessPorts(config, errStr, errStrLen, &saveptr);
         }
         else if ( !strcasecmp(CONF_IMAP_MEMCAP, arg) )
         {
-            ret = _dpd.checkValueInRange(strtok(NULL, CONF_SEPARATORS), CONF_IMAP_MEMCAP,
+            ret = _dpd.checkValueInRange(strtok_r(NULL, CONF_SEPARATORS, &saveptr), CONF_IMAP_MEMCAP,
                     MIN_IMAP_MEMCAP, MAX_IMAP_MEMCAP, &value);
             config->memcap = (uint32_t)value;
         }
         else if ( !strcasecmp(CONF_MAX_MIME_MEM, arg) )
         {
-            ret = _dpd.checkValueInRange(strtok(NULL, CONF_SEPARATORS), CONF_MAX_MIME_MEM,
+            ret = _dpd.checkValueInRange(strtok_r(NULL, CONF_SEPARATORS, &saveptr), CONF_MAX_MIME_MEM,
                     MIN_MIME_MEM, MAX_MIME_MEM, &value);
             config->decode_conf.max_mime_mem = (int)value;
         }
-        else if(!_dpd.fileAPI->parse_mime_decode_args(&(config->decode_conf), arg, "IMAP"))
+        else if(!_dpd.fileAPI->parse_mime_decode_args(&(config->decode_conf), arg, "IMAP", &saveptr))
         {
             ret = 0;
         }
@@ -145,7 +146,7 @@ void IMAP_ParseArgs(IMAPConfig *config, char *args)
         }
 
         /*  Get next token */
-        arg = strtok(NULL, CONF_SEPARATORS);
+        arg = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
     }
 
 }
@@ -301,6 +302,7 @@ void IMAP_PrintConfig(IMAPConfig *config)
 **
 **  @param ErrorString error string buffer
 **  @param ErrStrLen   the length of the error string buffer
+**  @param saveptr     the strtok_r saved state
 **
 **  @return an error code integer
 **          (0 = success, >0 = non-fatal error, <0 = fatal error)
@@ -309,7 +311,7 @@ void IMAP_PrintConfig(IMAPConfig *config)
 **  @retval -1 generic fatal error
 **  @retval  1 generic non-fatal error
 */
-static int ProcessPorts(IMAPConfig *config, char *ErrorString, int ErrStrLen)
+static int ProcessPorts(IMAPConfig *config, char *ErrorString, int ErrStrLen, char **saveptr)
 {
     char *pcToken;
     char *pcEnd;
@@ -323,7 +325,7 @@ static int ProcessPorts(IMAPConfig *config, char *ErrorString, int ErrStrLen)
         return -1;
     }
 
-    pcToken = strtok(NULL, CONF_SEPARATORS);
+    pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if(!pcToken)
     {
         snprintf(ErrorString, ErrStrLen, "Invalid port list format.");
@@ -341,7 +343,7 @@ static int ProcessPorts(IMAPConfig *config, char *ErrorString, int ErrStrLen)
     /* Since ports are specified, clear default ports */
     disablePort( config->ports, IMAP_DEFAULT_SERVER_PORT );
 
-    while ((pcToken = strtok(NULL, CONF_SEPARATORS)) != NULL)
+    while ((pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr)) != NULL)
     {
         if(!strcmp(CONF_END_LIST, pcToken))
         {
