@@ -556,7 +556,7 @@ static PAF_Status imap_paf(void* ssn, void** ps, const uint8_t* data,
         //if (_dpd.fileAPI->check_paf_abort(ssn))
           //  return PAF_ABORT;
 
-        pfdata = calloc(1, sizeof(*pfdata));
+        pfdata = _dpd.snortAlloc(1, sizeof(*pfdata), PP_IMAP, 0);
         if (pfdata == NULL)
         {
             return PAF_ABORT;
@@ -592,6 +592,12 @@ bool is_data_end (void* ssn)
     return false;
 }
 
+void imap_paf_cleanup(void *pafData)
+{
+   if(pafData) {
+      _dpd.snortFree(pafData, sizeof(ImapPafData), PP_IMAP, 0);
+   }
+}
 
 #ifdef TARGET_BASED
 void register_imap_paf_service (struct _SnortConfig *sc, int16_t app, tSfPolicyId policy)
@@ -600,6 +606,7 @@ void register_imap_paf_service (struct _SnortConfig *sc, int16_t app, tSfPolicyI
     {
         imap_paf_id = _dpd.streamAPI->register_paf_service(sc, policy, app, true, imap_paf, true);
         imap_paf_id = _dpd.streamAPI->register_paf_service(sc, policy, app, false,imap_paf, true);
+        _dpd.streamAPI->register_paf_free(imap_paf_id, imap_paf_cleanup);
     }
 }
 #endif
@@ -611,5 +618,6 @@ void register_imap_paf_port(struct _SnortConfig *sc, unsigned int i, tSfPolicyId
     {
         imap_paf_id = _dpd.streamAPI->register_paf_port(sc, policy, (uint16_t)i, true, imap_paf, true);
         imap_paf_id = _dpd.streamAPI->register_paf_port(sc, policy, (uint16_t)i, false, imap_paf, true);
+        _dpd.streamAPI->register_paf_free(imap_paf_id, imap_paf_cleanup);
     }
 }
