@@ -40,6 +40,7 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+#include <time.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -56,6 +57,38 @@
 #include "Unified2_common.h"
 
 extern IMAP *imap_ssn;
+extern MemPool *imap_mempool;
+extern MemPool *imap_mime_mempool;
+
+int IMAP_Print_Mem_Stats(char *buffer)
+{
+    time_t curr_time = time(NULL);
+        
+    return snprintf(buffer, CS_STATS_BUF_SIZE, "\n\nMemory Statistics of IMAP on: %s\n"
+             "IMAP Session Statistics:\n"
+             "       Total Sessions seen: " STDu64 "\n"
+             "   Max concurrent sessions: " STDu64 "\n"
+             "   Current Active sessions: " STDu64 "\n"
+             "\n   Memory Pool:\n"
+             "        Free Memory:\n"
+             "            IMAP Mime Pool: %14zu bytes\n"
+             "                 IMAP Pool: %14zu bytes\n"
+             "        Used Memory:\n"
+             "            IMAP Mime Pool: %14zu bytes\n"
+             "                 IMAP Pool: %14zu bytes\n"
+             "        -------------------       ---------------\n"             
+             "        Total Memory:       %14zu bytes\n"
+             , ctime(&curr_time)
+             , imap_stats.sessions
+             , imap_stats.max_conc_sessions
+             , imap_stats.cur_sessions
+             , (imap_mime_mempool) ? (imap_mime_mempool->max_memory - imap_mime_mempool->used_memory) : 0
+             , (imap_mempool) ? (imap_mempool->max_memory - imap_mempool->used_memory) : 0
+             , (imap_mime_mempool) ? imap_mime_mempool->used_memory : 0
+             , (imap_mempool) ? imap_mempool->used_memory : 0
+             , ((imap_mime_mempool) ? (imap_mime_mempool->max_memory) : 0) +
+                          ((imap_mempool) ? (imap_mempool->max_memory) : 0));
+}
 
 void IMAP_GetEOL(const uint8_t *ptr, const uint8_t *end,
                  const uint8_t **eol, const uint8_t **eolm)
