@@ -53,6 +53,7 @@
 #include "spp_imap.h"
 #include "sf_preproc_info.h"
 #include "snort_imap.h"
+#include "imap_util.h"
 #include "imap_config.h"
 #include "imap_log.h"
 #include "imap_paf.h"
@@ -184,6 +185,8 @@ static void IMAPInit(struct _SnortConfig *sc, char *args)
     PrintIMAPSize();
 #endif
 
+    _dpd.registerMemoryStatsFunc(PP_IMAP, "imap", IMAP_Print_Mem_Stats);
+
     if (imap_config == NULL)
     {
         //create a context
@@ -230,7 +233,7 @@ static void IMAPInit(struct _SnortConfig *sc, char *args)
         DynamicPreprocessorFatalMessage("Can only configure IMAP preprocessor once.\n");
     }
 
-    pPolicyConfig = (IMAPConfig *)calloc(1, sizeof(IMAPConfig));
+    pPolicyConfig = (IMAPConfig *)_dpd.snortAlloc(1, sizeof(IMAPConfig), PP_IMAP, 1);
     if (pPolicyConfig == NULL)
     {
         DynamicPreprocessorFatalMessage("Not enough memory to create IMAP "
@@ -590,7 +593,7 @@ static void IMAPReload(struct _SnortConfig *sc, char *args, void **new_config)
     if (pPolicyConfig != NULL)
         DynamicPreprocessorFatalMessage("Can only configure IMAP preprocessor once.\n");
 
-    pPolicyConfig = (IMAPConfig *)calloc(1, sizeof(IMAPConfig));
+    pPolicyConfig = (IMAPConfig *)_dpd.snortAlloc(1, sizeof(IMAPConfig), PP_IMAP, 1);
     if (pPolicyConfig == NULL)
     {
         DynamicPreprocessorFatalMessage("Not enough memory to create IMAP "
