@@ -29,6 +29,7 @@
 #include "snort_pop.h"
 #include "pop_config.h"
 #include "file_api.h"
+#include "pop_util.h"
 
 static uint8_t pop_paf_id = 0;
 
@@ -438,7 +439,8 @@ static PAF_Status pop_paf(void* ssn, void** ps, const uint8_t* data,
         if (_dpd.fileAPI->check_paf_abort(ssn))
             return PAF_ABORT;
         
-        pfdata = calloc(1, sizeof(*pfdata));
+        pfdata = _dpd.snortAlloc(1, sizeof(*pfdata), PP_POP, 0);
+        
         if (pfdata == NULL)
         {
             return PAF_ABORT;
@@ -474,6 +476,13 @@ bool is_data_end (void* ssn)
     return false;
 }
 
+void pop_paf_cleanup(void *pafData)
+{
+   if (pafData) {
+      _dpd.snortFree(pafData, sizeof(PopPafData), PP_POP, 0);
+   }
+}
+
 #ifdef TARGET_BASED
 void register_pop_paf_service (struct _SnortConfig *sc, int16_t app, tSfPolicyId policy)
 {
@@ -481,6 +490,7 @@ void register_pop_paf_service (struct _SnortConfig *sc, int16_t app, tSfPolicyId
     {
        pop_paf_id = _dpd.streamAPI->register_paf_service(sc, policy, app, true, pop_paf, true);
        pop_paf_id = _dpd.streamAPI->register_paf_service(sc, policy, app, false,pop_paf, true);
+       _dpd.streamAPI->register_paf_free(pop_paf_id, pop_paf_cleanup);
     }
 }
 #endif
@@ -492,5 +502,6 @@ void register_pop_paf_port(struct _SnortConfig *sc, unsigned int i, tSfPolicyId
     {
         pop_paf_id = _dpd.streamAPI->register_paf_port(sc, policy, (uint16_t)i, true, pop_paf, true);
         pop_paf_id = _dpd.streamAPI->register_paf_port(sc, policy, (uint16_t)i, false, pop_paf, true);
+	_dpd.streamAPI->register_paf_free(pop_paf_id, pop_paf_cleanup);
     }
 }
