@@ -40,6 +40,7 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+#include <time.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -51,12 +52,47 @@
 
 #include "snort_pop.h"
 #include "pop_util.h"
+#include "pop_config.h"
 #include "sf_dynamic_preprocessor.h"
 #include "sf_snort_packet.h"
 #include "Unified2_common.h"
 
 extern POP *pop_ssn;
 
+extern MemPool *pop_mime_mempool;
+extern MemPool *pop_mempool;
+extern POP_Stats pop_stats;
+
+int POP_Print_Mem_Stats(char *buffer)
+{
+    time_t curr_time = time(NULL);
+        
+    return snprintf(buffer, CS_STATS_BUF_SIZE, "\n\nMemory Statistics of POP on: %s\n"
+             "POP Session Statistics:\n"
+             "       Total Sessions seen: " STDu64 "\n"
+             "   Max concurrent sessions: " STDu64 "\n"
+             "   Current Active sessions: " STDu64 "\n"
+             "\n   Memory Pool:\n"
+             "         Free Memory:\n"
+             "             POP Mime Pool: %14zu bytes\n"
+             "                  POP Pool: %14zu bytes\n"
+             "         Used Memory:\n"
+             "             POP Mime Pool: %14zu bytes\n"
+             "                  POP Pool: %14zu bytes\n"
+             "        -------------------       ---------------\n"
+             "         Total Memory:      %14zu bytes\n"
+             , ctime(&curr_time)
+             , pop_stats.sessions
+             , pop_stats.max_conc_sessions
+             , pop_stats.cur_sessions
+             , (pop_mime_mempool) ? (pop_mime_mempool->max_memory - pop_mime_mempool->used_memory) : 0
+             , (pop_mempool) ? (pop_mempool->max_memory - pop_mempool->used_memory) : 0
+             , (pop_mime_mempool) ? pop_mime_mempool->used_memory : 0
+             , (pop_mempool) ? pop_mempool->used_memory : 0
+             , ((pop_mime_mempool) ? (pop_mime_mempool->max_memory) : 0) +
+                          ((pop_mempool) ? (pop_mempool->max_memory) : 0));
+}
+
 void POP_GetEOL(const uint8_t *ptr, const uint8_t *end,
                  const uint8_t **eol, const uint8_t **eolm)
 {
