@@ -173,7 +173,7 @@ void POP_InitCmds(POPConfig *config)
         return;
 
     /* add one to CMD_LAST for NULL entry */
-    config->cmds = (POPToken *)calloc(CMD_LAST + 1, sizeof(POPToken));
+    config->cmds = (POPToken *)_dpd.snortAlloc(CMD_LAST + 1, sizeof(POPToken), PP_POP, 1);
     if (config->cmds == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => failed to allocate memory for pop "
@@ -196,7 +196,8 @@ void POP_InitCmds(POPConfig *config)
     }
 
     /* initialize memory for command searches */
-    config->cmd_search = (POPSearch *)calloc(CMD_LAST, sizeof(POPSearch));
+    config->cmd_search = (POPSearch *)_dpd.snortAlloc(CMD_LAST, sizeof(POPSearch), PP_POP, 1);
+    
     if (config->cmd_search == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => failed to allocate memory for pop "
@@ -284,7 +285,7 @@ static POP * POP_GetNewSession(SFSnortPacket *p, tSfPolicyId policy_id)
 
     DEBUG_WRAP(DebugMessage(DEBUG_POP, "Creating new session data structure\n"););
 
-    ssn = (POP *)calloc(1, sizeof(POP));
+    ssn = (POP *)_dpd.snortAlloc(1, sizeof(POP), PP_POP, 0);
     if (ssn == NULL)
     {
         DynamicPreprocessorFatalMessage("Failed to allocate POP session data\n");
@@ -301,7 +302,7 @@ static POP * POP_GetNewSession(SFSnortPacket *p, tSfPolicyId policy_id)
     pop_ssn->mime_ssn.mime_stats = &(pop_stats.mime_stats);
     pop_ssn->mime_ssn.methods = &(mime_methods);
 
-    if (( ret = _dpd.fileAPI->set_log_buffers(&(pop_ssn->mime_ssn.log_state), &(pPolicyConfig->log_config),pop_mempool, p->stream_session)) < 0)
+    if (( ret = _dpd.fileAPI->set_log_buffers(&(pop_ssn->mime_ssn.log_state), &(pPolicyConfig->log_config),pop_mempool, p->stream_session, PP_POP)) < 0)
     {
         if( ret == -1 )
         {
@@ -311,7 +312,7 @@ static POP * POP_GetNewSession(SFSnortPacket *p, tSfPolicyId policy_id)
             }
             pop_stats.log_memcap_exceeded++;
         }
-        free(ssn);
+        _dpd.snortFree(ssn, sizeof(*ssn), PP_POP, 0);
         return NULL;
     }
 
@@ -350,6 +351,7 @@ static POP * POP_GetNewSession(SFSnortPacket *p, tSfPolicyId policy_id)
     pPolicyConfig->ref_count++;
     pop_stats.sessions++;
     pop_stats.conc_sessions++;
+    pop_stats.cur_sessions++;
     if(pop_stats.max_conc_sessions < pop_stats.conc_sessions)
        pop_stats.max_conc_sessions = pop_stats.conc_sessions;
 
@@ -505,19 +507,22 @@ static void POP_SessionFree(void *session_data)
     if(pop->mime_ssn.decode_state != NULL)
     {
         mempool_free(pop_mime_mempool, pop->mime_ssn.decode_bkt);
-        free(pop->mime_ssn.decode_state);
+        _dpd.snortFree(pop->mime_ssn.decode_state, sizeof(Email_DecodeState), PP_POP, 0);
     }
 
     if(pop->mime_ssn.log_state != NULL)
     {
         mempool_free(pop_mempool, pop->mime_ssn.log_state->log_hdrs_bkt);
-        free(pop->mime_ssn.log_state);
+        _dpd.snortFree(pop->mime_ssn.log_state, sizeof(MAIL_LogState), PP_POP, 0);
+       
     }
 
     if ( ssl_cb )
         ssl_cb->session_free(pop->flow_id);
 
-    free(pop);
+    _dpd.snortFree(pop, sizeof(*pop), PP_POP, 0);
+    if(pop_stats.cur_sessions)    
+	pop_stats.cur_sessions--;
     if(pop_stats.conc_sessions)
        pop_stats.conc_sessions--;
 }
@@ -556,18 +561,18 @@ void POP_FreeConfig(POPConfig *config)
         POPToken *tmp = config->cmds;
 
         for (; tmp->name != NULL; tmp++)
-            free(tmp->name);
+            _dpd.snortFree(tmp->name, sizeof(*(tmp->name)), PP_POP, 1);
 
-        free(config->cmds);
+        _dpd.snortFree(config->cmds, sizeof(*(config->cmds)), PP_POP, 1);
     }
 
     if (config->cmd_search_mpse != NULL)
         _dpd.searchAPI->search_instance_free(config->cmd_search_mpse);
 
     if (config->cmd_search != NULL)
-        free(config->cmd_search);
+        _dpd.snortFree(config->cmd_search, sizeof(*(config->cmd_search)), PP_POP, 1);
 
-    free(config);
+    _dpd.snortFree(config, sizeof(*config), PP_POP, 1);
 }
 
 
@@ -798,7 +803,7 @@ static void POP_ProcessServerPacket(SFSnortPacket *p)
         {
             DEBUG_WRAP(DebugMessage(DEBUG_POP, "DATA STATE ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n"););
             //ptr = POP_HandleData(p, ptr, end);
-            ptr = _dpd.fileAPI->process_mime_data(p, ptr, end, &(pop_ssn->mime_ssn), 0, true, "POP");
+            ptr = _dpd.fileAPI->process_mime_data(p, ptr, end, &(pop_ssn->mime_ssn), 0, true, "POP", PP_POP);
             continue;
         }
         POP_GetEOL(ptr, end, &eol, &eolm);
