@@ -56,6 +56,7 @@
 #include "pop_config.h"
 #include "pop_log.h"
 #include "pop_paf.h"
+#include "pop_util.h"
 
 #include "preprocids.h"
 #include "sf_snort_packet.h"
@@ -185,6 +186,8 @@ static void POPInit(struct _SnortConfig *sc, char *args)
     PrintPOPSize();
 #endif
 
+    _dpd.registerMemoryStatsFunc(PP_POP, "pop", POP_Print_Mem_Stats);
+
     if (pop_config == NULL)
     {
         //create a context
@@ -235,7 +238,7 @@ static void POPInit(struct _SnortConfig *sc, char *args)
         DynamicPreprocessorFatalMessage("Can only configure POP preprocessor once.\n");
     }
 
-    pPolicyConfig = (POPConfig *)calloc(1, sizeof(POPConfig));
+    pPolicyConfig = (POPConfig *)_dpd.snortAlloc(1, sizeof(POPConfig), PP_POP, 1);
     if (pPolicyConfig == NULL)
     {
         DynamicPreprocessorFatalMessage("Not enough memory to create POP "
@@ -585,7 +588,7 @@ static void POPReload(struct _SnortConfig *sc, char *args, void **new_config)
     if (pPolicyConfig != NULL)
         DynamicPreprocessorFatalMessage("Can only configure POP preprocessor once.\n");
 
-    pPolicyConfig = (POPConfig *)calloc(1, sizeof(POPConfig));
+    pPolicyConfig = (POPConfig *)_dpd.snortAlloc(1, sizeof(POPConfig), PP_POP, 1);
     if (pPolicyConfig == NULL)
     {
         DynamicPreprocessorFatalMessage("Not enough memory to create POP "
