@@ -1,7 +1,7 @@
 /* $Id$ */
 /****************************************************************************
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -114,6 +114,8 @@ void ShmemUnlink(const char *shmemName)
 
 void ShmemDestroy(const char *shmemName)
 {
+    if (!ShmemExists(shmemName, NULL))
+        return;
     ShmemUnlink(shmemName);
     unlink(shmemName);
     _dpd.logMsg("    Reputation Preprocessor: %s is freed\n", shmemName);
