@@ -89,6 +89,7 @@ static void ReputationPrintStats(int);
 static void ReputationCleanExit(int, void *);
 static inline IPrepInfo*  ReputationLookup(sfaddr_t* ip);
 static inline IPdecision GetReputation(IPrepInfo *, SFSnortPacket *, uint32_t *);
+bool reputation_process_external_ip(void *p, sfaddr_t* ip);
 #ifdef SHARED_REP
 static void ReputationMaintenanceCheck(int, void *);
 #endif
@@ -114,7 +115,6 @@ static void ReputationReloadSwapFree(void *);
 static int ReputationReloadVerify(struct _SnortConfig *, void *);
 #endif
 
-
 /* Called at preprocessor setup time. Links preprocessor keyword
  * to corresponding preprocessor initialization function.
  *
@@ -134,6 +134,7 @@ void SetupReputation(void)
             ReputationReloadVerify, ReputationReloadSwap,
             ReputationReloadSwapFree);
 #endif
+    _dpd.registerReputationProcessExternal(reputation_process_external_ip);
 }
 #ifdef SHARED_REP
 static int Reputation_MgmtInfo(uint16_t type, const uint8_t *data,
@@ -801,6 +802,70 @@ static inline void ReputationProcess(SFSnortPacket *p)
         reputation_stats.whitelisted++;
     }
 }
+bool reputation_process_external_ip(void *pkt, sfaddr_t *ip)
+{
+    IPdecision decision = DECISION_NULL;
+    IPrepInfo *result;
+    bool retval = false;
+    uint32_t flags = 0;
+    SFSnortPacket *p = (SFSnortPacket*)pkt;
+
+    if(!IPtables || !ip || !p)
+    {
+        return false;
+    }
+
+    reputation_eval_config = sfPolicyUserDataGetDefault(reputation_config);
+    reputation_eval_config->iplist = (table_flat_t *)*IPtables;
+    
+    result = ReputationLookup(ip);
+    if(result)
+    {
+        DEBUG_WRAP(ReputationPrintRepInfo(result,(uint8_t *) reputation_eval_config->iplist););
+        decision = GetReputation(result,p, &p->iplist_id);
+        
+        switch (decision)
+        {
+            case BLACKLISTED:
+                flags = SSNFLAG_DETECTION_DISABLED;
+                ALERT(REPUTATION_EVENT_BLACKLIST,REPUTATION_EVENT_BLACKLIST_STR);
+#ifdef POLICY_BY_ID_ONLY
+                _dpd.inlineForceDropSession(p);
+                flags |= SSNFLAG_FORCE_BLOCK;
+                if (*_dpd.pkt_tracer_enabled)
+                    _dpd.addPktTrace(VERDICT_REASON_REPUTATION, snprintf(_dpd.trace, _dpd.traceMax, "Reputation: packet blacklisted based on IP fetched from URL, drop\n"));
+                else 
+                    _dpd.addPktTrace(VERDICT_REASON_REPUTATION, 0);
+#endif
+                // disable all preproc analysis and detection for this packet
+                _dpd.disablePacketAnalysis(p);
+                _dpd.sessionAPI->set_session_flags( p->stream_session, flags );
+                reputation_stats.blacklisted++;
+                retval = true;
+                break;
+            case WHITELISTED_TRUST:
+                ALERT(REPUTATION_EVENT_WHITELIST,REPUTATION_EVENT_WHITELIST_STR);
+                p->flags |= FLAG_IGNORE_PORT;
+                _dpd.disablePacketAnalysis(p);
+                _dpd.sessionAPI->set_session_flags( p->stream_session, SSNFLAG_DETECTION_DISABLED );
+                reputation_stats.whitelisted++;
+                retval = true;
+                break;
+            case MONITORED:
+                if(!(p->flags & FLAG_IPREP_DATA_SET)) // Monitor the flow if it is not already monitored
+                {
+                    ALERT(REPUTATION_EVENT_MONITOR,REPUTATION_EVENT_MONITOR_STR);
+                    p->flags |= FLAG_IPREP_DATA_SET;
+                    reputation_stats.monitored++;
+                }
+                break;
+            case DECISION_NULL:
+            default:
+                break;
+        }
+    }
+    return retval;
+} 
 
 /* Main runtime entry point for Reputation preprocessor.
  * Analyzes Reputation packets for anomalies/exploits.
