@@ -53,7 +53,6 @@ void SIP_displayMedias(SIP_MediaList *dList);
 #endif
 
 
-
 /********************************************************************
  * Function: SIP_processRequest()
  *
@@ -419,11 +418,23 @@ static int SIP_ignoreChannels( SIP_DialogData *dialog, SFSnortPacket *p)
     			sfip_to_str(&mdataB->maddress), mdataB->mport););
     	/* Call into Streams to mark data channel as something to ignore. */
 #ifdef HAVE_DAQ_ADDRESS_SPACE_ID
-        ssn = _dpd.sessionAPI->get_session_ptr_from_ip_port(&mdataA->maddress,mdataA->mport, &mdataB->maddress,
-    	                                                    mdataB->mport, IPPROTO_UDP, 0, 0, p->pkt_header->address_space_id);
+#ifdef DAQ_CAPA_VRF
+      uint16_t sAsId = p->pkt_header->address_space_id_src;
+      uint16_t dAsId = p->pkt_header->address_space_id_dst;
+
+      ssn = _dpd.sessionAPI->get_session_ptr_from_ip_port(&mdataA->maddress,mdataA->mport,
+                                                          &mdataB->maddress,
+                                                          mdataB->mport,
+                                                          IPPROTO_UDP, 0, 0,
+                                                          sAsId, dAsId);                           
 #else
-        ssn = _dpd.sessionAPI->get_session_ptr_from_ip_port(&mdataA->maddress,mdataA->mport, &mdataB->maddress,
-    	                                                    mdataB->mport, IPPROTO_UDP, 0, 0, 0);
+      ssn = _dpd.sessionAPI->get_session_ptr_from_ip_port(&mdataA->maddress,mdataA->mport, &mdataB->maddress,
+                                                          mdataB->mport, IPPROTO_UDP, 0, 0, 
+                                                          p->pkt_header->address_space_id);
+#endif
+#else
+      ssn = _dpd.sessionAPI->get_session_ptr_from_ip_port(&mdataA->maddress,mdataA->mport, &mdataB->maddress,
+                                                          mdataB->mport, IPPROTO_UDP, 0, 0, 0);
 #endif
     	if ( _dpd.sessionAPI->is_session_verified( ssn ) )
     	{
