@@ -1,7 +1,7 @@
 /* $Id */
 
 /*
- ** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ ** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  ** Copyright (C) 2011-2013 Sourcefire, Inc.
  **
  **
@@ -114,6 +114,7 @@ static void registerPortsForDispatch( struct _SnortConfig *sc, SIPConfig *policy
 static void registerPortsForReassembly( SIPConfig *policy, int direction );
 static void _addPortsToStreamFilter(struct _SnortConfig *, SIPConfig *, tSfPolicyId);
 static void SIP_PrintStats(int);
+static void DisplaySIPStats (uint16_t type, void *old_context, struct _THREAD_ELEMENT *te, ControlDataSendFunc f);
 #ifdef TARGET_BASED
 static void _addServicesToStreamFilter(struct _SnortConfig *, tSfPolicyId);
 #endif
@@ -208,6 +209,8 @@ static void SIPInit(struct _SnortConfig *sc, char *argp)
 #ifdef REG_TEST
     PrintSIPSize();
 #endif
+	/* For SFR CLI */
+	_dpd.controlSocketRegisterHandler(CS_TYPE_SIP_STATS, NULL, NULL, &DisplaySIPStats);
 
     if (sip_config == NULL)
     {
@@ -818,6 +821,43 @@ void SIPFreeConfig(tSfPolicyUserContextId config)
     sfPolicyUserDataFreeIterate (config, SIPFreeConfigPolicy);
     sfPolicyConfigDelete(config);
 }
+
+static void DisplaySIPStats (uint16_t type, void *old_context, struct _THREAD_ELEMENT *te, ControlDataSendFunc f)
+{
+    char buffer[CS_STATS_BUF_SIZE + 1];
+    int i = 0;
+    int len = 0;
+
+    if (sip_stats.sessions) {
+        len += snprintf(buffer, CS_STATS_BUF_SIZE,  "SIP Preprocessor Statistics\n"
+            "  Total sessions: "STDu64"\n", sip_stats.sessions);
+        if (sip_stats.events)
+            len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "  SIP anomalies : "STDu64"\n", sip_stats.events);
+
+        if (sip_stats.dialogs)
+            len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "  Total  dialogs: "STDu64"\n", sip_stats.dialogs);
+
+        len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "  Requests: "STDu64"\n", sip_stats.requests[0]);
+        while (NULL != StandardMethods[i].name && len < CS_STATS_BUF_SIZE) {
+            len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "%16s:   "STDu64"\n",
+                    StandardMethods[i].name, sip_stats.requests[StandardMethods[i].methodFlag]);
+            i++;
+        }
+        len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "  Responses: "STDu64"\n", sip_stats.responses[TOTAL_RESPONSES]);
+        for (i = 1; i <NUM_OF_RESPONSE_TYPES && len < CS_STATS_BUF_SIZE; i++) {
+            len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "             %dxx:   "STDu64"\n", i, sip_stats.responses[i]);
+        }
+        len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  " Ignore sessions:   "STDu64"\n"
+            " Ignore channels:   "STDu64"\n", sip_stats.ignoreSessions, sip_stats.ignoreChannels);
+    } else {
+        len = snprintf(buffer, CS_STATS_BUF_SIZE, "SIP Stats not available\n Total Sessions:"STDu64"\n", sip_stats.sessions );
+    }
+
+    if (-1 == f(te, (const uint8_t *)buffer, len)) {
+        _dpd.logMsg("Unable to send data to the frontend\n");
+    }
+}
+
 /******************************************************************
  * Print statistics being kept by the preprocessor.
  *
