@@ -55,14 +55,14 @@
 
 
 /* Private functions */
-static int  ProcessPorts(SMTPConfig *, char *, int);
-static int ProcessCmds(SMTPConfig *, char *, int, int, SMTPCmdTypeEnum);
+static int  ProcessPorts(SMTPConfig *, char *, int, char **);
+static int  ProcessCmds(SMTPConfig *, char *, int, char **, int, SMTPCmdTypeEnum);
 static int  GetCmdId(SMTPConfig *, char *, SMTPCmdTypeEnum);
 static int  AddCmd(SMTPConfig *, char *, SMTPCmdTypeEnum);
-static int  ProcessAltMaxCmdLen(SMTPConfig *, char *, int);
-static int  ProcessMaxMimeDepth(SMTPConfig *, char *, int);
-static int  ProcessLogDepth(SMTPConfig *, char *, int);
-static int  ProcessXlink2State(SMTPConfig *, char *, int);
+static int  ProcessAltMaxCmdLen(SMTPConfig *, char *, int, char **);
+static int  ProcessMaxMimeDepth(SMTPConfig *, char *, int, char **);
+static int  ProcessLogDepth(SMTPConfig *, char *, int, char **);
+static int  ProcessXlink2State(SMTPConfig *, char *, int, char **);
 
 /*
  * Function: SMTP_ParseArgs(char *)
@@ -83,6 +83,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
     char *arg;
     char *value;
     char errStr[ERRSTRLEN];
+    char *saveptr;
     int errStrLen = ERRSTRLEN;
     int deprecated_options = 0;
 
@@ -106,7 +107,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
     _dpd.fileAPI->set_mime_log_config_defauts(&(config->log_config));
     config->log_config.email_hdrs_log_depth = DEFAULT_LOG_DEPTH;
 
-    config->cmd_config = (SMTPCmdConfig *)calloc(CMD_LAST, sizeof(SMTPCmdConfig));
+    config->cmd_config = (SMTPCmdConfig *)_dpd.snortAlloc(CMD_LAST, sizeof(SMTPCmdConfig), PP_SMTP, 1);
     if (config->cmd_config == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => Failed to allocate memory for SMTP "
@@ -116,7 +117,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
 
     *errStr = '\0';
 
-    arg = strtok(args, CONF_SEPARATORS);
+    arg = strtok_r(args, CONF_SEPARATORS, &saveptr);
 
     while ( arg != NULL )
     {
@@ -124,11 +125,11 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
 
         if ( !strcasecmp(CONF_PORTS, arg) )
         {
-            ret = ProcessPorts(config, errStr, errStrLen);
+            ret = ProcessPorts(config, errStr, errStrLen, &saveptr);
         }
         else if ( !strcasecmp(CONF_INSPECTION_TYPE, arg) )
         {
-            value = strtok(NULL, CONF_SEPARATORS);
+            value = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
             if ( value == NULL )
             {
                 return;
@@ -144,7 +145,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         }
         else if ( !strcasecmp(CONF_NORMALIZE, arg) )
         {
-            value = strtok(NULL, CONF_SEPARATORS);
+            value = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
             if ( value == NULL )
             {
                 return;
@@ -174,7 +175,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         {
             char *endptr;
 
-            value = strtok(NULL, CONF_SEPARATORS);
+            value = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
             if ( value == NULL )
                 return;
 
@@ -184,7 +185,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         {
             char *endptr;
 
-            value = strtok(NULL, CONF_SEPARATORS);
+            value = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
             if ( value == NULL )
                 return;
 
@@ -195,7 +196,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         {
             char *endptr;
 
-            value = strtok(NULL, CONF_SEPARATORS);
+            value = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
             if ( value == NULL )
                 return;
 
@@ -205,7 +206,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         {
             char *endptr;
 
-            value = strtok(NULL, CONF_SEPARATORS);
+            value = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
             if ( value == NULL )
                 return;
 
@@ -222,44 +223,44 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         else if ( !strcasecmp(CONF_INVALID_CMDS, arg) )
         {
             /* Parse disallowed commands */
-            ret = ProcessCmds(config, errStr, errStrLen, ACTION_ALERT, SMTP_CMD_TYPE_NORMAL);
+            ret = ProcessCmds(config, errStr, errStrLen, &saveptr, ACTION_ALERT, SMTP_CMD_TYPE_NORMAL);
         }
         else if ( !strcasecmp(CONF_VALID_CMDS, arg) )
         {
             /* Parse allowed commands */
-            ret = ProcessCmds(config, errStr, errStrLen, ACTION_NO_ALERT, SMTP_CMD_TYPE_NORMAL);
+            ret = ProcessCmds(config, errStr, errStrLen, &saveptr, ACTION_NO_ALERT, SMTP_CMD_TYPE_NORMAL);
         }
         else if ( !strcasecmp(CONF_AUTH_CMDS, arg) )
         {
-            ret = ProcessCmds(config, errStr, errStrLen, ACTION_NO_ALERT, SMTP_CMD_TYPE_AUTH);
+            ret = ProcessCmds(config, errStr, errStrLen, &saveptr, ACTION_NO_ALERT, SMTP_CMD_TYPE_AUTH);
         }
         else if ( !strcasecmp(CONF_DATA_CMDS, arg) )
         {
-            ret = ProcessCmds(config, errStr, errStrLen, ACTION_NO_ALERT, SMTP_CMD_TYPE_DATA);
+            ret = ProcessCmds(config, errStr, errStrLen, &saveptr, ACTION_NO_ALERT, SMTP_CMD_TYPE_DATA);
         }
         else if ( !strcasecmp(CONF_BDATA_CMDS, arg) )
         {
-            ret = ProcessCmds(config, errStr, errStrLen, ACTION_NO_ALERT, SMTP_CMD_TYPE_BDATA);
+            ret = ProcessCmds(config, errStr, errStrLen, &saveptr, ACTION_NO_ALERT, SMTP_CMD_TYPE_BDATA);
         }
         else if ( !strcasecmp(CONF_NORMALIZE_CMDS, arg) )
         {
             /* Parse normalized commands */
-            ret = ProcessCmds(config, errStr, errStrLen, ACTION_NORMALIZE, SMTP_CMD_TYPE_NORMAL);
+            ret = ProcessCmds(config, errStr, errStrLen, &saveptr, ACTION_NORMALIZE, SMTP_CMD_TYPE_NORMAL);
         }
         else if ( !strcasecmp(CONF_ALT_MAX_COMMAND_LINE_LEN, arg) )
         {
             /* Parse max line len for commands */
-            ret = ProcessAltMaxCmdLen(config, errStr, errStrLen);
+            ret = ProcessAltMaxCmdLen(config, errStr, errStrLen, &saveptr);
         }
         else if ( !strcasecmp(CONF_SMTP_MEMCAP, arg) )
         {
-            ret = _dpd.checkValueInRange(strtok(NULL, CONF_SEPARATORS), CONF_SMTP_MEMCAP,
+            ret = _dpd.checkValueInRange(strtok_r(NULL, CONF_SEPARATORS, &saveptr), CONF_SMTP_MEMCAP,
                     MIN_SMTP_MEMCAP, MAX_SMTP_MEMCAP, &val);
             config->memcap = (uint32_t)val;
         }
         else if ( !strcasecmp(CONF_MAX_MIME_MEM, arg) )
         {
-            ret = _dpd.checkValueInRange(strtok(NULL, CONF_SEPARATORS), CONF_MAX_MIME_MEM,
+            ret = _dpd.checkValueInRange(strtok_r(NULL, CONF_SEPARATORS, &saveptr), CONF_MAX_MIME_MEM,
                     MIN_MIME_MEM, MAX_MIME_MEM, &val);
             config->decode_conf.max_mime_mem = (int)val;
         }
@@ -268,7 +269,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
             deprecated_options = 1;
             _dpd.logMsg("WARNING: %s(%d) => The SMTP config option 'max_mime_depth' is deprecated.\n",
                             *(_dpd.config_file), *(_dpd.config_line));
-            ret = ProcessMaxMimeDepth(config, errStr, errStrLen);
+            ret = ProcessMaxMimeDepth(config, errStr, errStrLen, &saveptr);
         }
         else if ( !strcasecmp(CONF_ENABLE_MIME_DECODING, arg) )
         {
@@ -283,7 +284,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         }
         else if ( !strcasecmp(CONF_XLINK2STATE, arg) )
         {
-            ret = ProcessXlink2State(config, errStr, errStrLen);
+            ret = ProcessXlink2State(config, errStr, errStrLen, &saveptr);
         }
         else if ( !strcasecmp(CONF_LOG_FILENAME, arg) )
         {
@@ -303,7 +304,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         }
         else if ( !strcasecmp(CONF_EMAIL_HDRS_LOG_DEPTH, arg) )
         {
-            ret = ProcessLogDepth(config, errStr, errStrLen);
+            ret = ProcessLogDepth(config, errStr, errStrLen, &saveptr);
         }
 
         else if ( !strcasecmp(CONF_PRINT_CMDS, arg) )
@@ -311,7 +312,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
             config->print_cmds = 1;
         }
 
-        else if(!_dpd.fileAPI->parse_mime_decode_args(&(config->decode_conf), arg, "SMTP"))
+        else if(!_dpd.fileAPI->parse_mime_decode_args(&(config->decode_conf), arg, "SMTP", &saveptr))
         {
             ret = 0;
         }
@@ -339,7 +340,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         }
 
         /*  Get next token */
-        arg = strtok(NULL, CONF_SEPARATORS);
+        arg = strtok_r(NULL, CONF_SEPARATORS, &saveptr);
     }
 
     // NOTE: the default b64_depth is not defined in this file 
@@ -694,6 +695,7 @@ void SMTP_PrintConfig(SMTPConfig *config)
 **
 **  @param ErrorString error string buffer
 **  @param ErrStrLen   the length of the error string buffer
+**  @param saveptr     the strtok_r saved state
 **
 **  @return an error code integer
 **          (0 = success, >0 = non-fatal error, <0 = fatal error)
@@ -702,7 +704,7 @@ void SMTP_PrintConfig(SMTPConfig *config)
 **  @retval -1 generic fatal error
 **  @retval  1 generic non-fatal error
 */
-static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
+static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen, char **saveptr)
 {
     char *pcToken;
     char *pcEnd;
@@ -716,7 +718,7 @@ static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
         return -1;
     }
 
-    pcToken = strtok(NULL, CONF_SEPARATORS);
+    pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if(!pcToken)
     {
         snprintf(ErrorString, ErrStrLen, "Invalid port list format.");
@@ -735,7 +737,7 @@ static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
     disablePort( config->ports, SMTP_DEFAULT_SERVER_PORT );
     disablePort( config->ports, XLINK2STATE_DEFAULT_PORT );
     disablePort( config->ports, SMTP_DEFAULT_SUBMISSION_PORT );
-    while ((pcToken = strtok(NULL, CONF_SEPARATORS)) != NULL)
+    while ((pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr)) != NULL)
     {
         if(!strcmp(CONF_END_LIST, pcToken))
         {
@@ -798,6 +800,7 @@ static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
 **
 **  @param ErrorString error string buffer
 **  @param ErrStrLen   the length of the error string buffer
+**  @param saveptr     the strtok_r saved state
 **
 **  @return an error code integer
 **          (0 = success, >0 = non-fatal error, <0 = fatal error)
@@ -806,7 +809,7 @@ static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
 **  @retval -1 generic fatal error
 */
 static int ProcessCmds(SMTPConfig *config, char *ErrorString,
-        int ErrStrLen, int action, SMTPCmdTypeEnum type)
+        int ErrStrLen, char **saveptr, int action, SMTPCmdTypeEnum type)
 {
     char *pcToken;
     int   iEndCmds = 0;
@@ -818,7 +821,7 @@ static int ProcessCmds(SMTPConfig *config, char *ErrorString,
         return -1;
     }
 
-    pcToken = strtok(NULL, CONF_SEPARATORS);
+    pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if (!pcToken)
     {
         snprintf(ErrorString, ErrStrLen, "Invalid command list format.");
@@ -834,7 +837,7 @@ static int ProcessCmds(SMTPConfig *config, char *ErrorString,
         return -1;
     }
 
-    while ((pcToken = strtok(NULL, CONF_SEPARATORS)) != NULL)
+    while ((pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr)) != NULL)
     {
         if (strcmp(CONF_END_LIST, pcToken) == 0)
         {
@@ -908,7 +911,7 @@ static int AddCmd(SMTPConfig *config, char *name, SMTPCmdTypeEnum type)
     config->num_cmds++;
 
     /* allocate enough memory for new commmand - alloc one extra for NULL entry */
-    cmds = (SMTPToken *)calloc(config->num_cmds + 1, sizeof(SMTPToken));
+    cmds = (SMTPToken *)_dpd.snortAlloc(config->num_cmds + 1, sizeof(SMTPToken), PP_SMTP, 1);
     if (cmds == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => Failed to allocate memory for SMTP "
@@ -917,7 +920,7 @@ static int AddCmd(SMTPConfig *config, char *name, SMTPCmdTypeEnum type)
     }
 
     /* This gets filled in later */
-    cmd_search = (SMTPSearch *)calloc(config->num_cmds, sizeof(SMTPSearch));
+    cmd_search = (SMTPSearch *)_dpd.snortAlloc(config->num_cmds, sizeof(SMTPSearch), PP_SMTP, 1);
     if (cmd_search == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => Failed to allocate memory for SMTP "
@@ -925,7 +928,7 @@ static int AddCmd(SMTPConfig *config, char *name, SMTPCmdTypeEnum type)
                                         *(_dpd.config_file), *(_dpd.config_line));
     }
 
-    cmd_config = (SMTPCmdConfig *)calloc(config->num_cmds, sizeof(SMTPCmdConfig));
+    cmd_config = (SMTPCmdConfig *)_dpd.snortAlloc(config->num_cmds, sizeof(SMTPCmdConfig), PP_SMTP, 1);
     if (cmd_config == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => Failed to allocate memory for SMTP "
@@ -972,13 +975,13 @@ static int AddCmd(SMTPConfig *config, char *name, SMTPCmdTypeEnum type)
 
     /* free global memory structures */
     if (config->cmds != NULL)
-        free(config->cmds);
+	_dpd.snortFree(config->cmds, sizeof(*(config->cmds)), PP_SMTP, 1);
 
     if (config->cmd_search != NULL)
-        free(config->cmd_search);
+	_dpd.snortFree(config->cmd_search, sizeof(*(config->cmd_search)), PP_SMTP, 1);
 
     if (config->cmd_config != NULL)
-        free(config->cmd_config);
+	_dpd.snortFree(config->cmd_config, sizeof(*(config->cmd_config)), PP_SMTP, 1);
 
     /* set globals to new memory */
     config->cmds = cmds;
@@ -988,18 +991,19 @@ static int AddCmd(SMTPConfig *config, char *name, SMTPCmdTypeEnum type)
     return (config->num_cmds - 1);
 }
 
-static int ProcessMaxMimeDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen)
+static int ProcessMaxMimeDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen, char **saveptr)
 {
     char *endptr;
     char *value;
     int max_mime_depth = 0;
+
     if (config == NULL)
     {
         snprintf(ErrorString, ErrStrLen, "SMTP config is NULL.\n");
         return -1;
     }
 
-    value = strtok(NULL, CONF_SEPARATORS);
+    value = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if ( value == NULL )
     {
         snprintf(ErrorString, ErrStrLen,
@@ -1036,18 +1040,19 @@ static int ProcessMaxMimeDepth(SMTPConfig *config, char *ErrorString, int ErrStr
     return 0;
 }
 
-static int ProcessLogDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen)
+static int ProcessLogDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen, char **saveptr)
 {
     char *endptr;
     char *value;
     uint32_t log_depth = 0;
+
     if (config == NULL)
     {
         snprintf(ErrorString, ErrStrLen, "SMTP config is NULL.\n");
         return -1;
     }
 
-    value = strtok(NULL, CONF_SEPARATORS);
+    value = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if ( value == NULL )
     {
         snprintf(ErrorString, ErrStrLen,
@@ -1105,6 +1110,7 @@ static int ProcessLogDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen)
 **
 **  @param ErrorString error string buffer
 **  @param ErrStrLen   the length of the error string buffer
+**  @param saveptr     the strtok_r saved state
 **
 **  @return an error code integer
 **          (0 = success, >0 = non-fatal error, <0 = fatal error)
@@ -1112,7 +1118,7 @@ static int ProcessLogDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen)
 **  @retval  0 successs
 **  @retval -1 generic fatal error
 */
-static int ProcessAltMaxCmdLen(SMTPConfig *config, char *ErrorString, int ErrStrLen)
+static int ProcessAltMaxCmdLen(SMTPConfig *config, char *ErrorString, int ErrStrLen, char **saveptr)
 {
     char *pcToken;
     char *pcLen;
@@ -1128,7 +1134,7 @@ static int ProcessAltMaxCmdLen(SMTPConfig *config, char *ErrorString, int ErrStr
     }
 
     /* Find number */
-    pcLen = strtok(NULL, CONF_SEPARATORS);
+    pcLen = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if (!pcLen)
     {
         snprintf(ErrorString, ErrStrLen,
@@ -1137,7 +1143,7 @@ static int ProcessAltMaxCmdLen(SMTPConfig *config, char *ErrorString, int ErrStr
         return -1;
     }
 
-    pcToken = strtok(NULL, CONF_SEPARATORS);
+    pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if (!pcToken)
     {
         snprintf(ErrorString, ErrStrLen,
@@ -1164,7 +1170,7 @@ static int ProcessAltMaxCmdLen(SMTPConfig *config, char *ErrorString, int ErrStr
         return -1;
     }
 
-    while ((pcToken = strtok(NULL, CONF_SEPARATORS)) != NULL)
+    while ((pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr)) != NULL)
     {
         if (strcmp(CONF_END_LIST, pcToken) == 0)
         {
@@ -1206,7 +1212,7 @@ static int ProcessAltMaxCmdLen(SMTPConfig *config, char *ErrorString, int ErrStr
 **  @retval  0 successs
 **  @retval -1 generic fatal error
 */
-static int ProcessXlink2State(SMTPConfig *config, char *ErrorString, int ErrStrLen)
+static int ProcessXlink2State(SMTPConfig *config, char *ErrorString, int ErrStrLen, char **saveptr)
 {
     char *pcToken;
     int  iEnd = 0;
@@ -1217,7 +1223,7 @@ static int ProcessXlink2State(SMTPConfig *config, char *ErrorString, int ErrStrL
         return -1;
     }
 
-    pcToken = strtok(NULL, CONF_SEPARATORS);
+    pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr);
     if(!pcToken)
     {
         snprintf(ErrorString, ErrStrLen,
@@ -1235,7 +1241,7 @@ static int ProcessXlink2State(SMTPConfig *config, char *ErrorString, int ErrStrL
         return -1;
     }
 
-    while ((pcToken = strtok(NULL, CONF_SEPARATORS)) != NULL)
+    while ((pcToken = strtok_r(NULL, CONF_SEPARATORS, saveptr)) != NULL)
     {
         if(!strcmp(CONF_END_LIST, pcToken))
         {
