@@ -39,6 +39,7 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+#include <time.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -55,6 +56,38 @@
 
 extern SMTP *smtp_ssn;
 extern char smtp_normalizing;
+extern MemPool *smtp_mime_mempool;
+extern MemPool *smtp_mempool;
+
+int SMTP_Print_Mem_Stats(char *buffer)
+{
+    time_t curr_time = time(NULL);
+    
+    return snprintf(buffer, CS_STATS_BUF_SIZE, "\n\nMemory Statistics of SMTP on: %s\n"
+             "SMTP Session Statistics:\n"
+             "       Total Sessions seen: " STDu64 "\n"
+             "   Max concurrent sessions: " STDu64 "\n"
+             "   Current Active sessions: " STDu64 "\n"
+             "\n   Memory Pool:\n"
+             "        Free Memory:\n"
+             "            SMTP Mime Pool: %14zu bytes\n"
+             "                 SMTP Pool: %14zu bytes\n"
+             "        Used Memory:\n"
+             "            SMTP Mime Pool: %14zu bytes\n"
+             "                 SMTP Pool: %14zu bytes\n"
+             "        -------------------       ---------------\n"             
+             "        Total Memory:       %14zu bytes\n"
+             , ctime(&curr_time)
+             , smtp_stats.sessions
+             , smtp_stats.max_conc_sessions
+             , smtp_stats.cur_sessions
+             , (smtp_mime_mempool) ? (smtp_mime_mempool->max_memory - smtp_mime_mempool->used_memory) : 0
+             , (smtp_mempool) ? (smtp_mempool->max_memory - smtp_mempool->used_memory) : 0
+             , (smtp_mime_mempool) ? smtp_mime_mempool->used_memory : 0
+             , (smtp_mempool) ? smtp_mempool->used_memory : 0
+             , ((smtp_mime_mempool) ? (smtp_mime_mempool->max_memory) : 0) +
+                             ((smtp_mempool) ? (smtp_mempool->max_memory) : 0));
+}
 
 void SMTP_GetEOL(const uint8_t *ptr, const uint8_t *end,
                  const uint8_t **eol, const uint8_t **eolm)
