@@ -53,6 +53,7 @@
 #include "spp_smtp.h"
 #include "sf_preproc_info.h"
 #include "snort_smtp.h"
+#include "smtp_util.h"
 #include "smtp_config.h"
 #include "smtp_log.h"
 #include "smtp_paf.h"
@@ -179,6 +180,8 @@ static void SMTPInit(struct _SnortConfig *sc, char *args)
 #ifdef REG_TEST
     PrintSMTPSize();
 #endif
+    
+    _dpd.registerMemoryStatsFunc(PP_SMTP, "smtp", SMTP_Print_Mem_Stats);
 
     if (smtp_config == NULL)
     {
@@ -230,7 +233,8 @@ static void SMTPInit(struct _SnortConfig *sc, char *args)
         DynamicPreprocessorFatalMessage("Can only configure SMTP preprocessor once.\n");
     }
 
-    pPolicyConfig = (SMTPConfig *)calloc(1, sizeof(SMTPConfig));
+    pPolicyConfig = (SMTPConfig *)_dpd.snortAlloc(1, sizeof(SMTPConfig), PP_SMTP, 1);
+
     if (pPolicyConfig == NULL)
     {
         DynamicPreprocessorFatalMessage("Not enough memory to create SMTP "
@@ -527,7 +531,6 @@ static void DisplaySMTPStats (uint16_t type, void *old_context, struct _THREAD_E
 {
     char buffer[CS_STATS_BUF_SIZE + 1];
     int len = 0;
-
     if (smtp_stats.sessions) {
         len += snprintf(buffer, CS_STATS_BUF_SIZE, "SMTP Preprocessor Statistics\n"
                 "  Total sessions                                    : " STDu64 "\n"
@@ -616,7 +619,8 @@ static void SMTPReload(struct _SnortConfig *sc, char *args, void **new_config)
     if (pPolicyConfig != NULL)
         DynamicPreprocessorFatalMessage("Can only configure SMTP preprocessor once.\n");
 
-    pPolicyConfig = (SMTPConfig *)calloc(1, sizeof(SMTPConfig));
+    pPolicyConfig = (SMTPConfig *)_dpd.snortAlloc(1, sizeof(SMTPConfig), PP_SMTP, 1);
+
     if (pPolicyConfig == NULL)
     {
         DynamicPreprocessorFatalMessage("Not enough memory to create SMTP "
