@@ -988,6 +988,8 @@ int SSLReloadVerify(struct _SnortConfig *sc, void *swap_config)
     SSLPP_config_t *start_config = NULL;
     tSfPolicyId policyId = _dpd.getDefaultPolicy();
     int ret = 0;
+    bool register_sfssl_preproc_reload_flag = false;
+    ssl_callback_interface_t *ssl_cb = (ssl_callback_interface_t *)_dpd.getSSLCallback();
 
     if (!_dpd.isPreprocEnabled(sc, PP_STREAM))
     {
@@ -1007,16 +1009,33 @@ int SSLReloadVerify(struct _SnortConfig *sc, void *swap_config)
         return -1;
     }
 
-    if ( reload_config->memcap != start_config->memcap )
+    if (ssl_cb && ssl_cb->reload_mem_adjust_available())
     {
+       _dpd.logMsg("SSL reload: SFSSL reload memcap adjust is available.\n");
+       register_sfssl_preproc_reload_flag = true;
+    }
+
+    if (!register_sfssl_preproc_reload_flag &&
+        reload_config->memcap != start_config->memcap)
+    {
+        /* Reload mem adjust not available, restart snort. */
         _dpd.errMsg("SSL reload: Changing the memcap requires a restart.\n");
         return -1;
     }
 
-    if ( reload_config->decrypt_memcap != start_config->decrypt_memcap )
+    if (!register_sfssl_preproc_reload_flag &&
+        reload_config->decrypt_memcap != start_config->decrypt_memcap)
     {
-        _dpd.errMsg("SSL reload: Changing the decrypt_memcap requires a restart.\n");
-        return -1;
+      /* Reload mem adjust not available, restart snort. */
+      _dpd.errMsg("SSL reload: Changing the decrypt_memcap requires a restart.\n");
+      return -1;
+    }
+
+    if (reload_config->memcap != start_config->memcap)
+    {
+        /* reload mem adjust is available, any change in sfssl memcap, adjust the difference in sftls memcap */
+        reload_config->decrypt_memcap += reload_config->memcap - start_config->memcap;
+        _dpd.logMsg("SSL reload: Change in sfssl memcap:%d, sftls memcap:%d.\n", reload_config->memcap, reload_config->decrypt_memcap);
     }
 
     ret = SSLPP_PolicyInit(sc, ssl_swap_config, reload_config, policyId, true);
@@ -1026,6 +1045,15 @@ int SSLReloadVerify(struct _SnortConfig *sc, void *swap_config)
         start_config->reload_handle = reload_config->current_handle;
     }
 
+    if (register_sfssl_preproc_reload_flag)
+    {
+      /* Always register the SFSSL preproc reload, if sftls memcap adjuster is available
+       * even in case where decrypt memcap doesn't change, may be we will add sftls_memcap in
+       * ssl_tuning.conf file which might be differrent.
+       */
+      ssl_cb->register_reload_mem_adjust(sc, reload_config);
+    }
+
     return ret;
 }
 
