@@ -262,7 +262,12 @@ int Encode_Format (EncodeFlags f, const Packet* p, Packet* c, PseudoPacketType t
     pkth->egress_index = phdr->egress_index;
     pkth->egress_group = phdr->egress_group;
     pkth->flags = phdr->flags & (~DAQ_PKT_FLAG_HW_TCP_CS_GOOD);
+#ifdef DAQ_CAPA_VRF
+    pkth->address_space_id_src = phdr->address_space_id_src;
+    pkth->address_space_id_dst = phdr->address_space_id_dst;
+#else
     pkth->address_space_id = phdr->address_space_id;
+#endif
     pkth->opaque = opaque;
     if( type == PSEUDO_PKT_TCP || type == PSEUDO_PKT_IP )
         pkth->priv_ptr = phdr->priv_ptr;
@@ -748,6 +753,9 @@ static void FPath_Format (EncodeFlags f, const Packet* p, Packet* c, Layer* lyr)
 
 static void VLAN_Format (EncodeFlags f, const Packet* p, Packet* c, Layer* lyr)
 {
+#ifdef HAVE_DAQ_REAL_ADDRESSES
+      if (!(p->pkth->flags & DAQ_PKT_FLAG_IGNORE_VLAN))
+#endif
     c->vh = (VlanTagHdr*)lyr->start;
 }
 
