@@ -168,7 +168,7 @@ typedef File_Verdict (*File_type_callback_func) (void* p, void* ssnptr,
         uint32_t file_type_id, bool upload, uint32_t file_id);
 typedef File_Verdict (*File_signature_callback_func) (void* p, void* ssnptr,
         uint8_t* file_sig, uint64_t file_size, FileState *state, bool upload,
-        uint32_t file_id);
+        uint32_t file_id, bool partial_file);
 typedef void (*Log_file_action_func) (void* ssnptr, int action);
 
 typedef int (*File_process_func)( void* p, uint8_t* file_data, int data_size, FilePosition position,
@@ -258,6 +258,7 @@ typedef bool (*File_cache_mem_adjust_func)(struct _FileCache *fileCache, uint8_t
 typedef void (*File_cache_mem_set_func)(struct _FileCache *fileCache, uint64_t memcap);
 typedef void (*File_event_log_dump_func)( struct _FileCache *fileCache, void* p, uint64_t file_id);
 typedef void (*File_signature_reset)(void *ssnptr);
+typedef void (*Set_file_partial_func)(void *p, FilePosition position, bool upload, bool is_partial);
 
 typedef struct _file_api
 {
@@ -725,6 +726,7 @@ typedef struct _file_api
 
     /* Logging a file event */
     File_event_log_dump_func file_event_log_dump;
+    Set_file_partial_func set_file_partial;
 
 } FileAPI;
 
