@@ -63,7 +63,7 @@ static void verify_file_capture_info(FileContext* context,
                 (fileInfo->file_size + context->current_data_len
                         != context->processed_bytes))
         {
-            FILE_DEBUG_MSGS("File capture size failed w.r.t processed size!\n");
+            FILE_DEBUG("File capture size failed w.r.t processed size!");
         }
     }
     else
@@ -72,7 +72,7 @@ static void verify_file_capture_info(FileContext* context,
                 (fileInfo->file_size + context->current_data_len
                         != context->file_size))
         {
-            FILE_DEBUG_MSGS("File capture size failed w.r.t final file size!\n");
+            FILE_DEBUG("File capture size failed w.r.t final file size!");
         }
     }
 }
@@ -104,7 +104,7 @@ static void verifiy_file_capture(FileContext* context,
     {
         if (sha256[i] != context->sha256[i])
         {
-            FILE_DEBUG_MSGS("File capture buffer is wrong!\n");
+            FILE_DEBUG("File capture buffer is wrong! SHA256 mismatch");
             break;
         }
     }
@@ -140,6 +140,7 @@ static void* _init_file_mempool(int64_t max_file_mem, int64_t block_size)
     if ((!file_mempool)||
             (safe_mempool_init(file_mempool, max_files, block_size) != 0))
     {
+        FILE_CRITICAL( "File capture: Could not allocate file buffer mempool.");
         FatalError( "File capture: Could not allocate file buffer mempool.\n");
     }
 
@@ -205,7 +206,6 @@ void file_capture_stop( FileContext* context)
     if (fileInfo)
     {
         /*free mempool*/
-        FILE_DEBUG_MSGS("Stop file capture!\n");
         if(!fileInfo->reserved)
         {
             _free_file_buffer(fileInfo);
@@ -213,6 +213,7 @@ void file_capture_stop( FileContext* context)
         context->file_capture = NULL;
     }
     context->file_capture_enabled = false;
+    FILE_DEBUG("Capture stopped");
 }
 
 /*
@@ -235,7 +236,7 @@ static inline FileCaptureInfo * _create_file_buffer(SafeMemPool *file_mempool)
 
     if(fileInfo == NULL)
     {
-        FILE_DEBUG_MSGS("Failed to get file capture memory!\n");
+        FILE_DEBUG("Failed to get file capture memory!");
         file_capture_stats.file_memcap_failures_total++;
         return NULL;
     }
@@ -277,7 +278,7 @@ static inline int _save_to_file_buffer(SafeMemPool *file_mempool,
 
     if ( data_size + (signed)fileInfo->file_size > max_size)
     {
-        FILE_DEBUG_MSGS("Exceeding max file capture size!\n");
+        FILE_DEBUG("Exceeding max file capture size!");
         file_capture_stats.file_size_exceeded++;
         context->file_state.capture_state = FILE_CAPTURE_MAX;
         return -1;
@@ -307,6 +308,7 @@ static inline int _save_to_file_buffer(SafeMemPool *file_mempool,
 
             if(new_block == NULL)
             {
+                FILE_ERROR("Failed to save in file buffer: FILE_CAPTURE_MEMCAP");
                 context->file_state.capture_state = FILE_CAPTURE_MEMCAP;
                 return -1;
             }
@@ -370,6 +372,7 @@ int file_capture_process( FileContext* context, uint8_t* file_data,
 
     context->current_data = file_data;
     context->current_data_len = data_size;
+    FILE_DEBUG("Processing capture: context: %p, data_size: %d, position: %d", context, data_size, position);
 
     switch (position)
     {
@@ -378,6 +381,11 @@ int file_capture_process( FileContext* context, uint8_t* file_data,
         break;
     case SNORT_FILE_END:
         break;
+    case SNORT_FILE_START:
+    case SNORT_FILE_MIDDLE:
+        if(FILE_SIG_FLUSH == context->file_state.sig_state){
+            break;
+        }
     default:
 
         /* For File position is either SNORT_FILE_START
@@ -391,7 +399,7 @@ int file_capture_process( FileContext* context, uint8_t* file_data,
 
             if (!fileInfo)
             {
-                FILE_DEBUG_MSGS("Can't get file capture memory!\n");
+                FILE_ERROR("Processing file capture: Can't get file capture memory, FILE_CAPTURE_MEMCAP");
                 context->file_state.capture_state = FILE_CAPTURE_MEMCAP;
                 return -1;
             }
@@ -403,13 +411,14 @@ int file_capture_process( FileContext* context, uint8_t* file_data,
 
         if (!fileInfo)
         {
+            FILE_ERROR("Processing file capture: File info not available");
             return -1;
         }
 
         if (_save_to_file_buffer(file_mempool, context, file_data, data_size,
                 file_config->file_capture_max_size))
         {
-            FILE_DEBUG_MSGS("Can't save to file buffer!\n");
+            FILE_ERROR("Processing file capture: Can't save to file buffer!");
             return -1;
         }
     }
@@ -446,6 +455,7 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
 
     if (!ssnptr||!file_config||!file_mem)
     {
+        FILE_ERROR("Capture failed: No session/memory/config");
         return ERROR_capture(FILE_CAPTURE_FAIL);
     }
 
@@ -453,11 +463,13 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
 
     if (!context || !context->file_capture_enabled)
     {
+        FILE_ERROR("Capture failed: Not enabled");
         return ERROR_capture(FILE_CAPTURE_FAIL);
     }
 
     if (context->file_state.capture_state != FILE_CAPTURE_SUCCESS)
     {
+        FILE_ERROR("Capture failed: %d",context->file_state.capture_state);
         return ERROR_capture(context->file_state.capture_state);
     }
 
@@ -468,15 +480,17 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
      */
     fileSize = context->file_size;
 
-    if ( fileSize < (unsigned) file_config->file_capture_min_size)
+    if ((!context->partial_file) && (fileSize < (unsigned) file_config->file_capture_min_size))
     {
         file_capture_stats.file_size_min++;
+        FILE_ERROR("Capture failed: FILE_CAPTURE_MIN, size: %d",fileSize);
         return ERROR_capture(FILE_CAPTURE_MIN);
     }
 
     if ( fileSize > (unsigned) file_config->file_capture_max_size)
     {
         file_capture_stats.file_size_max++;
+        FILE_ERROR("Capture failed: FILE_CAPTURE_MAX, size: %d",fileSize);
         return ERROR_capture(FILE_CAPTURE_MAX);
     }
 
@@ -491,6 +505,7 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
         if (!fileInfo)
         {
             file_capture_stats.file_memcap_failures_reserve++;
+            FILE_ERROR("Capture failed: FILE_CAPTURE_MEMCAP");
             return ERROR_capture(FILE_CAPTURE_MEMCAP);
         }
 
@@ -502,6 +517,7 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
 
     if (!fileInfo)
     {
+        FILE_ERROR("Capture failed: FILE_CAPTURE_MEMCAP");
         return ERROR_capture(FILE_CAPTURE_MEMCAP);
     }
 
@@ -511,6 +527,7 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
     if (_save_to_file_buffer(file_mempool, context, context->current_data,
             context->current_data_len, file_config->file_capture_max_size) )
     {
+        FILE_ERROR("Capture failed: %d",context->file_state.capture_state);
         return ERROR_capture(context->file_state.capture_state);
     }
 
@@ -525,9 +542,13 @@ FileCaptureState file_capture_reserve(void *ssnptr, FileCaptureInfo **file_mem)
      * might use this information to change shared memory buffer
      * that might be released and then used by other sessions
      */
-    context->file_capture = NULL;
-    context->file_capture_enabled = false;
+    if(context->file_state.sig_state != FILE_SIG_FLUSH)
+    {
+        context->file_capture = NULL;
+        context->file_capture_enabled = false;
+    }
     DEBUG_WRAP(verifiy_file_capture(context, fileInfo););
+    FILE_INFO("Capture successful");
 
     return FILE_CAPTURE_SUCCESS;
 }
@@ -548,6 +569,7 @@ void* file_capture_read(FileCaptureInfo *fileInfo, uint8_t **buff, int *size)
 {
     if (!fileInfo || !buff || !size)
     {
+        FILE_ERROR("Failed to read capture");
         return NULL;
     }
 
