@@ -33,7 +33,7 @@
 /* Function prototypes  */
 void set_mime_decode_config_defauts(DecodeConfig *decode_conf);
 void set_mime_log_config_defauts(MAIL_LogConfig *log_config);
-int parse_mime_decode_args(DecodeConfig *decode_conf, char *arg, const char *preproc_name);
+int parse_mime_decode_args(DecodeConfig *decode_conf, char *arg, const char *preproc_name, char **strtok_saveptr);
 bool is_decoding_enabled(DecodeConfig *decode_conf);
 bool is_mime_log_enabled(MAIL_LogConfig *log_config);
 bool check_decode_config(DecodeConfig *currentConfig, DecodeConfig *defaultConfig, const char *preproc_name);
