@@ -40,6 +40,7 @@
 
 #include "stream_api.h"
 #include "reg_test.h"
+#include <file_lib.h>
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
@@ -1104,6 +1105,7 @@ const uint8_t * process_mime_data(void *packet, const uint8_t *start,
     Packet *p = (Packet *)packet;
     FilePosition position = SNORT_FILE_START;
     preprocessor = preproc_name;
+    SAVE_DAQ_PKT_HDR(p);
 
     if (paf_enabled)
     {
