@@ -31,14 +31,15 @@
 #include "mempool.h"
 #include "sfPolicy.h"
 #include "file_mail_common.h"
+#include "memory_stats.h"
 
-int set_log_buffers(MAIL_LogState **log_state, MAIL_LogConfig *conf, void *mempool, void* scbPtr);
+int set_log_buffers(MAIL_LogState **log_state, MAIL_LogConfig *conf, void *mempool, void* scbPtr, uint32_t preproc_id);
 void* init_mime_mempool(int max_mime_mem, int max_depth, void *mempool, const char *preproc_name);
 void* init_log_mempool(uint32_t email_hdrs_log_depth, uint32_t memcap,  void *mempool, const char *preproc_name);
 void init_mime(void);
 void free_mime(void);
 const uint8_t* process_mime_data(void *packet, const uint8_t *start, const uint8_t *end,
-        MimeState *mime_ssn, bool upload, bool paf_enabled, char *preproc_name);
+        MimeState *mime_ssn, bool upload, bool paf_enabled, char *preproc_name, uint32_t preproc_id);
 void free_mime_session(MimeState *mime_ssn);
 void finalize_mime_position(void *ssnptr, void *decode_state, FilePosition *position);
 
