@@ -27,6 +27,7 @@
 #include "config.h"
 #endif
 
+#include <pthread.h>
 #include "file_resume_block.h"
 #include "sf_types.h"
 #include "file_api.h"
@@ -39,6 +40,10 @@
 #include "sf_sechash.h"
 #include "file_config.h"
 #include "file_service.h"
+#include "file_ss.h"
+#include "sidechannel.h"
+#include "file_lib.h"
+
 
 /* The hash table of expected files */
 static SFXHASH *fileHash = NULL;
@@ -46,6 +51,8 @@ extern FileServiceConfig cur_config;
 extern FileContext* get_main_file_context(void *ssnptr);
 
 static FileState sig_file_state = { FILE_CAPTURE_SUCCESS, FILE_SIG_DONE };
+/* this file_cache_mutex is used to synchronize multiple add's to SFXHASH */
+static pthread_mutex_t file_cache_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 typedef struct _FileHashKey
 {
@@ -75,15 +82,23 @@ void file_resume_block_init(void)
 
     if (!fileHash)
         FatalError("Failed to create the expected channel hash table.\n");
+#ifdef SIDE_CHANNEL
+    FileSSConfigInit();
+#endif
 }
 
 void file_resume_block_cleanup(void)
 {
     if (fileHash)
     {
+        pthread_mutex_lock(&file_cache_mutex);
         sfxhash_delete(fileHash);
         fileHash = NULL;
+        pthread_mutex_unlock(&file_cache_mutex);
     }
+#if defined (SIDE_CHANNEL) && defined (REG_TEST)
+    FileCleanSS();
+#endif
 }
 
 static inline void updateFileNode(FileNode *node, File_Verdict verdict,
@@ -96,6 +111,102 @@ static inline void updateFileNode(FileNode *node, File_Verdict verdict,
         memcpy(node->sha256, signature, SHA256_HASH_SIZE);
     }
 }
+#ifdef SIDE_CHANNEL
+static int ProduceSSFileCache(FileHashKey *hk, FileNode *hv)
+{
+    uint32_t offset = 0;
+
+    void *msg_handle = NULL;
+    void *hdr_ptr = NULL;
+    void *data_ptr = NULL;
+    if (!hk || !hv)
+    {
+        return -1;
+    }
+
+    if (CreateFileSSUpdate(&msg_handle, &hdr_ptr, &data_ptr, SC_MSG_TYPE_FILE_SS_HOST_CACHE, sizeof(*hk) + sizeof(*hv)) != 0)
+    {
+        FILE_ERROR("Side channel: Failed to create side channel update");
+        return -1;
+    }
+
+    if (data_ptr)
+    {
+        memcpy(data_ptr, hk, sizeof(*hk));
+        offset += sizeof(*hk);
+
+        memcpy((uint8_t *)data_ptr + offset, hv, sizeof(*hv));
+        offset += sizeof(*hv);
+
+        SendFileSSUpdate(msg_handle, hdr_ptr, data_ptr, SC_MSG_TYPE_FILE_SS_HOST_CACHE, offset);
+    }
+#ifdef REG_TEST
+    LogMessage("produce verdict =%d file id =%d \n",hv->verdict,hv->file_type_id);
+    file_sha256_print(hv->sha256);
+#endif
+    FILE_DEBUG("Side channel: Produce verdict: %d, file id: %d",hv->verdict,hv->file_type_id);
+    return 0;
+}
+
+int ConsumeSSFileCache(const uint8_t *buf, uint32_t len)
+{
+    FileHashKey *hk;
+    FileNode *hv;
+    SFXHASH_NODE *hash_node;
+    FileNode *node;
+
+    if( !buf )
+    {
+        FILE_ERROR("Side channel: No buffer");
+        return -1;
+    }
+
+    if( len < sizeof(*hk) + sizeof(*hv) )
+    {
+        FILE_ERROR("Side channel: length too small");
+        return -1;
+    }
+    hk = (FileHashKey *)buf;
+    hv = (FileNode *)(buf + sizeof(*hk));
+
+    pthread_mutex_lock(&file_cache_mutex);
+    hash_node = sfxhash_find_node(fileHash, hk);
+    if (hash_node)
+    {
+      if (!(node = hash_node->data))
+      {
+        sfxhash_free_node(fileHash, hash_node);
+      }
+    }
+    else
+      node = NULL;
+
+    if (node)
+    {
+      node->expires = hv->expires ;/* 20 minuts timeout*/
+      updateFileNode(node, hv->verdict, hv->file_type_id, hv->sha256);
+    }
+    else if (sfxhash_add(fileHash, hk, hv) != SFXHASH_OK)
+    {
+      /* Uh, shouldn't get here...
+       * There is already a node or couldn't alloc space
+       * for key.  This means bigger problems, but fail
+       * gracefully.
+       */
+      FILE_ERROR("Side channel: Failed to add file node to hash table");
+      pthread_mutex_unlock(&file_cache_mutex);
+      return -1;
+    }
+    pthread_mutex_unlock(&file_cache_mutex);
+#ifdef REG_TEST
+  LogMessage("consume verdict =%d file id =%d \n",hv->verdict,hv->file_type_id);
+  file_sha256_print(hv->sha256);
+#endif
+   FILE_DEBUG("Side channel: Consume verdict: %d file id: %d",hv->verdict,hv->file_type_id); 
+
+    return 0;
+}
+#endif
 
 /** *
  * @param sip - source IP address
@@ -118,6 +229,7 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
     sfaddr_t* dstIP;
     Packet *p = (Packet*)pkt;
     time_t now = p->pkth->ts.tv_sec;
+    SAVE_DAQ_PKT_HDR(p);
 
     srcIP = GET_SRC_IP(p);
     dstIP = GET_DST_IP(p);
@@ -125,14 +237,18 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
     sfaddr_copy_to_raw(&hashKey.sip, srcIP);
     hashKey.file_sig = file_sig;
 
+    pthread_mutex_lock(&file_cache_mutex);
     hash_node = sfxhash_find_node(fileHash, &hashKey);
     if (hash_node)
     {
         if (!(node = hash_node->data))
+        {
             sfxhash_free_node(fileHash, hash_node);
+        }
     }
     else
         node = NULL;
+    pthread_mutex_unlock(&file_cache_mutex);
 
     if ( timeout == 0  && verdict == 0 && file_type_id == 0)
     {
@@ -141,7 +257,10 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
         file_config =  (FileConfig *)(snort_conf->file_config);
         context = get_main_file_context(p->ssnptr);
         if (!context && !node)
+        {
+            FILE_ERROR("Resume block: context and node not found");
             return -1;
+        }
         timeout = (uint32_t)file_config->file_block_timeout;
         if(context)
         {
@@ -178,6 +297,7 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
             }
             else
                 DAQ_Add_Dynamic_Protocol_Channel(p, srcIP, 0, dstIP, p->dp, GET_IPH_PROTO(p), &params);
+            FILE_DEBUG("Pinhole created from client packet, direction: %d, time: %d",direction, now);
         }
         else if (p->packet_flags & PKT_FROM_SERVER)
         {
@@ -190,19 +310,27 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
             }
             else
                 DAQ_Add_Dynamic_Protocol_Channel(p, dstIP, 0, srcIP, p->sp, GET_IPH_PROTO(p), &params);
+            FILE_DEBUG("Pinhole created from server packet, direction: %d, time: %d",direction, now);
         }
     }
 #endif
 
     if (node)
     {
-        node->expires = now + timeout;
+        FILE_DEBUG("Resume block: Updating file node");
+        node->expires = now + (timeout * 4);/* 20 minuts timeout*/
         updateFileNode(node, verdict, file_type_id, signature);
+#ifdef SIDE_CHANNEL
+        if (ProduceSSFileCache(&hashKey, node) < 0)
+        {
+          LogMessage("Failed to add Side channel message\n");
+        }
+#endif
     }
     else
     {
 
-        DEBUG_WRAP(DebugMessage(DEBUG_FILE, "Adding file node\n"););
+        FILE_DEBUG("Resume block: Adding file node");
 
         updateFileNode(&new_node, verdict, file_type_id, signature);
 
@@ -212,9 +340,16 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
          * after that anyway because the file that
          * caused this will be gone.
          */
-        new_node.expires = now + timeout;
+        new_node.expires = now + (timeout * 4);/* 20 minuts timeout*/
 
         /* Add it to the table */
+#ifdef SIDE_CHANNEL
+        if (ProduceSSFileCache(&hashKey, &new_node) < 0)
+        {
+          LogMessage("Failed to add Side channel message\n");
+        }
+#endif
+        pthread_mutex_lock(&file_cache_mutex);
         if (sfxhash_add(fileHash, &hashKey, &new_node) != SFXHASH_OK)
         {
             /* Uh, shouldn't get here...
@@ -222,17 +357,34 @@ int file_resume_block_add_file(void *pkt, uint32_t file_sig, uint32_t timeout,
              * for key.  This means bigger problems, but fail
              * gracefully.
              */
-            DEBUG_WRAP(DebugMessage(DEBUG_FILE,
-                    "Failed to add file node to hash table\n"););
+            FILE_ERROR("Resume block: Failed to add file node to hash table");
+            pthread_mutex_unlock(&file_cache_mutex);
             return -1;
         }
+        pthread_mutex_unlock(&file_cache_mutex);
     }
+    FILE_DEBUG("Resume block: Added file node with verdict: %d, file signature: %d, hash:"
+            "%02X%02X %02X%02X %02X%02X %02X%02X" 
+            "%02X%02X %02X%02X %02X%02X %02X%02X "
+            "%02X%02X %02X%02X %02X%02X %02X%02X "
+            "%02X%02X %02X%02X %02X%02X %02X%02X",
+            verdict, file_sig,
+            signature[0], signature[1], signature[2], signature[3],
+            signature[4], signature[5], signature[6], signature[7],
+            signature[8], signature[9], signature[10], signature[11],
+            signature[12], signature[13], signature[14], signature[15],
+            signature[16], signature[17], signature[18], signature[19],
+            signature[20], signature[21], signature[22], signature[23],
+            signature[24], signature[25], signature[26], signature[27],
+            signature[28], signature[29], signature[30], signature[31]);
     return 0;
 }
 
 static inline File_Verdict checkVerdict(Packet *p, FileNode *node, SFXHASH_NODE *hash_node)
 {
     File_Verdict verdict = FILE_VERDICT_UNKNOWN;
+    FileContext *context = NULL;
+    bool partialFile = false;
 
     /*Query the file policy in case verdict has been changed*/
     /*Check file type first*/
@@ -240,6 +392,7 @@ static inline File_Verdict checkVerdict(Packet *p, FileNode *node, SFXHASH_NODE
     {
         verdict = cur_config.file_type_cb(p, p->ssnptr, node->file_type_id, 0,
                 DEFAULT_FILE_ID);
+        FILE_DEBUG("Checking verdict, node verdict: %d, file type verdict: %d",node->verdict, verdict);
     }
 
     if ((verdict == FILE_VERDICT_UNKNOWN) ||
@@ -247,8 +400,14 @@ static inline File_Verdict checkVerdict(Packet *p, FileNode *node, SFXHASH_NODE
     {
         if (cur_config.file_signature_cb)
         {
+            context = get_main_file_context(p->ssnptr);
+            if(NULL != context)
+            {
+                partialFile = context->partial_file;
+            }
             verdict = cur_config.file_signature_cb(p, p->ssnptr, node->sha256, 0,
-                    &sig_file_state, 0, DEFAULT_FILE_ID);
+                    &sig_file_state, 0, DEFAULT_FILE_ID, partialFile );
+            FILE_DEBUG("Checking verdict, node verdict: %d, file signature verdict: %d",node->verdict, verdict);
         }
     }
 
@@ -260,7 +419,9 @@ static inline File_Verdict checkVerdict(Packet *p, FileNode *node, SFXHASH_NODE
 
     if (verdict == FILE_VERDICT_LOG)
     {
+        pthread_mutex_lock(&file_cache_mutex);
         sfxhash_free_node(fileHash, hash_node);
+        pthread_mutex_unlock(&file_cache_mutex);
         if (cur_config.log_file_action)
         {
             cur_config.log_file_action(p->ssnptr, FILE_RESUME_LOG);
@@ -304,6 +465,19 @@ static inline File_Verdict checkVerdict(Packet *p, FileNode *node, SFXHASH_NODE
         }
         verdict = node->verdict;
     }
+    FILE_DEBUG("Verdict checked for file node with hash: " 
+            "%02X%02X %02X%02X %02X%02X %02X%02X" 
+            "%02X%02X %02X%02X %02X%02X %02X%02X "
+            "%02X%02X %02X%02X %02X%02X %02X%02X "
+            "%02X%02X %02X%02X %02X%02X %02X%02X",
+            node->sha256[0], node->sha256[1], node->sha256[2], node->sha256[3],
+            node->sha256[4], node->sha256[5], node->sha256[6], node->sha256[7],
+            node->sha256[8], node->sha256[9], node->sha256[10], node->sha256[11],
+            node->sha256[12], node->sha256[13], node->sha256[14], node->sha256[15],
+            node->sha256[16], node->sha256[17], node->sha256[18], node->sha256[19],
+            node->sha256[20], node->sha256[21], node->sha256[22], node->sha256[23],
+            node->sha256[24], node->sha256[25], node->sha256[26], node->sha256[27],
+            node->sha256[28], node->sha256[29], node->sha256[30], node->sha256[31]);
 
     return verdict;
 }
@@ -317,11 +491,12 @@ File_Verdict file_resume_block_check(void *pkt, uint32_t file_sig)
     FileHashKey hashKey;
     FileNode *node;
     Packet *p = (Packet*)pkt;
+    SAVE_DAQ_PKT_HDR(pkt);
 
     /* No hash table, or its empty?  Get out of dodge.  */
     if (!fileHash || !sfxhash_count(fileHash))
     {
-        DEBUG_WRAP(DebugMessage(DEBUG_FILE, "No expected sessions\n"););
+        FILE_DEBUG("No expected sessions");
         return verdict;
     }
 
@@ -331,23 +506,33 @@ File_Verdict file_resume_block_check(void *pkt, uint32_t file_sig)
     sfaddr_copy_to_raw(&hashKey.sip, srcIP);
     hashKey.file_sig = file_sig;
 
+    pthread_mutex_lock(&file_cache_mutex);
     hash_node = sfxhash_find_node(fileHash, &hashKey);
-
+  
     if (hash_node)
     {
         if (!(node = hash_node->data))
+        {
             sfxhash_free_node(fileHash, hash_node);
+        }
     }
     else
+    {
+        pthread_mutex_unlock(&file_cache_mutex);
+        FILE_DEBUG("File not found");
         return verdict;
+    }
+    pthread_mutex_unlock(&file_cache_mutex);
 
     if (node)
     {
-        DEBUG_WRAP(DebugMessage(DEBUG_FILE, "Found resumed file\n"););
+        FILE_DEBUG("Found resumed file");
         if (node->expires && p->pkth->ts.tv_sec > node->expires)
         {
-            DEBUG_WRAP(DebugMessage(DEBUG_FILE, "File expired\n"););
+            FILE_DEBUG("File expired, verdict: %d",verdict);
+            pthread_mutex_lock(&file_cache_mutex);
             sfxhash_free_node(fileHash, hash_node);
+            pthread_mutex_unlock(&file_cache_mutex);
             return verdict;
         }
         /*Query the file policy in case verdict has been changed*/
@@ -359,6 +544,9 @@ File_Verdict file_resume_block_check(void *pkt, uint32_t file_sig)
             addPktTraceData(VERDICT_REASON_FILE, snprintf(trace_line, MAX_TRACE_LINE,
                 "File Process: file not resumed, %s\n", getPktTraceActMsg()));
         else addPktTraceData(VERDICT_REASON_FILE, 0);
+        FILE_INFO("File not resumed, verdict: %d",verdict);
     }
+    else
+        FILE_INFO("File resumed, verdict: %d",verdict);
     return verdict;
 }
