@@ -698,7 +698,7 @@ int file_segment_process( FileCache *fileCache, void* p, uint64_t file_id,
 resume_block:
     verdict = fileEntry->context->verdict;
     /* Add to resume queue if it is blocked */
-    if(verdict == FILE_VERDICT_BLOCK || verdict == FILE_VERDICT_REJECT || verdict == FILE_VERDICT_PENDING)
+    if((verdict == FILE_VERDICT_BLOCK) || (verdict == FILE_VERDICT_REJECT))
     {
         FileConfig *file_config =  (FileConfig *)(snort_conf->file_config);
         if(fileEntry->file_name_size > 0)
