@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2008-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -94,7 +94,8 @@ void file_cache_set_memcap(FileCache *fileCache, uint64_t memcap);
 
 /* Add/update a file entry in the file cache*/
 void *file_cache_update_entry (FileCache *fileCache, void* p, uint64_t file_id,
-        uint8_t *file_name, uint32_t file_name_size, uint64_t file_size, bool reset);
+        uint8_t *file_name, uint32_t file_name_size, uint64_t file_size, bool reset, 
+        bool no_update_size);
 
 /* Process file segments with offset specified. If file segment is out of order,
  * it will be put into the file seglist. Otherwise, it will be processed.
