@@ -94,6 +94,7 @@ static void render_block_verdict(void *ctx, void *p);
 static bool is_file_service_enabled(void);
 static uint32_t get_file_type_id(void *ssnptr);
 static uint32_t get_new_file_instance(void *ssnptr);
+static void set_file_partial(void *p, FilePosition position, bool upload, bool is_partial);
 
 /* File context based file processing*/
 FileContext* create_file_context(void *ssnptr);
@@ -195,6 +196,7 @@ void init_fileAPI(void)
     fileAPI.file_cache_set_memcap = &file_cache_set_memcap;
     fileAPI.file_event_log_dump = &file_event_log_dump;
     fileAPI.file_signature_reset= &file_signature_reset;
+    fileAPI.set_file_partial = &set_file_partial;
     file_api = &fileAPI;
     init_mime();
 }
@@ -305,7 +307,10 @@ FileContext* get_current_file_context(void *ssnptr)
     if (file_session)
         return file_session->current_context;
     else
+    {
+        FILE_WARNING("Failed to get current file context: file session not found");
         return NULL;
+    }
 }
 
 /*Get the current main file context*/
@@ -315,7 +320,10 @@ FileContext* get_main_file_context(void *ssnptr)
     if (file_session)
         return file_session->main_context;
     else
+    {
+        FILE_WARNING("Failed to get main file context: file session not found");
         return NULL;
+    }
 }
 
 /*Get the current working file context*/
@@ -345,6 +353,7 @@ bool set_current_file_context(void *ssnptr, FileContext *ctx)
 
     if (!file_session)
     {
+        FILE_WARNING("Failed to set current file context: file session not found");
         return false;
     }
 
@@ -380,6 +389,8 @@ static void init_file_context(void *ssnptr, bool upload, FileContext *context)
     context->file_capture_enabled = cur_config.file_capture_enabled;
     context->file_config = snort_conf->file_config;
     context->file_config_version = file_config_version;
+    context->smb_unknown_file_size = false;
+    context->partial_file = false;
     file_direction_set(context,upload);
     file_stats.files_total++;
 #ifdef TARGET_BASED
@@ -411,6 +422,7 @@ FileContext* create_file_context(void *ssnptr)
 
     /* Create file session if not yet*/
     get_create_file_session (ssnptr);
+    FILE_DEBUG("Successfully created file context %p",context);
 
     return context;
 }
@@ -427,8 +439,8 @@ static inline FileContext* find_main_file_context(void* p, FilePosition position
     if (file_session)
         context  = file_session->main_context;
 
-    if (context && ((position == SNORT_FILE_MIDDLE) ||
-            (position == SNORT_FILE_END)))
+    if (context && (((position == SNORT_FILE_MIDDLE) || (position == SNORT_FILE_END)) ||
+                ((context->partial_file) && (SNORT_FILE_START == position))))
         return context;
     else if (context)
     {
@@ -446,6 +458,7 @@ static inline FileContext* find_main_file_context(void* p, FilePosition position
             file_context_reset(context);
             init_file_context(ssnptr, upload, context);
             context->file_id = file_session->max_file_id++;
+            FILE_DEBUG("Reusing existing context from last session");
             return context;
         }
     }
@@ -462,12 +475,16 @@ static inline void updateFileSize(FileContext* context, int data_size,
         FilePosition position)
 {
     context->processed_bytes += data_size;
-    if ((position == SNORT_FILE_END) || (position == SNORT_FILE_FULL))
+    if ((position == SNORT_FILE_END) || (position == SNORT_FILE_FULL) || (context->file_state.sig_state == FILE_SIG_FLUSH))
     {
         if (get_max_file_depth(snort_conf, false) == (int64_t)context->processed_bytes)
             context->file_size = 0;
         else
             context->file_size = context->processed_bytes;
+    }
+    FILE_DEBUG("Processed bytes: %u, Updated file size is: %u " ,context->processed_bytes, context->file_size);
+    if((SNORT_FILE_FULL == position) || (SNORT_FILE_END == position))
+    {
         context->processed_bytes = 0;
     }
 }
@@ -479,11 +496,15 @@ int file_eventq_add(uint32_t gid, uint32_t sid, char *msg, RuleType type)
 
     otn = GetApplicableOtn(gid, sid, 1, 0, 3, msg);
     if (otn == NULL)
+    {
+        FILE_ERROR("Failed to add event: no otn");
         return 0;
 
+    }
     rtn = getRtnFromOtn(otn, getIpsRuntimePolicy());
     if (rtn == NULL)
     {
+        FILE_ERROR("Failed to add event: no rtn");
         return 0;
     }
 
@@ -514,6 +535,7 @@ static inline void add_file_to_block(Packet *p, File_Verdict verdict,
                 (uint32_t)file_config->file_block_timeout,
                 verdict, file_type_id, signature, 0, 0, true, 0);
     }
+    FILE_INFO("File blocked");
     if (pkt_trace_enabled)
         addPktTraceData(VERDICT_REASON_FILE, snprintf(trace_line, MAX_TRACE_LINE,
             "File Process: %s %s\n", getPktTraceActMsg(), (buf && len)? (char *)buf : ""));
@@ -548,6 +570,7 @@ static inline int check_http_partial_content(Packet *p)
         file_sig = str_to_hash(buf, len);
         file_resume_block_check(p, file_sig);
     }
+    FILE_DEBUG("HTTP partial content header found");
 
     return 1;
 }
@@ -564,12 +587,14 @@ static inline void _file_signature_lookup(FileContext* context,
 
     if (cur_config.file_signature_cb)
     {
+        FILE_DEBUG("Doing file signature callback...");
         verdict = cur_config.file_signature_cb(p, ssnptr, context->sha256,
                 context->file_size, &(context->file_state), context->upload,
-                context->file_id);
+                context->file_id, context->partial_file);
         if(context->file_state.sig_state != FILE_SIG_FLUSH)
             file_stats.verdicts_signature[verdict]++;
     }
+    FILE_INFO("File Signature lookup verdict: %d", verdict);
 
     if (suspend_block_verdict)
         context->suspend_block_verdict = true;
@@ -601,6 +626,7 @@ static inline void _file_signature_lookup(FileContext* context,
                         GENERATOR_FILE_SIGNATURE, FILE_SIGNATURE_SHA256, getPktTraceActMsg()));
                 }
                 else addPktTraceData(VERDICT_REASON_FILE, 0);
+                FILE_INFO("Malware detected");
                 return;
             }
             /*Timeout, let packet go through OR block based on config*/
@@ -678,6 +704,7 @@ static void render_block_verdict(void *ctx, void *p)
 {
     FileContext *context = (FileContext *)ctx;
     Packet *pkt = (Packet *)p;
+    SAVE_DAQ_PKT_HDR(p);
 
     if (p == NULL)
         return;
@@ -735,6 +762,7 @@ static uint32_t get_new_file_instance(void *ssnptr)
 static void file_signature_lookup(void* p, bool is_retransmit)
 {
     Packet *pkt = (Packet *)p;
+    SAVE_DAQ_PKT_HDR(p);
 
     FileContext* context  = get_current_file_context(pkt->ssnptr);
 
@@ -751,12 +779,19 @@ static void file_signature_callback(Packet* p)
     void *ssnptr = pkt->ssnptr;
     FileSession *file_session;
     FileEntry *fileEntry;
+    SAVE_DAQ_PKT_HDR(p);
 
     if (!ssnptr)
+    {
+        FILE_ERROR("Signature callback failed: no session");
         return;
+    }
     file_session = get_file_session (ssnptr);
     if (!file_session)
+    {
+        FILE_ERROR("Signature callback failed: no file session");
         return;
+    }
 
     if(file_session->file_cache)
     {
@@ -795,6 +830,7 @@ static int process_file_context(FileContext *context, void *p, uint8_t *file_dat
     Packet *pkt = (Packet *)p;
     void *ssnptr = pkt->ssnptr;
     bool file_capture_enabled = false;
+    SAVE_DAQ_PKT_HDR(p);
 
     if (!context)
         return 0;
@@ -806,6 +842,7 @@ static int process_file_context(FileContext *context, void *p, uint8_t *file_dat
     if ((!context->file_type_enabled) && (!context->file_signature_enabled))
     {
         updateFileSize(context, data_size, position);
+        FILE_DEBUG("Signature and Type lookup not enabled");
         return 0;
     }
 
@@ -819,6 +856,7 @@ static int process_file_context(FileContext *context, void *p, uint8_t *file_dat
          * File type id will become UNKNOWN after file_type_id()
          * if in the middle of file and file type is CONTINUE (undecided) */
         context->file_type_context = NULL;
+        FILE_DEBUG("Updated file config.");
     }
 
     if(check_http_partial_content(p))
@@ -834,6 +872,7 @@ static int process_file_context(FileContext *context, void *p, uint8_t *file_dat
         File_Verdict verdict = FILE_VERDICT_UNKNOWN;
 
         file_type_id(context, file_data, data_size, position);
+        FILE_DEBUG("File type ID: %u", context->file_type_id);
 
         /*Don't care unknown file type*/
         if (context->file_type_id == SNORT_FILE_TYPE_UNKNOWN)
@@ -849,8 +888,10 @@ static int process_file_context(FileContext *context, void *p, uint8_t *file_dat
         {
             if (cur_config.file_type_cb)
             {
+                FILE_DEBUG("Doing file type callback...");
                 verdict = cur_config.file_type_cb(p, ssnptr, context->file_type_id,
                         context->upload, context->file_id);
+                FILE_INFO("File type verdict: %d",verdict);
                 file_stats.verdicts_type[verdict]++;
                 context->verdict = verdict;
             }
@@ -957,14 +998,23 @@ static int file_process( void* p, uint8_t* file_data, int data_size,
         FilePosition position, bool upload, bool suspend_block_verdict, bool do_flush)
 {
     FileContext* context;
+    SAVE_DAQ_PKT_HDR(p);
+    int fileverdict;
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+    uint64_t start = 0, end = 0;
+#endif    
+
+    FILE_DEBUG("Processing file data:: size:%d, position:%d, direction:%d, flush:%d",data_size,position,upload,do_flush);
 
     /* if both disabled, return immediately*/
     if (!is_file_service_enabled())
+    {
+        FILE_DEBUG("File service not enabled.");
         return 0;
+    }
 
     if (position == SNORT_FILE_POSITION_UNKNOWN)
         return 0;
-
     FILE_REG_DEBUG_WRAP(DumpHexFile(stdout, file_data, data_size);)
 
     context = find_main_file_context(p, position, upload);
@@ -979,8 +1029,23 @@ static int file_process( void* p, uint8_t* file_data, int data_size,
     {
         context->file_state.sig_state = FILE_SIG_PROCESSING;
     }
-    return process_file_context(context, p, file_data, data_size, position,
-            suspend_block_verdict);
+
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+    Packet *pkt = (Packet *)p;
+    if ( pkt && pkt->pkth && (pkt->pkth->flags & DAQ_PKT_FLAG_DEBUG_ON))
+    {
+       get_clockticks(start);
+       fileverdict = process_file_context(context, p, file_data, data_size, position,suspend_block_verdict);
+       get_clockticks(end);
+       print_flow(p,"PROCESS_FILE_CONTEXT",0,start,end);
+    }
+    else
+       fileverdict = process_file_context(context, p, file_data, data_size, position,suspend_block_verdict);
+#else
+    fileverdict = process_file_context(context, p, file_data, data_size, position,suspend_block_verdict);
+#endif
+
+    return fileverdict;
 }
 
 static void set_file_name (void* ssnptr, uint8_t* fname, uint32_t name_size,
@@ -991,6 +1056,19 @@ static void set_file_name (void* ssnptr, uint8_t* fname, uint32_t name_size,
     FILE_REG_DEBUG_WRAP(printFileContext(context);)
 }
 
+/*
+ *  set_file_partial API, used to mark a file partial/incomplete.
+ *  This information is required by FW signature lookup for FTP PP
+ *  See CSCvi28409 for more details.
+ */
+static void set_file_partial(void *p, FilePosition position,bool upload, bool is_partial)
+{
+    SAVE_DAQ_PKT_HDR(p);
+    FileContext *context = find_main_file_context(p,position,upload);
+    FILE_DEBUG("Partial file: %d",is_partial);
+    context->partial_file = is_partial;
+}
+
 /* Return 1: file name available,
  *        0: file name is unavailable
  */
@@ -1149,6 +1227,7 @@ static FilePosition get_file_position(void *pkt)
 {
     FilePosition position = SNORT_FILE_POSITION_UNKNOWN;
     Packet *p = (Packet *)pkt;
+    SAVE_DAQ_PKT_HDR(p);
 
     if(ScPafEnabled())
     {
@@ -1181,14 +1260,12 @@ static bool check_paf_abort(void* ssn)
     uint32_t flags = session_api->get_session_flags(ssn);
     if (flags & SSNFLAG_MIDSTREAM)
     {
-        DEBUG_WRAP(DebugMessage(DEBUG_FILE,
-                "Aborting PAF because of midstream pickup.\n"));
+        FILE_DEBUG("Aborting PAF because of midstream pickup.");
         return true;
     }
     else if (!(flags & SSNFLAG_ESTABLISHED))
     {
-        DEBUG_WRAP(DebugMessage(DEBUG_FILE,
-                "Aborting PAF because of unestablished session.\n"));
+        FILE_DEBUG("Aborting PAF because of unestablished session.");
         return true;
     }
     return false;
@@ -1311,7 +1388,10 @@ static void file_signature_reset (void *ssnptr)
         context = file_session->main_context;
 
     if (!context)
+    {
+        FILE_ERROR("Faild to reset signature state: context not found.");
         return;
+    }
 
     if (context->file_state.sig_state == FILE_SIG_FLUSH)
     {
@@ -1324,6 +1404,10 @@ static void file_signature_reset (void *ssnptr)
             context->sha256 = NULL;
         }
     }
+    else
+    {
+        FILE_DEBUG("Did not reset signature state: current state %d",context->file_state.sig_state);
+    }
     return;
 }
 
