@@ -56,5 +56,12 @@ void close_fileAPI(void);
 
 /* Get current file context */
 FileContext* get_current_file_context(void *ssnptr);
-#endif
 
+/* Check and set the sidechannel to file cache sync */
+#if defined (SIDE_CHANNEL)
+void check_sidechannel_enabled(void *file_config);
+#ifdef REG_TEST
+void FileSSConfigFree(void *file_config);
+#endif
+#endif
+#endif
