@@ -42,6 +42,7 @@
 #include "file_config.h"
 #include "file_lib.h"
 #include "file_capture.h"
+#include "file_ss.h"
 
 #define FILE_SERVICE_OPT__TYPE_DEPTH            "file_type_depth"
 #define FILE_SERVICE_OPT__SIG_DEPTH             "file_signature_depth"
@@ -401,6 +402,16 @@ void file_service_config(struct _SnortConfig* sc, char *args, void *conf)
             if (file_config->show_data_depth == 0)
                 file_config->show_data_depth = FILE_SERVICE_SIG_DEPTH_MAX;
         }
+#endif
+#if defined (SIDE_CHANNEL) && defined (REG_TEST)
+        else if(!strcasecmp(opts[0], "ss_startup_input_file"))
+        {
+            file_config->file_ss_config->startup_input_file = strdup(opts[1]);
+        }
+        else if(!strcasecmp(opts[0], "ss_runtime_output_file"))
+        {
+            file_config->file_ss_config->runtime_output_file = strdup(opts[1]);
+        }
 #endif
         else
         {
