@@ -236,7 +236,10 @@ void file_name_set (FileContext *context, uint8_t *file_name, uint32_t name_size
 {
     uint8_t *name = file_name;
     if (!context)
+    {
+        FILE_ERROR("Failed to set file name: no context");
         return;
+    }
     if (save_in_context)
     {
         if (context->file_name && context->file_name_saved)
@@ -256,22 +259,35 @@ void file_name_set (FileContext *context, uint8_t *file_name, uint32_t name_size
 int file_name_get (FileContext *context, uint8_t **file_name, uint32_t *name_size)
 {
     if (!context)
+    {
+        FILE_ERROR("Failed to fetch file name: no context");
         return 0;
+    }
     if (file_name)
         *file_name = context->file_name;
     else
+    {
+        FILE_ERROR("Failed to fetch file name: name parameter NULL");
         return 0;
+    }
     if (name_size)
         *name_size = context->file_name_size;
     else
+    {
+        FILE_ERROR("Failed to fetch file name: size parameter NULL");
         return 0;
+    }
+    FILE_DEBUG("File name fetched from context: %s, size %d",(char*)(*file_name),*name_size);
     return 1;
 }
 
 void file_size_set (FileContext *context, uint64_t file_size)
 {
     if (!context)
+    {
+        FILE_ERROR("Failed to set file size: no context");
         return;
+    }
     context->file_size = file_size;
 
 }
@@ -279,7 +295,11 @@ void file_size_set (FileContext *context, uint64_t file_size)
 uint64_t file_size_get (FileContext *context)
 {
     if (!context)
+    {
+        FILE_ERROR("Failed to fetch file size: no context");
         return 0;
+    }
+    FILE_DEBUG("File size fetched from context: %d",context->file_size);
     return (context->file_size);
 }
 
