@@ -36,6 +36,7 @@
 #include "sf_types.h" /* for bool */
 
 #include "file_api.h"
+#include "sfdaq.h"
 
 #define SNORT_FILE_TYPE_UNKNOWN          1024  /**/
 #define SNORT_FILE_TYPE_CONTINUE         0 /**/
@@ -88,9 +89,16 @@ typedef struct _FileContext
     uint32_t current_data_len;
     File_Verdict verdict;
     bool suspend_block_verdict;
+    /* for some SMB upload cases, file size is not known during SMB negotiation. We are setting 
+     * SIG_FLUSH during end of stream, but END of file is not set in case of SMB unknown 
+     * file size upload. This causing file capture to fail. This flag is used to set End of file, 
+     * only for SMB upload cases.
+     */
+    bool smb_unknown_file_size;
     FileState file_state;
     uint32_t file_id;
     uint32_t file_config_version;
+    bool partial_file;
 } FileContext;
 
 /*Main File Processing functions */
@@ -128,5 +136,35 @@ extern int64_t file_signature_depth;
 #if defined(DEBUG_MSGS) || defined (REG_TEST)
 void file_sha256_print(unsigned char *hash);
 #endif
+
+#if defined (DAQ_VERSION) && DAQ_VERSION > 9
+const DAQ_PktHdr_t* daq_pktHdr;
+#define SAVE_DAQ_PKT_HDR(p) daq_pktHdr = ((Packet*)(p))->pkth
+#define FILE_PKT_DEBUG(logLevel, msg, args...)\
+    SNORT_DEBUG_PKT_LOG(daq_pktHdr,DAQ_DEBUG_PKT_MODULE_SNORTFILEPP,logLevel, msg, ##args)
+
+#define FILE_EMERGENCY(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_EMERGENCY,msg,##args) 
+#define FILE_ALERT(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_ALERT,msg,##args)
+#define FILE_CRITICAL(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_CRITICAL,msg,##args)
+#define FILE_ERROR(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_ERROR,msg,##args)
+#define FILE_WARNING(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_WARNING,msg,##args)
+#define FILE_NOTICE(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_NOTICE,msg,##args)
+#define FILE_INFO(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_INFO,msg,##args)
+#define FILE_DEBUG(msg,args...) FILE_PKT_DEBUG(DAQ_DEBUG_PKT_LEVEL_DEBUG,msg,##args)
+
+#else
+
+#define FILE_LOG_MSGS(msg, args...) DEBUG_WRAP(DebugMessage(DEBUG_FILE, msg"\n", ##args);)
+#define FILE_EMERGENCY(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_ALERT(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_CRITICAL(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_ERROR(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_WARNING(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_NOTICE(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_INFO(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define FILE_DEBUG(msg,args...) FILE_LOG_MSGS(msg,##args)
+#define SAVE_DAQ_PKT_HDR(p)
+#endif
+
 #endif
 
