@@ -417,10 +417,26 @@ static int PrintObfuscatedData(FILE* fp, Packet *p)
     {
         uint8_t buf[UINT16_MAX];
         uint16_t dlen = p->data - p->pkt;
+        int ret;
 
-        SafeMemcpy(buf, p->pkt, dlen, buf, buf + sizeof(buf));
-        SafeMemcpy(buf + dlen, payload, payload_len,
+        ret = SafeMemcpy(buf, p->pkt, dlen, buf, buf + sizeof(buf));
+        if (ret != SAFEMEM_SUCCESS) 
+        {
+           DEBUG_WRAP(DebugMessage(DEBUG_LOG,
+                   "%s: SafeMemcpy() Failed !!!",  __FUNCTION__);)
+           free(payload);
+           return -1;
+        }
+
+        ret = SafeMemcpy(buf + dlen, payload, payload_len,
                 buf, buf + sizeof(buf));
+        if (ret != SAFEMEM_SUCCESS)
+        {
+            DEBUG_WRAP(DebugMessage(DEBUG_LOG,
+                    "%s: SafeMemcpy() Failed !!!",  __FUNCTION__);)
+            free(payload);
+            return -1;
+        }
 
         PrintNetData(fp, buf, dlen + payload_len, NULL);
     }
