@@ -673,7 +673,7 @@ static void LogOuterIPHeader(TextLog *log, Packet *p)
     IP4Hdr *save_ip4h = p->ip4h;
     IP6Hdr *save_ip6h = p->ip6h;
     uint8_t save_frag_flag = p->frag_flag;
-    uint16_t save_sp, save_dp;
+    uint16_t save_sp = 0, save_dp = 0;
 
     p->family = p->outer_family;
     p->iph_api = p->outer_iph_api;
@@ -1612,10 +1612,26 @@ static int LogObfuscatedData(TextLog* log, Packet *p)
     {
         uint8_t buf[UINT16_MAX];
         uint16_t dlen = p->data - p->pkt;
+        int ret;
 
-        SafeMemcpy(buf, p->pkt, dlen, buf, buf + sizeof(buf));
-        SafeMemcpy(buf + dlen, payload, payload_len,
+        ret = SafeMemcpy(buf, p->pkt, dlen, buf, buf + sizeof(buf));
+        if (ret != SAFEMEM_SUCCESS)
+        {
+            DEBUG_WRAP(DebugMessage(DEBUG_LOG,
+                    "%s: SafeMemcpy() Failed !!!",  __FUNCTION__);)
+            free(payload);
+            return -1;
+        }
+
+        ret = SafeMemcpy(buf + dlen, payload, payload_len,
                 buf, buf + sizeof(buf));
+        if (ret != SAFEMEM_SUCCESS)
+        {
+            DEBUG_WRAP(DebugMessage(DEBUG_LOG,
+                    "%s: SafeMemcpy() Failed !!!",  __FUNCTION__);)
+            free(payload);
+            return -1;
+        }
 
         LogNetData(log, buf, dlen + payload_len, NULL);
     }
