@@ -213,116 +213,61 @@ bool pktTracerDebugCheck(Packet* p)
     if (!pkt_trace_cli_flag || !p || !(p->iph_api))
         return pkt_trace_enabled_by_lina;
 
-    StreamSessionKey local_key;
-    memset(&local_key, 0, sizeof(local_key));
     sfaddr_t *src = GET_SRC_IP(p);
     sfaddr_t *dst = GET_DST_IP(p);
-    uint16_t srcPort = p->sp;
-    uint16_t dstPort = p->dp;
-    uint16_t sport, dport;
+    uint16_t sport = p->sp;
+    uint16_t dport = p->dp;
+#ifdef DAQ_CAPA_VRF
+    uint16_t sAsId = DAQ_GetSourceAddressSpaceID(p->pkth);
+    uint16_t dAsId = DAQ_GetDestinationAddressSpaceID(p->pkth);
+#endif
 
-    StreamSessionKey *key = &local_key;
-    key->protocol = (uint8_t) GET_IPH_PROTO(p);
-    switch (key->protocol)
+    uint8_t protocol = GET_IPH_PROTO(p);
+    switch (protocol)
     {
         case IPPROTO_TCP:
         case IPPROTO_UDP:
-            sport = srcPort;
-            dport = dstPort;
             break;
         case IPPROTO_ICMP:
-            if (srcPort == ICMP_ECHOREPLY)
+            if (sport == ICMP_ECHOREPLY)
             {
                 dport = ICMP_ECHO; /* Treat ICMP echo reply the same as request */
                 sport = 0;
             }
             else /* otherwise, every ICMP type gets different key */
-            {
-                sport = srcPort;
                 dport = 0;
-            }
             break;
         case IPPROTO_ICMPV6:
-            if (srcPort == ICMP6_REPLY)
+            if (sport == ICMP6_REPLY)
             {
                 dport = ICMP6_ECHO; /* Treat ICMPv6 echo reply the same as request */
                 sport = 0;
             }
             else /* otherwise, every ICMP type gets different key */
-            {
-                sport = srcPort;
                 dport = 0;
-            }
             break;
         default:
             sport = dport = 0;
             break;
     }
 
-    if (sfip_fast_lt6(src, dst))
-    {
-        COPY4(key->ip_l, sfaddr_get_ip6_ptr(src));
-        key->port_l = sport;
-        COPY4(key->ip_h, sfaddr_get_ip6_ptr(dst));
-        key->port_h = dport;
-    }
-    else if (sfip_fast_eq6(src, dst))
-    {
-        COPY4(key->ip_l, sfaddr_get_ip6_ptr(src));
-        COPY4(key->ip_h, sfaddr_get_ip6_ptr(dst));
-        if (sport < dport)
-        {
-            key->port_l = sport;
-            key->port_h = dport;
-        }
-        else
-        {
-            key->port_l = dport;
-            key->port_h = sport;
-        }
-    }
-    else
-    {
-        COPY4(key->ip_l, sfaddr_get_ip6_ptr(dst));
-        key->port_l = dport;
-        COPY4(key->ip_h, sfaddr_get_ip6_ptr(src));
-        key->port_h = sport;
-    }
-
-    if ((!pkt_tracer_debug_info.protocol || pkt_tracer_debug_info.protocol == key->protocol) &&
-        (((!pkt_tracer_debug_info.sport || pkt_tracer_debug_info.sport == key->port_l) &&
-          (!pkt_tracer_debug_info.sip_flag || memcmp(&pkt_tracer_debug_info.sip, key->ip_l, sizeof(pkt_tracer_debug_info.sip)) == 0) &&
-          (!pkt_tracer_debug_info.dport || pkt_tracer_debug_info.dport == key->port_h) &&
-          (!pkt_tracer_debug_info.dip_flag || memcmp(&pkt_tracer_debug_info.dip, key->ip_h, sizeof(pkt_tracer_debug_info.dip)) == 0)) ||
-         ((!pkt_tracer_debug_info.sport || pkt_tracer_debug_info.sport == key->port_h) &&
-           (!pkt_tracer_debug_info.sip_flag || memcmp(&pkt_tracer_debug_info.sip, key->ip_h, sizeof(pkt_tracer_debug_info.sip)) == 0) &&
-           (!pkt_tracer_debug_info.dport || pkt_tracer_debug_info.dport == key->port_l) &&
-           (!pkt_tracer_debug_info.dip_flag || memcmp(&pkt_tracer_debug_info.dip, key->ip_l, sizeof(pkt_tracer_debug_info.dip)) == 0))))
+    if ((!pkt_tracer_debug_info.protocol || pkt_tracer_debug_info.protocol == protocol) &&
+        (((!pkt_tracer_debug_info.sport || pkt_tracer_debug_info.sport == sport) &&
+          (!pkt_tracer_debug_info.sip_flag || memcmp(&pkt_tracer_debug_info.sip, src, sizeof(pkt_tracer_debug_info.sip)) == 0) &&
+          (!pkt_tracer_debug_info.dport || pkt_tracer_debug_info.dport == dport) &&
+          (!pkt_tracer_debug_info.dip_flag || memcmp(&pkt_tracer_debug_info.dip, dst, sizeof(pkt_tracer_debug_info.dip)) == 0)) ||
+         ((!pkt_tracer_debug_info.sport || pkt_tracer_debug_info.sport == dport) &&
+           (!pkt_tracer_debug_info.sip_flag || memcmp(&pkt_tracer_debug_info.sip, dst, sizeof(pkt_tracer_debug_info.sip)) == 0) &&
+           (!pkt_tracer_debug_info.dport || pkt_tracer_debug_info.dport == sport) &&
+           (!pkt_tracer_debug_info.dip_flag || memcmp(&pkt_tracer_debug_info.dip, src, sizeof(pkt_tracer_debug_info.dip)) == 0))))
     {
         int af;
-        const struct in6_addr* sip;
-        const struct in6_addr* dip;
+        const struct in6_addr* sip = (const struct in6_addr*)src;
+        const struct in6_addr* dip = (const struct in6_addr*)dst;
         unsigned offset;
-        uint16_t sport;
-        uint16_t dport;
         char sipstr[INET6_ADDRSTRLEN];
         char dipstr[INET6_ADDRSTRLEN];
 
-        if (p->packet_flags & PKT_FROM_CLIENT)
-        {
-            sip = (const struct in6_addr*)key->ip_l;
-            dip = (const struct in6_addr*)key->ip_h;
-            sport = key->port_l;
-            dport = key->port_h;
-        }
-        else
-        {
-            sip = (const struct in6_addr*)key->ip_h;
-            dip = (const struct in6_addr*)key->ip_l;
-            sport = key->port_h;
-            dport = key->port_l;
-        }
-
         sipstr[0] = 0;
         if (sip->s6_addr32[0] || sip->s6_addr32[1] || sip->s6_addr16[4] || (sip->s6_addr16[5] && sip->s6_addr16[5] != 0xFFFF))
         {
@@ -347,8 +292,14 @@ bool pktTracerDebugCheck(Packet* p)
             offset = 12;
         }
         inet_ntop(af, &dip->s6_addr[offset], dipstr, sizeof(dipstr));
+#ifdef DAQ_CAPA_VRF
+        snprintf(pkt_tracer_debug_session, DEBUG_SESSION_ID_SIZE, "%s-%u - %s-%u %u AS %u-%u",
+                 sipstr, (unsigned)sport, dipstr, (unsigned)dport, (unsigned)protocol,
+                 sAsId, dAsId);
+#else
         snprintf(pkt_tracer_debug_session, DEBUG_SESSION_ID_SIZE, "%s-%u - %s-%u %u",
-            sipstr, (unsigned)sport, dipstr, (unsigned)dport, (unsigned)key->protocol);
+                 sipstr, (unsigned)sport, dipstr, (unsigned)dport, (unsigned)protocol);
+#endif
         pkt_trace_enabled_by_clish = true;
         return true;
     }
@@ -401,21 +352,6 @@ void addPktTraceData(int reason, int traceLen)
 
     if (traceLen <= 0) return;
 
-    if (module == VERDICT_REASON_SSNSTR) // update debug session string
-    {
-        if (traceLen >= DEBUG_SESSION_ID_SIZE)
-        {
-            strncpy(pkt_tracer_debug_session, trace_line, DEBUG_SESSION_ID_SIZE-1);
-            pkt_tracer_debug_session[DEBUG_SESSION_ID_SIZE-1] = '\0';
-        }
-        else
-        {
-            strncpy(pkt_tracer_debug_session, trace_line, traceLen);
-            pkt_tracer_debug_session[traceLen] = '\0';
-        }
-        return;
-    }
-
     if (pkt_trace_enabled_by_clish) // tracing enabled by 'system support tracer'
     {
         if (first_trace_line)
@@ -618,10 +554,17 @@ bool pktTracerDebugCheckSsn(void* ssn)
         sfip_ntop(&scb->server_ip, dipstr, sizeof(dipstr));
         uint16_t sport = ntohs(scb->client_port);
         uint16_t dport = ntohs(scb->server_port);    
+#ifdef DAQ_CAPA_VRF
+        uint16_t sAsId = scb->key->addressSpaceId_l;
+        uint16_t dAsId = scb->key->addressSpaceId_h;
 
-
+        snprintf(pkt_tracer_debug_session, DEBUG_SESSION_ID_SIZE, "%s-%u - %s-%u %u AS %u-%u",
+                 sipstr, (unsigned)sport, dipstr, (unsigned)dport, (unsigned)scb->protocol,
+                 sAsId, dAsId);
+#else
         snprintf(pkt_tracer_debug_session, DEBUG_SESSION_ID_SIZE, "%s-%u - %s-%u %u",
                 sipstr, (unsigned)sport, dipstr, (unsigned)dport, (unsigned)scb->protocol);
+#endif
         pkt_trace_enabled_by_clish = true;
         return true;
     }
