@@ -183,7 +183,9 @@ static HI_EVENT_INFO server_event_info[HI_EO_SERVER_EVENT_NUM] = {
     {HI_EO_SERVER_NO_RESP_HEADER_END,HI_EO_HIGH_PRIORITY,
         HI_EO_SERVER_NO_RESP_HEADER_END_STR},
     {HI_EO_SERVER_INVALID_CHUNK_SIZE,HI_EO_HIGH_PRIORITY,
-        HI_EO_SERVER_INVALID_CHUNK_SIZE_STR}
+        HI_EO_SERVER_INVALID_CHUNK_SIZE_STR},
+    {HI_EO_SERVER_INVALID_VERSION_RESP_HEADER,HI_EO_HIGH_PRIORITY,
+        HI_EO_SERVER_INVALID_VERSION_RESP_HEADER_STR}
 };
 
 /*
