@@ -117,6 +117,7 @@ typedef struct {
     uint8_t junk_chars;
     bool eoh;
     bool disable_chunked;
+    bool valid_http;
 } Hi5State;
 
 // config stuff
@@ -279,8 +280,8 @@ typedef struct {
 // more of these make it easier to insert states
 #define P0 (0)
 #define P1 (P0+8)
-#define P2 (P1+10)
-#define P3 (P2+3)
+#define P2 (P1+11)
+#define P3 (P2+2)
 #define P4 (P3+2)
 
 #define Q0 (P4+3)
@@ -345,13 +346,14 @@ static HiRule hi_rule[] =
     { P1+ 5, P1+ 6, P1+ 6, ACT_NOP, DIGS },
     { P1+ 6, P1+ 7, P1+ 7, ACT_NOP, DIGS },
     { P1+ 7, P1+ 8, P4+ 2, ACT_NOP, DIGS },
-    { P1+ 8, P1+ 9, P4+ 2, ACT_NOP, LWSS },
-    { P1+ 9, P1+ 9, P2   , ACT_NOP, LWSS },
+    { P1+ 8, P1+ 10, P1+ 9, ACT_NOP, LWSS }, 
+    // no status message (http response status code followed by \r\n)    
+    { P1+ 9, R2+ 0, P4+ 2, ACT_RSP, EOLS },
+    { P1+ 10, P1+ 10, P2, ACT_NOP, LWSS },
 
     // now get status message (variable)
-    { P2+ 0, P2+ 1, P2+ 1, ACT_NOP, ANYS },
-    { P2+ 1, R2+ 0, P2+ 2, ACT_RSP, EOLS },
-    { P2+ 2, P2+ 1, P2+ 1, ACT_NOP, ANYS },
+    { P2+ 0, R2+ 0, P2+ 1, ACT_RSP, EOLS },
+    { P2+ 1, P2+ 0, P2+ 0, ACT_NOP, ANYS },
 
     { P3+ 0, P0   , P3+ 1,   ACT_JNK, EOLS },
     { P3+ 1, P3+ 0, P3+ 0,   ACT_JNK, ANYS },
@@ -895,7 +897,10 @@ static inline PAF_Status hi_exec (Hi5State* s, Action a, int c, void* ssn)
             break;
         case ACT_JNK:
             if(++(s->junk_chars) >= MAX_JUNK_CHAR_BEFORE_RESP_STATUS)
+            {
+                s->valid_http = false;
                 return PAF_ABORT;
+            }  
             break;
     }
     return PAF_SEARCH;
@@ -1343,7 +1348,7 @@ static PAF_Status hi_paf (
     }
 
     hip->eoh = false;
-
+hip->valid_http = true;
     DEBUG_WRAP(DebugMessage(DEBUG_STREAM_PAF,
         "%s: len=%u\n", __FUNCTION__, len);)
 
@@ -1717,6 +1722,17 @@ uint32_t hi_paf_resp_bytes_processed(void* ssn)
     return 0;
 }
 
+bool hi_paf_valid_http(void* ssn)
+{
+    if ( ssn )
+    {   
+        Hi5State** s = (Hi5State **)stream_api->get_paf_user_data(ssn, 0, hi_paf_id);
+         
+        if ( s && *s )
+            return ((*s)->valid_http);
+    }
+    return 1;
+}
 bool hi_paf_disable_te(void* ssn, bool to_server)
 {
     if ( ssn )
