@@ -48,6 +48,10 @@
 #define STREAM_MAX_SSN_TIMEOUT      3600 * 24 /* max timeout (approx 1 day) */
 #define STREAM_MIN_SSN_TIMEOUT      1         /* min timeout (1 second) */
 #define STREAM_MIN_ALT_HS_TIMEOUT   0         /* min timeout (0 seconds) */
+/* Lower timeout value in seconds to clean up the session
+ * for receiving valid RST for a ongoing/hanged tcp session.
+ */
+#define STREAM_SSN_RST_TIMEOUT      180
 #define STREAM_TRACK_YES            1
 #define STREAM_TRACK_NO             0
 
