@@ -152,6 +152,7 @@ static StreamHAStats s5ha_stats;
 static HADebugSessionConstraints s5_ha_debug_info;
 static volatile int s5_ha_debug_flag = 0;
 static char s5_ha_debug_session[HA_DEBUG_SESSION_ID_SIZE];
+uint32_t HA_CRITICAL_SESSION_FLAGS = ( SSNFLAG_DROP_CLIENT | SSNFLAG_DROP_SERVER | SSNFLAG_RESET );
 
 #define IP6_SESSION_KEY_SIZE sizeof(SessionKey)
 #define IP4_SESSION_KEY_SIZE (IP6_SESSION_KEY_SIZE - 24)
@@ -781,7 +782,11 @@ void SessionHAInit( struct _SnortConfig *sc, char *args )
 
 #ifdef HAVE_DAQ_EXT_MODFLOW
     if (session_configuration->ha_config->use_daq)
+    {
         AddFuncToPreprocMetaEvalList(sc, SessionHAMetaEval, PP_SESSION_PRIORITY, PP_SESSION);
+        //Do not send delete notification on RST when there is a underlying data plane.
+        HA_CRITICAL_SESSION_FLAGS &= ~SSNFLAG_RESET;
+    }    
 #endif
 
     StreamPrintHAConfig(session_configuration->ha_config);
@@ -1468,16 +1473,19 @@ void SessionHANotifyDeletion(SessionControlBlock *scb)
         return;
     }
 
-#ifndef HAVE_DAQ_EXT_MODFLOW
-    debug_flag = StreamHADebugCheck(scb->key, s5_ha_debug_flag, &s5_ha_debug_info,
+#ifdef SIDE_CHANNEL
+    if (session_configuration->ha_config->use_side_channel)
+    {
+        debug_flag = StreamHADebugCheck(scb->key, s5_ha_debug_flag, &s5_ha_debug_info,
                                      s5_ha_debug_session, sizeof(s5_ha_debug_session));
-    if (debug_flag)
-        LogMessage("S5HADbg Producing deletion message for %s\n", s5_ha_debug_session);
-
+        if (debug_flag)
+            LogMessage("S5HADbg Producing deletion message for %s\n",
+                       s5_ha_debug_session);
+    }
+#endif
 
     /* Calculate the size of the deletion message. */
     msg_size = CalculateHAMessageSize(HA_EVENT_DELETE, scb);
-#endif
 
     if (runtime_output_fd >= 0)
     {
@@ -1488,20 +1496,22 @@ void SessionHANotifyDeletion(SessionControlBlock *scb)
         }
     }
 
+    if (session_configuration->ha_config->use_daq)
+    {
+        s5ha_stats.delete_messages_not_sent++;
+        PREPROC_PROFILE_END(sessionHAPerfStats);
+        return;
+    }
+
 #ifdef SIDE_CHANNEL
     if (session_configuration->ha_config->use_side_channel)
     {
         SendSCDeletionMessage(scb, msg_size);
     }
 #endif
-
-    scb->ha_flags |= HA_FLAG_DELETED;
-
-#ifndef HAVE_DAQ_EXT_MODFLOW
+  
     s5ha_stats.delete_messages_sent++;
-#else
-    s5ha_stats.delete_messages_not_sent++;
-#endif
+    scb->ha_flags |= HA_FLAG_DELETED;
 
     PREPROC_PROFILE_END(sessionHAPerfStats);
 }
