@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2004-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -544,11 +544,20 @@ int StreamProcessUdp( Packet *p, SessionControlBlock *scb,
     if ( !scb->session_established )
     {
         int rc;
+#if defined(DAQ_CAPA_CST_TIMEOUT)
+        uint64_t timeout;
+        if (Daq_Capa_Timeout)
+        {
+          GetTimeout(p,&timeout);
+          s5UdpPolicy->session_timeout = timeout;
+        }
+#endif
         rc = isPacketFilterDiscard( p, s5UdpPolicy->flags & STREAM_CONFIG_IGNORE_ANY );
         if( ( rc == PORT_MONITOR_PACKET_DISCARD ) && !StreamExpectIsExpected( p, &hash_node ) )
         {
             //ignore the packet
             UpdateFilteredPacketStats(&sfBase, IPPROTO_UDP);
+            session_api->set_expire_timer(p, scb, s5UdpPolicy->session_timeout);
             PREPROC_PROFILE_END(s5UdpPerfStats);
             return 0;
         }
@@ -597,7 +606,6 @@ int StreamProcessUdp( Packet *p, SessionControlBlock *scb,
     }
     MarkupPacketFlags(p, scb);
     session_api->set_expire_timer(p, scb, s5UdpPolicy->session_timeout);
-
     PREPROC_PROFILE_END(s5UdpPerfStats);
 
     return 0;
