@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -87,6 +87,32 @@ int StreamExpireSession(SessionControlBlock *scb)
     return 1;
 }
 
+void StreamDeleteSession(SessionControlBlock *scb)
+{
+    sfBase.iStreamTimeouts++;
+    scb->ha_state.session_flags |= SSNFLAG_TIMEDOUT;
+
+    switch (scb->protocol)
+    {
+        case IPPROTO_TCP:
+            s5stats.tcp_timeouts++;
+            break;
+        case IPPROTO_UDP:
+            s5stats.udp_timeouts++;
+            break;
+        case IPPROTO_ICMP:
+            s5stats.icmp_timeouts++;
+        case IPPROTO_IP:
+            s5stats.ip_timeouts++;
+            break;
+    }
+
+    if ( session_api->delete_session_by_key(scb, "timeout") != SFXHASH_OK )
+    {
+        LogMessage("WARNING: failed to delete session. \n");
+    }
+}
+
 int StreamExpire(Packet *p, SessionControlBlock *scb)
 {
     uint64_t pkttime = CalcJiffies(p);
@@ -135,7 +161,10 @@ void StreamActiveResponse(Packet* p, SessionControlBlock *scb)
 
         Active_KillSession(p, &flags);
         ++scb->response_count;
-        session_api->set_expire_timer(p, scb, delay);
+#if defined(DAQ_CAPA_CST_TIMEOUT)
+        if (!Daq_Capa_Timeout)
+#endif
+           session_api->set_expire_timer(p, scb, delay);
 
         scb->session_state &= ~(STREAM_STATE_DROP_CLIENT|STREAM_STATE_DROP_SERVER);
     }
