@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -136,6 +136,7 @@ typedef struct _FlushMgr
     uint8_t    flush_policy;
     uint8_t    flush_type;
     uint8_t    auto_disable;
+    bool       flush;
     //uint8_t    spare;
 
 } FlushMgr;
@@ -380,4 +381,6 @@ extern SessionConfiguration *stream_session_config;
 extern tSfPolicyUserContextId stream_online_config;
 extern tSfActionQueueId decoderActionQ;
 
+void StreamDeleteSession(SessionControlBlock *scb);
+
 #endif /* STREAM_COMMON_H_ */
