@@ -39,7 +39,7 @@ static void getTicksPerMicrosec(void)
 }
 
 #ifdef PI_PACKET_LATENCY_SUPPORT
-static uint32_t GetPacketLatency()
+uint32_t GetPacketLatency(void)
 {
     if( (latencyStats != NULL) && (latencyStats->exits != 0) )
     {
@@ -57,7 +57,7 @@ static uint32_t GetPacketLatency()
 #endif
 
 #ifdef PI_PACKET_DROPS_SUPPORT
-static double GetPacketDropPortion()
+double GetPacketDropPortion(void)
 {
     uint64_t drop, recv, sum;
     double portion;
