@@ -84,7 +84,15 @@ int PerfIndicator_RegisterPreprocStat( PreprocStats *Stats,
 
 int PerfIndicator_GetIndicators( Perf_Indicator_Descriptor_p_t PI_List );
 
-static inline Perf_Indicator_Descriptor_p_t PerfIndicator_NewDescriptor()
+#ifdef PI_PACKET_LATENCY_SUPPORT
+uint32_t GetPacketLatency(void);
+#endif
+
+#ifdef PI_PACKET_DROPS_SUPPORT
+double GetPacketDropPortion(void);
+#endif
+
+static inline Perf_Indicator_Descriptor_p_t PerfIndicator_NewDescriptor(void)
 {
     /* Caller must check for NULL */
     return( (Perf_Indicator_Descriptor_p_t)calloc(sizeof(Perf_Indicator_Descriptor_t), sizeof(char)));
