@@ -136,12 +136,6 @@
 // HA Session flags helper macros
 #define HA_IGNORED_SESSION_FLAGS   ( SSNFLAG_COUNTED_INITIALIZE | SSNFLAG_COUNTED_ESTABLISH | \
                                      SSNFLAG_COUNTED_CLOSING | SSNFLAG_LOGGED_QUEUE_FULL)
-#ifdef HAVE_DAQ_EXT_MODFLOW
-// Do not send delete notifications with RST
-#define HA_CRITICAL_SESSION_FLAGS  ( SSNFLAG_DROP_CLIENT | SSNFLAG_DROP_SERVER )
-#else
-#define HA_CRITICAL_SESSION_FLAGS  ( SSNFLAG_DROP_CLIENT | SSNFLAG_DROP_SERVER | SSNFLAG_RESET )
-#endif
 
 #define HA_TCP_MAJOR_SESSION_FLAGS ( SSNFLAG_ESTABLISHED )
 
@@ -161,16 +155,21 @@
 typedef struct _StreamSessionKey
 {
 /* XXX If this data structure changes size, HashKeyCmp must be updated! */
-    uint32_t   ip_l[4]; /* Low IP */
-    uint32_t   ip_h[4]; /* High IP */
-    uint16_t   port_l; /* Low Port - 0 if ICMP */
-    uint16_t   port_h; /* High Port - 0 if ICMP */
-    uint16_t   vlan_tag;
-    uint8_t    protocol;
-    char       pad;
-    uint32_t   mplsLabel; /* MPLS label */
-    uint16_t   addressSpaceId;
-    uint16_t   addressSpaceIdPad1;
+    uint32_t  ip_l[4]; /* Low IP */
+    uint32_t  ip_h[4]; /* High IP */
+    uint16_t  port_l; /* Low Port - 0 if ICMP */
+    uint16_t  port_h; /* High Port - 0 if ICMP */
+    uint16_t  vlan_tag;
+    uint8_t   protocol;
+    char      pad;
+    uint32_t  mplsLabel; /* MPLS label */
+#ifdef DAQ_CAPA_VRF
+    uint16_t  addressSpaceId_l; /* Low ASID */      
+    uint16_t  addressSpaceId_h; /* Higher ASID */     
+#else
+    uint16_t  addressSpaceId;
+    uint16_t  addressSpaceIdPad1;
+#endif
 /* XXX If this data structure changes size, HashKeyCmp must be updated! */
 } StreamSessionKey;
 
@@ -227,6 +226,8 @@ typedef uint32_t ( *StreamHAProducerFunc )( void *ssnptr, uint8_t *buf );
 typedef int ( *StreamHAConsumerFunc )( void *ssnptr, const uint8_t *data, uint8_t length );
 #endif
 
+extern uint32_t HA_CRITICAL_SESSION_FLAGS;
+
 // Protocol types for creating session cache
 #define SESSION_PROTO_TCP 0x00
 #define SESSION_PROTO_UDP 0x01
@@ -292,7 +293,13 @@ typedef struct _session_api
       *   Session Key
       */
      int (*get_session_key_by_ip_port)(sfaddr_t*, uint16_t, sfaddr_t*, uint16_t, char, uint16_t,
-                                       uint32_t, uint16_t, SessionKey *);
+                                       uint32_t,
+#ifdef DAQ_CAPA_VRF
+                                       uint16_t, uint16_t,
+#else
+                                       uint16_t, 
+#endif
+                                       SessionKey *);
 
      /* Lookup by session key and return Session Control Block
       *
@@ -828,7 +835,13 @@ typedef struct _session_api
      *     Stream session pointer
      */
     void *(*get_session_ptr_from_ip_port)(sfaddr_t*, uint16_t, sfaddr_t*, uint16_t, char,
-                                          uint16_t, uint32_t, uint16_t);
+                                          uint16_t, uint32_t, 
+#ifdef DAQ_CAPA_VRF
+                                          uint16_t, uint16_t
+#else
+                                          uint16_t
+#endif
+                                          );
 
     /** Retrieve the session key given a stream session pointer.
      *
@@ -880,8 +893,13 @@ typedef struct _session_api
      * Returns
      *     Application Data reference (pointer)
      */
-    void *(*get_application_data_from_ip_port)(sfaddr_t*, uint16_t, sfaddr_t*, uint16_t, char,
-                                               uint16_t, uint32_t, uint16_t, uint32_t);
+    void *(*get_application_data_from_ip_port)(sfaddr_t*, uint16_t, sfaddr_t*, uint16_t, 
+#ifdef DAQ_CAPA_VRF
+                                               uint16_t, uint16_t, 
+#else
+                                               uint16_t,
+#endif                                             
+                                               char, uint16_t, uint32_t, uint32_t);
 
     void (*disable_preproc_for_session)( void *, uint32_t );
     void (*enable_preproc_for_port)( struct _SnortConfig *, uint32_t, uint32_t, uint16_t );
