@@ -226,9 +226,9 @@ void ApplyFlowDepth(HTTPINSPECT_CONF *, Packet *, HttpSessionData *, int, int, u
 
 
 int SnortHttpInspect(HTTPINSPECT_GLOBAL_CONF *GlobalConf, Packet *p);
-int ProcessGlobalConf(HTTPINSPECT_GLOBAL_CONF *, char *, int);
+int ProcessGlobalConf(HTTPINSPECT_GLOBAL_CONF *, char *, int, char **saveptr);
 int PrintGlobalConf(HTTPINSPECT_GLOBAL_CONF *);
-int ProcessUniqueServerConf(struct _SnortConfig *, HTTPINSPECT_GLOBAL_CONF *, char *, int);
+int ProcessUniqueServerConf(struct _SnortConfig *, HTTPINSPECT_GLOBAL_CONF *, char *, int, char **);
 int HttpInspectInitializeGlobalConfig(HTTPINSPECT_GLOBAL_CONF *, char *, int);
 HttpSessionData * SetNewHttpSessionData(Packet *, void *);
 void FreeHttpSessionData(void *data);
