@@ -1828,14 +1828,23 @@ static int HttpInspectReloadVerify(struct _SnortConfig *sc, void *swap_config)
 
     policy_id = getParserPolicy(sc);
 
+    LogMessage("HTTPInspect: gzip old=%s, fd old=%s\n", curr_gzip ? "true": "false", curr_fd ? "true": "false");
     if( curr_gzip || curr_fd )
     {
         /* Look for the case where the current and swap configs have differing gzip & fd options. */
         swap_fd = (sfPolicyUserDataIterate(sc, hi_swap_config, HttpInspectFileDecomp) != 0);
         swap_gzip = (sfPolicyUserDataIterate(sc, hi_swap_config, HttpInspectExtractGzip) != 0);
 
+        LogMessage("HTTPInspect: gzip new=%s, fd new=%s\n", swap_gzip ? "true": "false", swap_fd ? "true": "false");
         if(defaultSwapConfig)
         {
+             LogMessage("HTTPInspect: old gzip memcap=%u, new gzip memcap=%u\n", defaultConfig->max_gzip_mem, defaultSwapConfig->max_gzip_mem);
+             if(curr_gzip)
+                 LogMessage("HTTPInspect: HTTP-GZIP-MEMPOOL used=%zu, free=%zu, max=%zu, obj_size=%zu\n",
+                         hi_gzip_mempool->used_memory, hi_gzip_mempool->free_memory, hi_gzip_mempool->max_memory, hi_gzip_mempool->obj_size);
+             if(curr_fd)
+                 LogMessage("HTTPInspect: HTTP-FD-MEMPOOL used=%zu, free=%zu, max=%zu, obj_size=%zu\n",
+                         hi_fd_conf.fd_MemPool->used_memory, hi_fd_conf.fd_MemPool->free_memory, hi_fd_conf.fd_MemPool->max_memory, hi_fd_conf.fd_MemPool->obj_size);
              if(defaultSwapConfig->max_gzip_mem < defaultConfig->max_gzip_mem)
              {
                   /* Change in max_gzip_mem value changes the number of max_sessions of hi_gzip_mempool and max_gzip_sessions.
@@ -1867,6 +1876,8 @@ static int HttpInspectReloadVerify(struct _SnortConfig *sc, void *swap_config)
     {
         if (defaultSwapConfig != NULL)
         {
+            LogMessage("HTTPInspect: HTTP-MEMPOOL old memcap=%d, new_memcap=%d, used=%zu, free=%zu, max=%zu, obj_size=%zu\n",
+                    defaultConfig->memcap, defaultSwapConfig->memcap, http_mempool->used_memory, http_mempool->free_memory, http_mempool->max_memory, http_mempool->obj_size);
              if (defaultSwapConfig->memcap < defaultConfig->memcap)
                   ReloadAdjustRegister(sc, "HTTP-MEMPOOL", policy_id, &HttpMempoolReloadAdjust, NULL, NULL);
         }
@@ -1906,6 +1917,9 @@ static int HttpInspectReloadVerify(struct _SnortConfig *sc, void *swap_config)
          */
         if(defaultSwapConfig)
         {
+            LogMessage("HTTPInspect: HTTP-MIME-MEMPOOL old memcap=%d, new_memcap=%d, used=%zu, free=%zu, max=%zu, obj_size=%zu\n",
+                    defaultConfig->decode_conf.max_mime_mem, defaultSwapConfig->decode_conf.max_mime_mem, mime_decode_mempool->used_memory,
+                    mime_decode_mempool->free_memory, mime_decode_mempool->max_memory, mime_decode_mempool->obj_size);
              if( defaultSwapConfig->decode_conf.max_mime_mem  < defaultConfig->decode_conf.max_mime_mem )
                   ReloadAdjustRegister(sc, "HTTP-MIME-MEMPOOL", policy_id, &HttpMimeReloadAdjust, NULL, NULL);
         }
@@ -1933,6 +1947,9 @@ static int HttpInspectReloadVerify(struct _SnortConfig *sc, void *swap_config)
             /* If memcap of HTTP mIme changes, log mempool need to be adjusted bcz mempool max_mempory will be changed.
               * Registering here to adjust Log memory Pool when memcap changes.
               */
+            LogMessage("HTTPInspect: HTTP-LOG-MEMPOOL old memcap=%d, new_memcap=%d, used=%zu, free=%zu, max=%zu, obj_size=%zu\n",
+                    defaultConfig->mime_conf.memcap, defaultSwapConfig->mime_conf.memcap, mime_log_mempool->used_memory, mime_log_mempool->free_memory,
+                    mime_log_mempool->max_memory, mime_log_mempool->obj_size);
             if (defaultSwapConfig->mime_conf.memcap < defaultConfig->mime_conf.memcap)
                  ReloadAdjustRegister(sc, "HTTP-LOG-MEMPOOL", policy_id, &HttpLogReloadAdjust, NULL, NULL);
        }
