@@ -1,6 +1,6 @@
 /* $Id$ */
 /*
- ** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ ** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  ** Copyright (C) 2010-2013 Sourcefire, Inc.
  **
  ** This program is free software; you can redistribute it and/or modify
@@ -128,8 +128,11 @@ static NormalizerContext* Init_GetContext (struct _SnortConfig *sc)
     {
         pc = (NormalizerContext* )SnortAlloc(sizeof(NormalizerContext));
         sfPolicyUserDataSetCurrent(base_set, pc);
-
-        AddFuncToPreprocList( sc, Preproc_Execute, PP_NORMALIZE_PRIORITY,  PP_NORMALIZE, PROTO_BITS);
+        if( pc->regFunc != reload)
+        {
+            AddFuncToPreprocList( sc, Preproc_Execute, PP_NORMALIZE_PRIORITY,  PP_NORMALIZE, PROTO_BITS);
+            pc->regFunc = init;
+        }
         session_api->enable_preproc_all_ports( sc, PP_NORMALIZE, PROTO_BITS );          
     }
     pc->normMode = ScNapInlineTestModeNewConf(sc) ? NORM_MODE_WOULDA : NORM_MODE_ON;
@@ -784,8 +787,12 @@ static NormalizerContext* Reload_GetContext (struct _SnortConfig *sc, void **new
         pc = (NormalizerContext* )SnortAlloc(sizeof(NormalizerContext));
         sfPolicyUserDataSetCurrent(swap_set, pc);
 
-        AddFuncToPreprocList(
-            sc, Preproc_Execute, PP_NORMALIZE_PRIORITY, PP_NORMALIZE, PROTO_BITS);
+        if( pc->regFunc != init)
+        {
+            AddFuncToPreprocList(
+                sc, Preproc_Execute, PP_NORMALIZE_PRIORITY, PP_NORMALIZE, PROTO_BITS);
+            pc->regFunc = reload;
+        }
         session_api->enable_preproc_all_ports( sc, PP_NORMALIZE, PROTO_BITS );          
   
     }
