@@ -1,7 +1,7 @@
 /* $Id$ */
 /****************************************************************************
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -73,6 +73,7 @@
 #include "sfPolicy.h"
 #include "sp_flowbits.h"
 #include "stream5_ha.h"
+#include "control/sfcontrol_funcs.h"
 
 #ifdef TARGET_BASED
 #include "sftarget_protocol_reference.h"
@@ -129,6 +130,7 @@ static void StreamResetStats(int, void *);
 static int StreamVerifyConfig(struct _SnortConfig *);
 static void StreamPrintSessionConfig(SessionConfiguration *);
 static void StreamPrintStats(int);
+static void DisplayStreamStatistics (uint16_t type, void *old_context, struct _THREAD_ELEMENT *te, ControlDataSendFunc f);
 static void StreamProcess(Packet *p, void *context);
 static inline int IsEligible(Packet *p);
 #ifdef TARGET_BASED
@@ -191,6 +193,7 @@ static void s5UnsetPortFilterStatus( struct _SnortConfig *, IpProto protocol, ui
 static void setServiceFilterStatus( struct _SnortConfig *sc, int service, int status, tSfPolicyId policyId, int parsing );
 #endif
 static void StreamForceSessionExpiration(void *ssnptr);
+static void StreamForceDeleteSession(void *ssnptr );
 static void registerReassemblyPort( char *network, uint16_t port, int reassembly_direction );
 static void unregisterReassemblyPort( char *network, uint16_t port, int reassembly_direction );
 static unsigned StreamRegisterHandler(Stream_Callback);
@@ -224,6 +227,7 @@ static bool StreamShowRebuiltPackets();
 static bool StreamIsSessionHttp2Upg(void* ssnptr);
 static void StreamSetSessionHttp2Upg(void* ssnptr);
 static int RegisterFTPFlushCallback (FTP_Processor_Flush_Callback cb);
+static void setFtpFilePosition (void *scbptr,bool flush);
 #ifdef HAVE_DAQ_DECRYPTED_SSL
 static int StreamSimulateTcpAck(void *ssnptr, uint8_t dir, uint32_t len);
 #endif
@@ -271,6 +275,7 @@ StreamAPI s5api = {
     /* .register_reassembly_port = */ registerReassemblyPort,
     /* .register_reassembly_port = */ unregisterReassemblyPort,
     /* .expire_session = */ StreamForceSessionExpiration,
+    /* .force_delete_session = */ StreamForceDeleteSession,    
     /* .register_event_handler = */ StreamRegisterHandler,
     /* .set_event_handler = */ StreamSetHandler,
     /* .set_reset_policy = */ StreamResetPolicy,
@@ -295,7 +300,8 @@ StreamAPI s5api = {
     /* .is_session_http2_upg */ StreamIsSessionHttp2Upg,
     /* .set_session_http2_upg */ StreamSetSessionHttp2Upg,
     /* .get_preproc_flags */ StreamGetPreprocFlags,
-    /* .register_ftp_flush_cb */ RegisterFTPFlushCallback
+    /* .register_ftp_flush_cb */ RegisterFTPFlushCallback,
+    /* .set_ftp_file_position */ setFtpFilePosition
 #ifdef HAVE_DAQ_DECRYPTED_SSL
     ,
     /* .simulate_tcp_ack_in_peer_stream_tracker = */ StreamSimulateTcpAck
@@ -322,7 +328,9 @@ void SetupStream6(void)
 
     // init pointer to stream api dispatch table...
     stream_api = &s5api;
-
+	
+    /* Registering for SFR CLI */
+	ControlSocketRegisterHandler(CS_TYPE_STREAM_STATS, NULL, NULL, &DisplayStreamStatistics);
     DEBUG_WRAP(DebugMessage(DEBUG_STREAM, "Stream preprocessor setup complete.\n"););
 }
 
@@ -677,6 +685,88 @@ static void StreamCleanExit(int signal, void *foo)
     stream_online_config = NULL;
 }
 
+static void DisplayStreamStatistics (uint16_t type, void *old_context, struct _THREAD_ELEMENT *te, ControlDataSendFunc f)
+{
+    char buffer[CS_STATS_BUF_SIZE + 1];
+    int len = 0;
+    int total_sessions = s5stats.total_tcp_sessions + s5stats.total_udp_sessions +
+        s5stats.total_icmp_sessions + s5stats.total_ip_sessions;
+
+    if (total_sessions) {
+        len = snprintf(buffer, CS_STATS_BUF_SIZE, "Stream statistics:\n"
+                "            Total sessions: %u\n"
+                "              TCP sessions: %u\n"
+                "              UDP sessions: %u\n"
+                "             ICMP sessions: %u\n"
+                "               IP sessions: %u\n"
+                "                TCP Prunes: %u\n"
+                "                UDP Prunes: %u\n"
+                "               ICMP Prunes: %u\n"
+                "                 IP Prunes: %u\n"
+                "TCP StreamTrackers Created: %u\n"
+                "TCP StreamTrackers Deleted: %u\n"
+                "              TCP Timeouts: %u\n"
+                "              TCP Overlaps: %u\n"
+                "       TCP Segments Queued: %u\n"
+                "     TCP Segments Released: %u\n"
+                "       TCP Rebuilt Packets: %u\n"
+                "         TCP Segments Used: %u\n"
+                "              TCP Discards: %u\n"
+                "                  TCP Gaps: %u\n"
+                "      UDP Sessions Created: %u\n"
+                "      UDP Sessions Deleted: %u\n"
+                "              UDP Timeouts: %u\n"
+                "              UDP Discards: %u\n"
+                "                    Events: %u\n"
+                "           Internal Events: %u\n"
+                "           TCP Port Filter\n"
+                "                  Filtered: %u\n"
+                "                 Inspected: %u\n"
+                "                   Tracked: %u\n"
+                "           UDP Port Filter\n"
+                "                  Filtered: %u\n"
+                "                 Inspected: %u\n"
+                "                   Tracked: %u\n"
+                , total_sessions
+                , s5stats.total_tcp_sessions
+                , s5stats.total_udp_sessions
+                , s5stats.total_icmp_sessions
+                , s5stats.total_ip_sessions
+                , StreamGetTcpPrunes()
+                , StreamGetUdpPrunes()
+                , StreamGetIcmpPrunes()
+                , StreamGetIpPrunes()
+                , s5stats.tcp_streamtrackers_created
+                , s5stats.tcp_streamtrackers_released
+                , s5stats.tcp_timeouts
+                , s5stats.tcp_overlaps
+                , s5stats.tcp_streamsegs_created
+                , s5stats.tcp_streamsegs_released
+                , s5stats.tcp_rebuilt_packets
+                , s5stats.tcp_rebuilt_seqs_used
+                , s5stats.tcp_discards
+                , s5stats.tcp_gaps
+                , s5stats.udp_sessions_created
+                , s5stats.udp_sessions_released
+                , s5stats.udp_timeouts
+                , s5stats.udp_discards
+                , s5stats.events
+                , s5stats.internalEvents
+                , s5stats.tcp_port_filter.filtered
+                , s5stats.tcp_port_filter.inspected
+                , s5stats.tcp_port_filter.session_tracked
+                , s5stats.udp_port_filter.filtered
+                , s5stats.udp_port_filter.inspected
+                , s5stats.udp_port_filter.session_tracked);
+    } else {
+        len  = snprintf(buffer, CS_STATS_BUF_SIZE, "Stream statistics not available\n Total sessions: %u", total_sessions);
+    }
+
+    if (-1 == f(te, (const uint8_t *)buffer, len)) {
+        LogMessage("Unable to send data to the frontend\n");
+    }
+}
+
 static void StreamPrintStats(int exiting)
 {
     LogMessage("Stream statistics:\n");
@@ -1601,6 +1691,14 @@ static void StreamForceSessionExpiration( void *ssnptr )
     }
 }
 
+static void StreamForceDeleteSession(void *ssnptr )
+{
+    SessionControlBlock *scb = ( SessionControlBlock * ) ssnptr;
+
+    if(scb)
+        StreamDeleteSession( scb );
+}
+
 static void registerReassemblyPort( char *network, uint16_t port, int reassembly_direction )
 {
     registerPortForReassembly( network, port, reassembly_direction );
@@ -1769,6 +1867,13 @@ void StreamCallHandler( Packet* p, unsigned id )
     stream_cb[ id ]( p );
 }
 
+static void setFtpFilePosition (void *scbptr,bool flush)
+{
+  SetFTPFileLocation(scbptr,flush);
+  return;
+}
+
+
 static int StreamSetApplicationProtocolIdExpectedPreassignCallbackId( const Packet *ctrlPkt,
         sfaddr_t* srcIP, uint16_t srcPort, sfaddr_t* dstIP, uint16_t dstPort,
         uint8_t protocol, int16_t protoId, uint32_t preprocId, void *protoData,
