@@ -1,6 +1,6 @@
 /* $Id$ */
 /*
- ** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ ** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * ** Copyright (C) 2005-2013 Sourcefire, Inc.
  * ** AUTHOR: Steven Sturges
  * **
@@ -476,6 +476,7 @@ typedef struct _stream_api
      *     Session Ptr
      */
     void (*expire_session)(void *);
+    void (*force_delete_session)(void *);
 
     /* register returns a non-zero id for use with set; zero is error */
     unsigned (*register_event_handler)(Stream_Callback);
@@ -630,6 +631,14 @@ typedef struct _stream_api
      */
     int (*register_ftp_flush_cb)(FTP_Processor_Flush_Callback);
 
+    /* set the ftp file position
+     *
+     * parameters
+     *   ssnptr -session pointer
+     *   flage -flush flage
+     */
+    void (*set_ftp_file_position)(void *ssnptr, bool flush);
+
 #ifdef HAVE_DAQ_DECRYPTED_SSL
     /* Simulate ACK in peer Streamtracker
      *
