@@ -25,6 +25,10 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_GETTID
+#define _GNU_SOURCE
+#endif
+
 #include <stdio.h>
 #include <ctype.h>
 #include <sys/stat.h>
@@ -935,6 +939,10 @@ void * ReloadConfigThread(void *data)
                      * attached to existing sessions. */
                     SwapPreprocConfigurations(snort_conf);
                     FreeSwappedPreprocConfigurations(snort_conf);
+#if defined (SIDE_CHANNEL) && defined (REG_TEST)
+                    if (snort_conf && snort_conf->file_config)
+                      FileSSConfigFree(snort_conf->file_config);
+#endif
 
 #ifdef CONTROL_SOCKET
                     reloadInProgress = false;
