@@ -430,7 +430,7 @@ int DAQ_UnprivilegedStart (void)
 #ifdef INLINE_FAILOPEN
     return ( (daq_get_capabilities(daq_mod, daq_hand) & DAQ_CAPA_UNPRIV_START) || (ScUid() == -1 && ScGid() == -1) );
 #else
-    return ( daq_get_capabilities(daq_mod, daq_hand) & DAQ_CAPA_UNPRIV_START );
+    return ( (daq_get_capabilities(daq_mod, daq_hand) & DAQ_CAPA_UNPRIV_START) );
 #endif
 }
 
