@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2003-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -251,6 +251,12 @@ bool TextLog_PrintUnicode(TextLog* this, uint8_t *buffer, uint32_t length, uint8
     uint32_t out_len = length/2 + 1, i, j;
     wchar_t *outbuf = (wchar_t *)malloc(out_len*sizeof(wchar_t));
 
+    if (!outbuf)
+    {
+        FatalError("TextLog_PrintUnicode: Failed to allocate memory for outbuf\n");
+        return FALSE;
+    }
+
     for(i = 0,j = 0; i<length; i+=2,j++)
     {
         unsigned short value = 0;
