@@ -27,6 +27,10 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_GETTID
+#define _GNU_SOURCE
+#endif
+
 #include <signal.h>
 
 #include "dmq.h"
