@@ -1162,6 +1162,10 @@ typedef struct _PcapReadObject
 bool Daq_Capa_Timeout;
 #endif
 
+#if defined(DAQ_CAPA_VRF)
+bool Daq_Capa_Vrf;
+#endif
+
 /* ptr to the packet processor */
 typedef void (*grinder_t)(Packet *, const DAQ_PktHdr_t*, const uint8_t *);
 
@@ -1196,6 +1200,7 @@ extern grinder_t grinder;
 #ifdef SIDE_CHANNEL
 extern pthread_mutex_t snort_process_lock;
 #endif
+extern pthread_mutex_t dynamic_rules_lock;
 
 extern OutputFuncNode *AlertList;
 extern OutputFuncNode *LogList;
@@ -1210,6 +1215,11 @@ extern PostConfigFuncNode *plugin_reload_funcs;
 #endif
 extern PeriodicCheckFuncNode *periodic_check_funcs;
 
+#if defined(DAQ_VERSION) && DAQ_VERSION > 9
+void print_pktverdict (Packet *, uint64_t );
+void print_flow(Packet *, char *, uint32_t, uint64_t, uint64_t );
+#endif
+
 /*  P R O T O T Y P E S  ******************************************************/
 int SnortMain(int argc, char *argv[]);
 DAQ_Verdict ProcessPacket(Packet*, const DAQ_PktHdr_t*, const uint8_t*, void*);
