@@ -27,6 +27,10 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_GETTID
+#define _GNU_SOURCE
+#endif
+
 #ifdef TARGET_BASED
 
 #include <stdio.h>
