@@ -1,6 +1,6 @@
 /* $Id$ */
 /*
-** Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2002-2013 Sourcefire, Inc.
 ** Copyright (C) 2002 Martin Roesch <roesch@sourcefire.com>
 **
@@ -83,6 +83,7 @@ static struct mallinfo mi;
 #include "ppm.h"
 #include "active.h"
 #include "packet_time.h"
+#include "control/sfcontrol.h"
 
 #ifdef TARGET_BASED
 #include "sftarget_reader.h"
@@ -197,7 +198,7 @@ int DisplayBanner(void)
                BUILD,
                info);
     LogMessage("   ''''    By Martin Roesch & The Snort Team: http://www.snort.org/contact#team\n");
-    LogMessage("           Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.\n");
+    LogMessage("           Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.\n");
     LogMessage("           Copyright (C) 1998-2013 Sourcefire, Inc., et al.\n");
 #ifdef HAVE_PCAP_LIB_VERSION
     LogMessage("           Using %s\n", pcap_lib_version());
@@ -1013,6 +1014,18 @@ void InitGroups(int user_id, int group_id)
 #define STATS_SEPARATOR \
     "==============================================================================="
 
+static inline int DisplayCount (char *buf, const char* s, uint64_t n, int size)
+{
+    return snprintf(buf+size, CS_STATS_BUF_SIZE-size, "%11s: " FMTu64("12") "\n", s, n);
+}
+
+static inline int DisplayStat (char *buf, const char* s, uint64_t n, uint64_t tot, int size)
+{
+	return snprintf(buf+size, CS_STATS_BUF_SIZE-size,
+        "%11s: " FMTu64("12") " (%7.3f%%)\n",
+        s, n, CalcPct(n, tot));
+}
+
 static inline void LogCount (const char* s, uint64_t n)
 {
     LogMessage("%11s: " FMTu64("12") "\n", s, n);
@@ -1124,6 +1137,49 @@ static void display_mallinfo(void)
 }
 #endif
 
+void DisplayActionStats (uint16_t type, void *old_context, struct _THREAD_ELEMENT *te, ControlDataSendFunc f)
+{
+    char buffer[CS_STATS_BUF_SIZE + 1];
+    int len = 0;
+    int i = 0;
+    uint64_t total = pc.total_processed;
+    uint64_t pkts_recv = pc.total_from_daq;
+    const DAQ_Stats_t* pkt_stats = DAQ_GetStats();
+
+    if (total) {
+        // ensure proper counting of log_limit
+        SnortEventqResetCounts();
+
+        len += snprintf(buffer, CS_STATS_BUF_SIZE,  "Action Stats:\n");
+        len += DisplayStat(buffer, "Alerts", pc.total_alert_pkts, total, len);
+        len += DisplayStat(buffer, "Logged", pc.log_pkts, total, len);
+        len += DisplayStat(buffer, "Passed", pc.pass_pkts, total, len);
+        len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "Limits:\n");
+        len += DisplayCount(buffer, "Match", pc.match_limit, len);
+        len += DisplayCount(buffer, "Queue", pc.queue_limit, len);
+        len += DisplayCount(buffer, "Log", pc.log_limit, len);
+        len += DisplayCount(buffer, "Event", pc.event_limit, len);
+        len += DisplayCount(buffer, "Alert", pc.alert_limit, len);
+        len += snprintf(buffer+len, CS_STATS_BUF_SIZE-len,  "Verdicts:\n");
+
+        for ( i = 0; i < MAX_DAQ_VERDICT && len < CS_STATS_BUF_SIZE; i++ ) {
+            const char* s = Verdicts[i];
+            len += DisplayStat(buffer, s, pkt_stats->verdicts[i], pkts_recv, len);
+        }
+        if ( pc.internal_blacklist )
+            len += DisplayStat(buffer, "Int Blklst", pc.internal_blacklist, pkts_recv, len);
+
+        if ( pc.internal_whitelist )
+            len += DisplayStat(buffer, "Int Whtlst", pc.internal_whitelist, pkts_recv, len);
+    } else {
+        len = snprintf(buffer, CS_STATS_BUF_SIZE,  "Action Stats are not available\n Total Action Processed:"FMTu64("12") "\n", total);
+    }
+
+    if (-1 == f(te, (const uint8_t *)buffer, len)) {
+        LogMessage("Unable to send data to the frontend\n");
+    }
+}
+
 /* exiting should be 0 for if not exiting, 1 if restarting, and 2 if exiting */
 void DropStats(int exiting)
 {
@@ -1566,8 +1622,8 @@ void GoDaemon(void)
     (void)open("/dev/null", O_RDWR);  /* stdin, fd 0 */
 #endif
 
-    dup(0);  /* stdout, fd 0 => fd 1 */
-    dup(0);  /* stderr, fd 0 => fd 2 */
+    if (dup(0)) {}  /* stdout, fd 0 => fd 1 */
+    if (dup(0)) {}  /* stderr, fd 0 => fd 2 */
 
     SignalWaitingParent();
 #endif /* ! WIN32 */
