@@ -3,7 +3,7 @@
  **
  **  sfcontrol.c
  **
- **  Copyright (C) 2014-2018 Cisco and/or its affiliates. All rights reserved.
+ **  Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
  **  Copyright (C) 2002-2013 Sourcefire, Inc.
  **  Author(s):  Ron Dempster <rdempster@sourcefire.com>
  **
@@ -135,7 +135,7 @@ static int SendMessage(int socket_fd, const CSMessage *msg, uint32_t len)
 
     do
     {
-        numsent = write(socket_fd, (*(uint8_t **)&msg) + total, total_len - total);
+        numsent = write(socket_fd, ((const unsigned char *)msg) + total, total_len - total);
         if (!numsent)
             return 0;
         else if (numsent > 0)
@@ -173,7 +173,7 @@ static int ReadResponse(int socket_fd, CSMessageHeader *hdr)
 
     do
     {
-        numread = read(socket_fd, (*(uint8_t **)&hdr) + total, sizeof(*hdr) - total);
+        numread = read(socket_fd, ((unsigned char *)hdr) + total, sizeof(*hdr) - total);
         if (!numread)
             return 0;
         else if (numread > 0)
